from enum import Enum


class OutlineIcon(Enum):

    A_B_2 = 'a-b-2.svg'
    A_B_OFF = 'a-b-off.svg'
    A_B = 'a-b.svg'
    ABACUS_OFF = 'abacus-off.svg'
    ABACUS = 'abacus.svg'
    ABC = 'abc.svg'
    ACCESS_POINT_OFF = 'access-point-off.svg'
    ACCESS_POINT = 'access-point.svg'
    ACCESSIBLE_OFF = 'accessible-off.svg'
    ACCESSIBLE = 'accessible.svg'
    ACTIVITY_HEARTBEAT = 'activity-heartbeat.svg'
    ACTIVITY = 'activity.svg'
    AD_2 = 'ad-2.svg'
    AD_CIRCLE_OFF = 'ad-circle-off.svg'
    AD_CIRCLE = 'ad-circle.svg'
    AD_OFF = 'ad-off.svg'
    AD = 'ad.svg'
    ADDRESS_BOOK_OFF = 'address-book-off.svg'
    ADDRESS_BOOK = 'address-book.svg'
    ADJUSTMENTS_ALT = 'adjustments-alt.svg'
    ADJUSTMENTS_BOLT = 'adjustments-bolt.svg'
    ADJUSTMENTS_CANCEL = 'adjustments-cancel.svg'
    ADJUSTMENTS_CHECK = 'adjustments-check.svg'
    ADJUSTMENTS_CODE = 'adjustments-code.svg'
    ADJUSTMENTS_COG = 'adjustments-cog.svg'
    ADJUSTMENTS_DOLLAR = 'adjustments-dollar.svg'
    ADJUSTMENTS_DOWN = 'adjustments-down.svg'
    ADJUSTMENTS_EXCLAMATION = 'adjustments-exclamation.svg'
    ADJUSTMENTS_HEART = 'adjustments-heart.svg'
    ADJUSTMENTS_HORIZONTAL = 'adjustments-horizontal.svg'
    ADJUSTMENTS_MINUS = 'adjustments-minus.svg'
    ADJUSTMENTS_OFF = 'adjustments-off.svg'
    ADJUSTMENTS_PAUSE = 'adjustments-pause.svg'
    ADJUSTMENTS_PIN = 'adjustments-pin.svg'
    ADJUSTMENTS_PLUS = 'adjustments-plus.svg'
    ADJUSTMENTS_QUESTION = 'adjustments-question.svg'
    ADJUSTMENTS_SEARCH = 'adjustments-search.svg'
    ADJUSTMENTS_SHARE = 'adjustments-share.svg'
    ADJUSTMENTS_STAR = 'adjustments-star.svg'
    ADJUSTMENTS_UP = 'adjustments-up.svg'
    ADJUSTMENTS_X = 'adjustments-x.svg'
    ADJUSTMENTS = 'adjustments.svg'
    AERIAL_LIFT = 'aerial-lift.svg'
    AFFILIATE = 'affiliate.svg'
    AIR_BALLOON = 'air-balloon.svg'
    AIR_CONDITIONING_DISABLED = 'air-conditioning-disabled.svg'
    AIR_CONDITIONING = 'air-conditioning.svg'
    AIR_TRAFFIC_CONTROL = 'air-traffic-control.svg'
    ALARM_AVERAGE = 'alarm-average.svg'
    ALARM_MINUS = 'alarm-minus.svg'
    ALARM_OFF = 'alarm-off.svg'
    ALARM_PLUS = 'alarm-plus.svg'
    ALARM_SNOOZE = 'alarm-snooze.svg'
    ALARM = 'alarm.svg'
    ALBUM_OFF = 'album-off.svg'
    ALBUM = 'album.svg'
    ALERT_CIRCLE_OFF = 'alert-circle-off.svg'
    ALERT_CIRCLE = 'alert-circle.svg'
    ALERT_HEXAGON_OFF = 'alert-hexagon-off.svg'
    ALERT_HEXAGON = 'alert-hexagon.svg'
    ALERT_OCTAGON = 'alert-octagon.svg'
    ALERT_SMALL_OFF = 'alert-small-off.svg'
    ALERT_SMALL = 'alert-small.svg'
    ALERT_SQUARE_ROUNDED_OFF = 'alert-square-rounded-off.svg'
    ALERT_SQUARE_ROUNDED = 'alert-square-rounded.svg'
    ALERT_SQUARE = 'alert-square.svg'
    ALERT_TRIANGLE_OFF = 'alert-triangle-off.svg'
    ALERT_TRIANGLE = 'alert-triangle.svg'
    ALIEN = 'alien.svg'
    ALIGN_BOX_BOTTOM_CENTER = 'align-box-bottom-center.svg'
    ALIGN_BOX_BOTTOM_LEFT = 'align-box-bottom-left.svg'
    ALIGN_BOX_BOTTOM_RIGHT = 'align-box-bottom-right.svg'
    ALIGN_BOX_CENTER_BOTTOM = 'align-box-center-bottom.svg'
    ALIGN_BOX_CENTER_MIDDLE = 'align-box-center-middle.svg'
    ALIGN_BOX_CENTER_STRETCH = 'align-box-center-stretch.svg'
    ALIGN_BOX_CENTER_TOP = 'align-box-center-top.svg'
    ALIGN_BOX_LEFT_BOTTOM = 'align-box-left-bottom.svg'
    ALIGN_BOX_LEFT_MIDDLE = 'align-box-left-middle.svg'
    ALIGN_BOX_LEFT_STRETCH = 'align-box-left-stretch.svg'
    ALIGN_BOX_LEFT_TOP = 'align-box-left-top.svg'
    ALIGN_BOX_RIGHT_BOTTOM = 'align-box-right-bottom.svg'
    ALIGN_BOX_RIGHT_MIDDLE = 'align-box-right-middle.svg'
    ALIGN_BOX_RIGHT_STRETCH = 'align-box-right-stretch.svg'
    ALIGN_BOX_RIGHT_TOP = 'align-box-right-top.svg'
    ALIGN_BOX_TOP_CENTER = 'align-box-top-center.svg'
    ALIGN_BOX_TOP_LEFT = 'align-box-top-left.svg'
    ALIGN_BOX_TOP_RIGHT = 'align-box-top-right.svg'
    ALIGN_CENTER = 'align-center.svg'
    ALIGN_JUSTIFIED = 'align-justified.svg'
    ALIGN_LEFT = 'align-left.svg'
    ALIGN_RIGHT = 'align-right.svg'
    ALPHA = 'alpha.svg'
    ALPHABET_CYRILLIC = 'alphabet-cyrillic.svg'
    ALPHABET_GREEK = 'alphabet-greek.svg'
    ALPHABET_LATIN = 'alphabet-latin.svg'
    ALT = 'alt.svg'
    AMBULANCE = 'ambulance.svg'
    AMPERSAND = 'ampersand.svg'
    ANALYZE_OFF = 'analyze-off.svg'
    ANALYZE = 'analyze.svg'
    ANCHOR_OFF = 'anchor-off.svg'
    ANCHOR = 'anchor.svg'
    ANGLE = 'angle.svg'
    ANKH = 'ankh.svg'
    ANTENNA_BARS_1 = 'antenna-bars-1.svg'
    ANTENNA_BARS_2 = 'antenna-bars-2.svg'
    ANTENNA_BARS_3 = 'antenna-bars-3.svg'
    ANTENNA_BARS_4 = 'antenna-bars-4.svg'
    ANTENNA_BARS_5 = 'antenna-bars-5.svg'
    ANTENNA_BARS_OFF = 'antenna-bars-off.svg'
    ANTENNA_OFF = 'antenna-off.svg'
    ANTENNA = 'antenna.svg'
    APERTURE_OFF = 'aperture-off.svg'
    APERTURE = 'aperture.svg'
    API_APP_OFF = 'api-app-off.svg'
    API_APP = 'api-app.svg'
    API_OFF = 'api-off.svg'
    API = 'api.svg'
    APP_WINDOW = 'app-window.svg'
    APPLE = 'apple.svg'
    APPS_OFF = 'apps-off.svg'
    APPS = 'apps.svg'
    ARCHERY_ARROW = 'archery-arrow.svg'
    ARCHIVE_OFF = 'archive-off.svg'
    ARCHIVE = 'archive.svg'
    ARMCHAIR_2_OFF = 'armchair-2-off.svg'
    ARMCHAIR_2 = 'armchair-2.svg'
    ARMCHAIR_OFF = 'armchair-off.svg'
    ARMCHAIR = 'armchair.svg'
    ARROW_AUTOFIT_CONTENT = 'arrow-autofit-content.svg'
    ARROW_AUTOFIT_DOWN = 'arrow-autofit-down.svg'
    ARROW_AUTOFIT_HEIGHT = 'arrow-autofit-height.svg'
    ARROW_AUTOFIT_LEFT = 'arrow-autofit-left.svg'
    ARROW_AUTOFIT_RIGHT = 'arrow-autofit-right.svg'
    ARROW_AUTOFIT_UP = 'arrow-autofit-up.svg'
    ARROW_AUTOFIT_WIDTH = 'arrow-autofit-width.svg'
    ARROW_BACK_UP_DOUBLE = 'arrow-back-up-double.svg'
    ARROW_BACK_UP = 'arrow-back-up.svg'
    ARROW_BACK = 'arrow-back.svg'
    ARROW_BADGE_DOWN = 'arrow-badge-down.svg'
    ARROW_BADGE_LEFT = 'arrow-badge-left.svg'
    ARROW_BADGE_RIGHT = 'arrow-badge-right.svg'
    ARROW_BADGE_UP = 'arrow-badge-up.svg'
    ARROW_BAR_BOTH = 'arrow-bar-both.svg'
    ARROW_BAR_DOWN = 'arrow-bar-down.svg'
    ARROW_BAR_LEFT = 'arrow-bar-left.svg'
    ARROW_BAR_RIGHT = 'arrow-bar-right.svg'
    ARROW_BAR_TO_DOWN = 'arrow-bar-to-down.svg'
    ARROW_BAR_TO_LEFT = 'arrow-bar-to-left.svg'
    ARROW_BAR_TO_RIGHT = 'arrow-bar-to-right.svg'
    ARROW_BAR_TO_UP = 'arrow-bar-to-up.svg'
    ARROW_BAR_UP = 'arrow-bar-up.svg'
    ARROW_BEAR_LEFT_2 = 'arrow-bear-left-2.svg'
    ARROW_BEAR_LEFT = 'arrow-bear-left.svg'
    ARROW_BEAR_RIGHT_2 = 'arrow-bear-right-2.svg'
    ARROW_BEAR_RIGHT = 'arrow-bear-right.svg'
    ARROW_BIG_DOWN_LINE = 'arrow-big-down-line.svg'
    ARROW_BIG_DOWN_LINES = 'arrow-big-down-lines.svg'
    ARROW_BIG_DOWN = 'arrow-big-down.svg'
    ARROW_BIG_LEFT_LINE = 'arrow-big-left-line.svg'
    ARROW_BIG_LEFT_LINES = 'arrow-big-left-lines.svg'
    ARROW_BIG_LEFT = 'arrow-big-left.svg'
    ARROW_BIG_RIGHT_LINE = 'arrow-big-right-line.svg'
    ARROW_BIG_RIGHT_LINES = 'arrow-big-right-lines.svg'
    ARROW_BIG_RIGHT = 'arrow-big-right.svg'
    ARROW_BIG_UP_LINE = 'arrow-big-up-line.svg'
    ARROW_BIG_UP_LINES = 'arrow-big-up-lines.svg'
    ARROW_BIG_UP = 'arrow-big-up.svg'
    ARROW_BOUNCE = 'arrow-bounce.svg'
    ARROW_CAPSULE = 'arrow-capsule.svg'
    ARROW_CURVE_LEFT = 'arrow-curve-left.svg'
    ARROW_CURVE_RIGHT = 'arrow-curve-right.svg'
    ARROW_DOWN_BAR = 'arrow-down-bar.svg'
    ARROW_DOWN_CIRCLE = 'arrow-down-circle.svg'
    ARROW_DOWN_FROM_ARC = 'arrow-down-from-arc.svg'
    ARROW_DOWN_LEFT_CIRCLE = 'arrow-down-left-circle.svg'
    ARROW_DOWN_LEFT = 'arrow-down-left.svg'
    ARROW_DOWN_RHOMBUS = 'arrow-down-rhombus.svg'
    ARROW_DOWN_RIGHT_CIRCLE = 'arrow-down-right-circle.svg'
    ARROW_DOWN_RIGHT = 'arrow-down-right.svg'
    ARROW_DOWN_SQUARE = 'arrow-down-square.svg'
    ARROW_DOWN_TAIL = 'arrow-down-tail.svg'
    ARROW_DOWN_TO_ARC = 'arrow-down-to-arc.svg'
    ARROW_DOWN = 'arrow-down.svg'
    ARROW_ELBOW_LEFT = 'arrow-elbow-left.svg'
    ARROW_ELBOW_RIGHT = 'arrow-elbow-right.svg'
    ARROW_FORK = 'arrow-fork.svg'
    ARROW_FORWARD_UP_DOUBLE = 'arrow-forward-up-double.svg'
    ARROW_FORWARD_UP = 'arrow-forward-up.svg'
    ARROW_FORWARD = 'arrow-forward.svg'
    ARROW_GUIDE = 'arrow-guide.svg'
    ARROW_ITERATION = 'arrow-iteration.svg'
    ARROW_LEFT_BAR = 'arrow-left-bar.svg'
    ARROW_LEFT_CIRCLE = 'arrow-left-circle.svg'
    ARROW_LEFT_FROM_ARC = 'arrow-left-from-arc.svg'
    ARROW_LEFT_RHOMBUS = 'arrow-left-rhombus.svg'
    ARROW_LEFT_RIGHT = 'arrow-left-right.svg'
    ARROW_LEFT_SQUARE = 'arrow-left-square.svg'
    ARROW_LEFT_TAIL = 'arrow-left-tail.svg'
    ARROW_LEFT_TO_ARC = 'arrow-left-to-arc.svg'
    ARROW_LEFT = 'arrow-left.svg'
    ARROW_LOOP_LEFT_2 = 'arrow-loop-left-2.svg'
    ARROW_LOOP_LEFT = 'arrow-loop-left.svg'
    ARROW_LOOP_RIGHT_2 = 'arrow-loop-right-2.svg'
    ARROW_LOOP_RIGHT = 'arrow-loop-right.svg'
    ARROW_MERGE_ALT_LEFT = 'arrow-merge-alt-left.svg'
    ARROW_MERGE_ALT_RIGHT = 'arrow-merge-alt-right.svg'
    ARROW_MERGE_BOTH = 'arrow-merge-both.svg'
    ARROW_MERGE_LEFT = 'arrow-merge-left.svg'
    ARROW_MERGE_RIGHT = 'arrow-merge-right.svg'
    ARROW_MERGE = 'arrow-merge.svg'
    ARROW_MOVE_DOWN = 'arrow-move-down.svg'
    ARROW_MOVE_LEFT = 'arrow-move-left.svg'
    ARROW_MOVE_RIGHT = 'arrow-move-right.svg'
    ARROW_MOVE_UP = 'arrow-move-up.svg'
    ARROW_NARROW_DOWN = 'arrow-narrow-down.svg'
    ARROW_NARROW_LEFT = 'arrow-narrow-left.svg'
    ARROW_NARROW_RIGHT = 'arrow-narrow-right.svg'
    ARROW_NARROW_UP = 'arrow-narrow-up.svg'
    ARROW_RAMP_LEFT_2 = 'arrow-ramp-left-2.svg'
    ARROW_RAMP_LEFT_3 = 'arrow-ramp-left-3.svg'
    ARROW_RAMP_LEFT = 'arrow-ramp-left.svg'
    ARROW_RAMP_RIGHT_2 = 'arrow-ramp-right-2.svg'
    ARROW_RAMP_RIGHT_3 = 'arrow-ramp-right-3.svg'
    ARROW_RAMP_RIGHT = 'arrow-ramp-right.svg'
    ARROW_RIGHT_BAR = 'arrow-right-bar.svg'
    ARROW_RIGHT_CIRCLE = 'arrow-right-circle.svg'
    ARROW_RIGHT_FROM_ARC = 'arrow-right-from-arc.svg'
    ARROW_RIGHT_RHOMBUS = 'arrow-right-rhombus.svg'
    ARROW_RIGHT_SQUARE = 'arrow-right-square.svg'
    ARROW_RIGHT_TAIL = 'arrow-right-tail.svg'
    ARROW_RIGHT_TO_ARC = 'arrow-right-to-arc.svg'
    ARROW_RIGHT = 'arrow-right.svg'
    ARROW_ROTARY_FIRST_LEFT = 'arrow-rotary-first-left.svg'
    ARROW_ROTARY_FIRST_RIGHT = 'arrow-rotary-first-right.svg'
    ARROW_ROTARY_LAST_LEFT = 'arrow-rotary-last-left.svg'
    ARROW_ROTARY_LAST_RIGHT = 'arrow-rotary-last-right.svg'
    ARROW_ROTARY_LEFT = 'arrow-rotary-left.svg'
    ARROW_ROTARY_RIGHT = 'arrow-rotary-right.svg'
    ARROW_ROTARY_STRAIGHT = 'arrow-rotary-straight.svg'
    ARROW_ROUNDABOUT_LEFT = 'arrow-roundabout-left.svg'
    ARROW_ROUNDABOUT_RIGHT = 'arrow-roundabout-right.svg'
    ARROW_SHARP_TURN_LEFT = 'arrow-sharp-turn-left.svg'
    ARROW_SHARP_TURN_RIGHT = 'arrow-sharp-turn-right.svg'
    ARROW_UP_BAR = 'arrow-up-bar.svg'
    ARROW_UP_CIRCLE = 'arrow-up-circle.svg'
    ARROW_UP_FROM_ARC = 'arrow-up-from-arc.svg'
    ARROW_UP_LEFT_CIRCLE = 'arrow-up-left-circle.svg'
    ARROW_UP_LEFT = 'arrow-up-left.svg'
    ARROW_UP_RHOMBUS = 'arrow-up-rhombus.svg'
    ARROW_UP_RIGHT_CIRCLE = 'arrow-up-right-circle.svg'
    ARROW_UP_RIGHT = 'arrow-up-right.svg'
    ARROW_UP_SQUARE = 'arrow-up-square.svg'
    ARROW_UP_TAIL = 'arrow-up-tail.svg'
    ARROW_UP_TO_ARC = 'arrow-up-to-arc.svg'
    ARROW_UP = 'arrow-up.svg'
    ARROW_WAVE_LEFT_DOWN = 'arrow-wave-left-down.svg'
    ARROW_WAVE_LEFT_UP = 'arrow-wave-left-up.svg'
    ARROW_WAVE_RIGHT_DOWN = 'arrow-wave-right-down.svg'
    ARROW_WAVE_RIGHT_UP = 'arrow-wave-right-up.svg'
    ARROW_ZIG_ZAG = 'arrow-zig-zag.svg'
    ARROWS_CROSS = 'arrows-cross.svg'
    ARROWS_DIAGONAL_2 = 'arrows-diagonal-2.svg'
    ARROWS_DIAGONAL_MINIMIZE_2 = 'arrows-diagonal-minimize-2.svg'
    ARROWS_DIAGONAL_MINIMIZE = 'arrows-diagonal-minimize.svg'
    ARROWS_DIAGONAL = 'arrows-diagonal.svg'
    ARROWS_DIFF = 'arrows-diff.svg'
    ARROWS_DOUBLE_NE_SW = 'arrows-double-ne-sw.svg'
    ARROWS_DOUBLE_NW_SE = 'arrows-double-nw-se.svg'
    ARROWS_DOUBLE_SE_NW = 'arrows-double-se-nw.svg'
    ARROWS_DOUBLE_SW_NE = 'arrows-double-sw-ne.svg'
    ARROWS_DOWN_UP = 'arrows-down-up.svg'
    ARROWS_DOWN = 'arrows-down.svg'
    ARROWS_EXCHANGE_2 = 'arrows-exchange-2.svg'
    ARROWS_EXCHANGE = 'arrows-exchange.svg'
    ARROWS_HORIZONTAL = 'arrows-horizontal.svg'
    ARROWS_JOIN_2 = 'arrows-join-2.svg'
    ARROWS_JOIN = 'arrows-join.svg'
    ARROWS_LEFT_DOWN = 'arrows-left-down.svg'
    ARROWS_LEFT_RIGHT = 'arrows-left-right.svg'
    ARROWS_LEFT = 'arrows-left.svg'
    ARROWS_MAXIMIZE = 'arrows-maximize.svg'
    ARROWS_MINIMIZE = 'arrows-minimize.svg'
    ARROWS_MOVE_HORIZONTAL = 'arrows-move-horizontal.svg'
    ARROWS_MOVE_VERTICAL = 'arrows-move-vertical.svg'
    ARROWS_MOVE = 'arrows-move.svg'
    ARROWS_RANDOM = 'arrows-random.svg'
    ARROWS_RIGHT_DOWN = 'arrows-right-down.svg'
    ARROWS_RIGHT_LEFT = 'arrows-right-left.svg'
    ARROWS_RIGHT = 'arrows-right.svg'
    ARROWS_SHUFFLE_2 = 'arrows-shuffle-2.svg'
    ARROWS_SHUFFLE = 'arrows-shuffle.svg'
    ARROWS_SORT = 'arrows-sort.svg'
    ARROWS_SPLIT_2 = 'arrows-split-2.svg'
    ARROWS_SPLIT = 'arrows-split.svg'
    ARROWS_TRANSFER_DOWN = 'arrows-transfer-down.svg'
    ARROWS_TRANSFER_UP = 'arrows-transfer-up.svg'
    ARROWS_UP_DOWN = 'arrows-up-down.svg'
    ARROWS_UP_LEFT = 'arrows-up-left.svg'
    ARROWS_UP_RIGHT = 'arrows-up-right.svg'
    ARROWS_UP = 'arrows-up.svg'
    ARROWS_VERTICAL = 'arrows-vertical.svg'
    ARTBOARD_OFF = 'artboard-off.svg'
    ARTBOARD = 'artboard.svg'
    ARTICLE_OFF = 'article-off.svg'
    ARTICLE = 'article.svg'
    ASPECT_RATIO_OFF = 'aspect-ratio-off.svg'
    ASPECT_RATIO = 'aspect-ratio.svg'
    ASSEMBLY_OFF = 'assembly-off.svg'
    ASSEMBLY = 'assembly.svg'
    ASSET = 'asset.svg'
    ASTERISK_SIMPLE = 'asterisk-simple.svg'
    ASTERISK = 'asterisk.svg'
    AT_OFF = 'at-off.svg'
    AT = 'at.svg'
    ATOM_2 = 'atom-2.svg'
    ATOM_OFF = 'atom-off.svg'
    ATOM = 'atom.svg'
    AUGMENTED_REALITY_2 = 'augmented-reality-2.svg'
    AUGMENTED_REALITY_OFF = 'augmented-reality-off.svg'
    AUGMENTED_REALITY = 'augmented-reality.svg'
    AUTH_2FA = 'auth-2fa.svg'
    AUTOMATIC_GEARBOX = 'automatic-gearbox.svg'
    AVOCADO = 'avocado.svg'
    AWARD_OFF = 'award-off.svg'
    AWARD = 'award.svg'
    AXE = 'axe.svg'
    AXIS_X = 'axis-x.svg'
    AXIS_Y = 'axis-y.svg'
    BABY_BOTTLE = 'baby-bottle.svg'
    BABY_CARRIAGE = 'baby-carriage.svg'
    BACKGROUND = 'background.svg'
    BACKHOE = 'backhoe.svg'
    BACKPACK_OFF = 'backpack-off.svg'
    BACKPACK = 'backpack.svg'
    BACKSLASH = 'backslash.svg'
    BACKSPACE = 'backspace.svg'
    BADGE_3D = 'badge-3d.svg'
    BADGE_4K = 'badge-4k.svg'
    BADGE_8K = 'badge-8k.svg'
    BADGE_AD_OFF = 'badge-ad-off.svg'
    BADGE_AD = 'badge-ad.svg'
    BADGE_AR = 'badge-ar.svg'
    BADGE_CC = 'badge-cc.svg'
    BADGE_HD = 'badge-hd.svg'
    BADGE_OFF = 'badge-off.svg'
    BADGE_SD = 'badge-sd.svg'
    BADGE_TM = 'badge-tm.svg'
    BADGE_VO = 'badge-vo.svg'
    BADGE_VR = 'badge-vr.svg'
    BADGE_WC = 'badge-wc.svg'
    BADGE = 'badge.svg'
    BADGES_OFF = 'badges-off.svg'
    BADGES = 'badges.svg'
    BAGUETTE = 'baguette.svg'
    BALL_AMERICAN_FOOTBALL_OFF = 'ball-american-football-off.svg'
    BALL_AMERICAN_FOOTBALL = 'ball-american-football.svg'
    BALL_BASEBALL = 'ball-baseball.svg'
    BALL_BASKETBALL = 'ball-basketball.svg'
    BALL_BOWLING = 'ball-bowling.svg'
    BALL_FOOTBALL_OFF = 'ball-football-off.svg'
    BALL_FOOTBALL = 'ball-football.svg'
    BALL_TENNIS = 'ball-tennis.svg'
    BALL_VOLLEYBALL = 'ball-volleyball.svg'
    BALLOON_OFF = 'balloon-off.svg'
    BALLOON = 'balloon.svg'
    BALLPEN_OFF = 'ballpen-off.svg'
    BALLPEN = 'ballpen.svg'
    BAN = 'ban.svg'
    BANDAGE_OFF = 'bandage-off.svg'
    BANDAGE = 'bandage.svg'
    BARBELL_OFF = 'barbell-off.svg'
    BARBELL = 'barbell.svg'
    BARCODE_OFF = 'barcode-off.svg'
    BARCODE = 'barcode.svg'
    BARREL_OFF = 'barrel-off.svg'
    BARREL = 'barrel.svg'
    BARRIER_BLOCK_OFF = 'barrier-block-off.svg'
    BARRIER_BLOCK = 'barrier-block.svg'
    BASELINE_DENSITY_LARGE = 'baseline-density-large.svg'
    BASELINE_DENSITY_MEDIUM = 'baseline-density-medium.svg'
    BASELINE_DENSITY_SMALL = 'baseline-density-small.svg'
    BASELINE = 'baseline.svg'
    BASKET_BOLT = 'basket-bolt.svg'
    BASKET_CANCEL = 'basket-cancel.svg'
    BASKET_CHECK = 'basket-check.svg'
    BASKET_CODE = 'basket-code.svg'
    BASKET_COG = 'basket-cog.svg'
    BASKET_DISCOUNT = 'basket-discount.svg'
    BASKET_DOLLAR = 'basket-dollar.svg'
    BASKET_DOWN = 'basket-down.svg'
    BASKET_EXCLAMATION = 'basket-exclamation.svg'
    BASKET_HEART = 'basket-heart.svg'
    BASKET_MINUS = 'basket-minus.svg'
    BASKET_OFF = 'basket-off.svg'
    BASKET_PAUSE = 'basket-pause.svg'
    BASKET_PIN = 'basket-pin.svg'
    BASKET_PLUS = 'basket-plus.svg'
    BASKET_QUESTION = 'basket-question.svg'
    BASKET_SEARCH = 'basket-search.svg'
    BASKET_SHARE = 'basket-share.svg'
    BASKET_STAR = 'basket-star.svg'
    BASKET_UP = 'basket-up.svg'
    BASKET_X = 'basket-x.svg'
    BASKET = 'basket.svg'
    BAT = 'bat.svg'
    BATH_OFF = 'bath-off.svg'
    BATH = 'bath.svg'
    BATTERY_1 = 'battery-1.svg'
    BATTERY_2 = 'battery-2.svg'
    BATTERY_3 = 'battery-3.svg'
    BATTERY_4 = 'battery-4.svg'
    BATTERY_AUTOMOTIVE = 'battery-automotive.svg'
    BATTERY_CHARGING_2 = 'battery-charging-2.svg'
    BATTERY_CHARGING = 'battery-charging.svg'
    BATTERY_ECO = 'battery-eco.svg'
    BATTERY_OFF = 'battery-off.svg'
    BATTERY = 'battery.svg'
    BEACH_OFF = 'beach-off.svg'
    BEACH = 'beach.svg'
    BED_FLAT = 'bed-flat.svg'
    BED_OFF = 'bed-off.svg'
    BED = 'bed.svg'
    BEER_OFF = 'beer-off.svg'
    BEER = 'beer.svg'
    BELL_BOLT = 'bell-bolt.svg'
    BELL_CANCEL = 'bell-cancel.svg'
    BELL_CHECK = 'bell-check.svg'
    BELL_CODE = 'bell-code.svg'
    BELL_COG = 'bell-cog.svg'
    BELL_DOLLAR = 'bell-dollar.svg'
    BELL_DOWN = 'bell-down.svg'
    BELL_EXCLAMATION = 'bell-exclamation.svg'
    BELL_HEART = 'bell-heart.svg'
    BELL_MINUS = 'bell-minus.svg'
    BELL_OFF = 'bell-off.svg'
    BELL_PAUSE = 'bell-pause.svg'
    BELL_PIN = 'bell-pin.svg'
    BELL_PLUS = 'bell-plus.svg'
    BELL_QUESTION = 'bell-question.svg'
    BELL_RINGING_2 = 'bell-ringing-2.svg'
    BELL_RINGING = 'bell-ringing.svg'
    BELL_SCHOOL = 'bell-school.svg'
    BELL_SEARCH = 'bell-search.svg'
    BELL_SHARE = 'bell-share.svg'
    BELL_STAR = 'bell-star.svg'
    BELL_UP = 'bell-up.svg'
    BELL_X = 'bell-x.svg'
    BELL_Z = 'bell-z.svg'
    BELL = 'bell.svg'
    BETA = 'beta.svg'
    BIBLE = 'bible.svg'
    BIKE_OFF = 'bike-off.svg'
    BIKE = 'bike.svg'
    BINARY_OFF = 'binary-off.svg'
    BINARY_TREE_2 = 'binary-tree-2.svg'
    BINARY_TREE = 'binary-tree.svg'
    BINARY = 'binary.svg'
    BIOHAZARD_OFF = 'biohazard-off.svg'
    BIOHAZARD = 'biohazard.svg'
    BLADE = 'blade.svg'
    BLEACH_CHLORINE = 'bleach-chlorine.svg'
    BLEACH_NO_CHLORINE = 'bleach-no-chlorine.svg'
    BLEACH_OFF = 'bleach-off.svg'
    BLEACH = 'bleach.svg'
    BLEND_MODE = 'blend-mode.svg'
    BLENDER = 'blender.svg'
    BLOB = 'blob.svg'
    BLOCKQUOTE = 'blockquote.svg'
    BLUETOOTH_CONNECTED = 'bluetooth-connected.svg'
    BLUETOOTH_OFF = 'bluetooth-off.svg'
    BLUETOOTH_X = 'bluetooth-x.svg'
    BLUETOOTH = 'bluetooth.svg'
    BLUR_OFF = 'blur-off.svg'
    BLUR = 'blur.svg'
    BMP = 'bmp.svg'
    BODY_SCAN = 'body-scan.svg'
    BOLD_OFF = 'bold-off.svg'
    BOLD = 'bold.svg'
    BOLT_OFF = 'bolt-off.svg'
    BOLT = 'bolt.svg'
    BOMB = 'bomb.svg'
    BONE_OFF = 'bone-off.svg'
    BONE = 'bone.svg'
    BONG_OFF = 'bong-off.svg'
    BONG = 'bong.svg'
    BOOK_2 = 'book-2.svg'
    BOOK_DOWNLOAD = 'book-download.svg'
    BOOK_OFF = 'book-off.svg'
    BOOK_UPLOAD = 'book-upload.svg'
    BOOK = 'book.svg'
    BOOKMARK_AI = 'bookmark-ai.svg'
    BOOKMARK_EDIT = 'bookmark-edit.svg'
    BOOKMARK_MINUS = 'bookmark-minus.svg'
    BOOKMARK_OFF = 'bookmark-off.svg'
    BOOKMARK_PLUS = 'bookmark-plus.svg'
    BOOKMARK_QUESTION = 'bookmark-question.svg'
    BOOKMARK = 'bookmark.svg'
    BOOKMARKS_OFF = 'bookmarks-off.svg'
    BOOKMARKS = 'bookmarks.svg'
    BOOKS_OFF = 'books-off.svg'
    BOOKS = 'books.svg'
    BOOM = 'boom.svg'
    BORDER_ALL = 'border-all.svg'
    BORDER_BOTTOM_PLUS = 'border-bottom-plus.svg'
    BORDER_BOTTOM = 'border-bottom.svg'
    BORDER_CORNER_IOS = 'border-corner-ios.svg'
    BORDER_CORNER_PILL = 'border-corner-pill.svg'
    BORDER_CORNER_ROUNDED = 'border-corner-rounded.svg'
    BORDER_CORNER_SQUARE = 'border-corner-square.svg'
    BORDER_CORNERS = 'border-corners.svg'
    BORDER_HORIZONTAL = 'border-horizontal.svg'
    BORDER_INNER = 'border-inner.svg'
    BORDER_LEFT_PLUS = 'border-left-plus.svg'
    BORDER_LEFT = 'border-left.svg'
    BORDER_NONE = 'border-none.svg'
    BORDER_OUTER = 'border-outer.svg'
    BORDER_RADIUS = 'border-radius.svg'
    BORDER_RIGHT_PLUS = 'border-right-plus.svg'
    BORDER_RIGHT = 'border-right.svg'
    BORDER_SIDES = 'border-sides.svg'
    BORDER_STYLE_2 = 'border-style-2.svg'
    BORDER_STYLE = 'border-style.svg'
    BORDER_TOP_PLUS = 'border-top-plus.svg'
    BORDER_TOP = 'border-top.svg'
    BORDER_VERTICAL = 'border-vertical.svg'
    BOTTLE_OFF = 'bottle-off.svg'
    BOTTLE = 'bottle.svg'
    BOUNCE_LEFT = 'bounce-left.svg'
    BOUNCE_RIGHT = 'bounce-right.svg'
    BOW = 'bow.svg'
    BOWL_CHOPSTICKS = 'bowl-chopsticks.svg'
    BOWL_SPOON = 'bowl-spoon.svg'
    BOWL = 'bowl.svg'
    BOX_ALIGN_BOTTOM_LEFT = 'box-align-bottom-left.svg'
    BOX_ALIGN_BOTTOM_RIGHT = 'box-align-bottom-right.svg'
    BOX_ALIGN_BOTTOM = 'box-align-bottom.svg'
    BOX_ALIGN_LEFT = 'box-align-left.svg'
    BOX_ALIGN_RIGHT = 'box-align-right.svg'
    BOX_ALIGN_TOP_LEFT = 'box-align-top-left.svg'
    BOX_ALIGN_TOP_RIGHT = 'box-align-top-right.svg'
    BOX_ALIGN_TOP = 'box-align-top.svg'
    BOX_MARGIN = 'box-margin.svg'
    BOX_MODEL_2_OFF = 'box-model-2-off.svg'
    BOX_MODEL_2 = 'box-model-2.svg'
    BOX_MODEL_OFF = 'box-model-off.svg'
    BOX_MODEL = 'box-model.svg'
    BOX_MULTIPLE_0 = 'box-multiple-0.svg'
    BOX_MULTIPLE_1 = 'box-multiple-1.svg'
    BOX_MULTIPLE_2 = 'box-multiple-2.svg'
    BOX_MULTIPLE_3 = 'box-multiple-3.svg'
    BOX_MULTIPLE_4 = 'box-multiple-4.svg'
    BOX_MULTIPLE_5 = 'box-multiple-5.svg'
    BOX_MULTIPLE_6 = 'box-multiple-6.svg'
    BOX_MULTIPLE_7 = 'box-multiple-7.svg'
    BOX_MULTIPLE_8 = 'box-multiple-8.svg'
    BOX_MULTIPLE_9 = 'box-multiple-9.svg'
    BOX_MULTIPLE = 'box-multiple.svg'
    BOX_OFF = 'box-off.svg'
    BOX_PADDING = 'box-padding.svg'
    BOX = 'box.svg'
    BRACES_OFF = 'braces-off.svg'
    BRACES = 'braces.svg'
    BRACKETS_ANGLE_OFF = 'brackets-angle-off.svg'
    BRACKETS_ANGLE = 'brackets-angle.svg'
    BRACKETS_CONTAIN_END = 'brackets-contain-end.svg'
    BRACKETS_CONTAIN_START = 'brackets-contain-start.svg'
    BRACKETS_CONTAIN = 'brackets-contain.svg'
    BRACKETS_OFF = 'brackets-off.svg'
    BRACKETS = 'brackets.svg'
    BRAILLE = 'braille.svg'
    BRAIN = 'brain.svg'
    BRAND_4CHAN = 'brand-4chan.svg'
    BRAND_ABSTRACT = 'brand-abstract.svg'
    BRAND_ADOBE = 'brand-adobe.svg'
    BRAND_ADONIS_JS = 'brand-adonis-js.svg'
    BRAND_AIRBNB = 'brand-airbnb.svg'
    BRAND_AIRTABLE = 'brand-airtable.svg'
    BRAND_ALGOLIA = 'brand-algolia.svg'
    BRAND_ALIPAY = 'brand-alipay.svg'
    BRAND_ALPINE_JS = 'brand-alpine-js.svg'
    BRAND_AMAZON = 'brand-amazon.svg'
    BRAND_AMD = 'brand-amd.svg'
    BRAND_AMIGO = 'brand-amigo.svg'
    BRAND_AMONG_US = 'brand-among-us.svg'
    BRAND_ANDROID = 'brand-android.svg'
    BRAND_ANGULAR = 'brand-angular.svg'
    BRAND_ANSIBLE = 'brand-ansible.svg'
    BRAND_AO3 = 'brand-ao3.svg'
    BRAND_APPGALLERY = 'brand-appgallery.svg'
    BRAND_APPLE_ARCADE = 'brand-apple-arcade.svg'
    BRAND_APPLE_PODCAST = 'brand-apple-podcast.svg'
    BRAND_APPLE = 'brand-apple.svg'
    BRAND_APPSTORE = 'brand-appstore.svg'
    BRAND_ARC = 'brand-arc.svg'
    BRAND_ASANA = 'brand-asana.svg'
    BRAND_ASTRO = 'brand-astro.svg'
    BRAND_AUTH0 = 'brand-auth0.svg'
    BRAND_AWS = 'brand-aws.svg'
    BRAND_AZURE = 'brand-azure.svg'
    BRAND_BACKBONE = 'brand-backbone.svg'
    BRAND_BADOO = 'brand-badoo.svg'
    BRAND_BAIDU = 'brand-baidu.svg'
    BRAND_BANDCAMP = 'brand-bandcamp.svg'
    BRAND_BANDLAB = 'brand-bandlab.svg'
    BRAND_BEATS = 'brand-beats.svg'
    BRAND_BEHANCE = 'brand-behance.svg'
    BRAND_BILIBILI = 'brand-bilibili.svg'
    BRAND_BINANCE = 'brand-binance.svg'
    BRAND_BING = 'brand-bing.svg'
    BRAND_BITBUCKET = 'brand-bitbucket.svg'
    BRAND_BLACKBERRY = 'brand-blackberry.svg'
    BRAND_BLENDER = 'brand-blender.svg'
    BRAND_BLOGGER = 'brand-blogger.svg'
    BRAND_BLUESKY = 'brand-bluesky.svg'
    BRAND_BOOKING = 'brand-booking.svg'
    BRAND_BOOTSTRAP = 'brand-bootstrap.svg'
    BRAND_BULMA = 'brand-bulma.svg'
    BRAND_BUMBLE = 'brand-bumble.svg'
    BRAND_BUNPO = 'brand-bunpo.svg'
    BRAND_C_SHARP = 'brand-c-sharp.svg'
    BRAND_CAKE = 'brand-cake.svg'
    BRAND_CAKEPHP = 'brand-cakephp.svg'
    BRAND_CAMPAIGNMONITOR = 'brand-campaignmonitor.svg'
    BRAND_CARBON = 'brand-carbon.svg'
    BRAND_CASHAPP = 'brand-cashapp.svg'
    BRAND_CHROME = 'brand-chrome.svg'
    BRAND_CINEMA_4D = 'brand-cinema-4d.svg'
    BRAND_CITYMAPPER = 'brand-citymapper.svg'
    BRAND_CLOUDFLARE = 'brand-cloudflare.svg'
    BRAND_CODECOV = 'brand-codecov.svg'
    BRAND_CODEPEN = 'brand-codepen.svg'
    BRAND_CODESANDBOX = 'brand-codesandbox.svg'
    BRAND_COHOST = 'brand-cohost.svg'
    BRAND_COINBASE = 'brand-coinbase.svg'
    BRAND_COMEDY_CENTRAL = 'brand-comedy-central.svg'
    BRAND_COREOS = 'brand-coreos.svg'
    BRAND_COUCHDB = 'brand-couchdb.svg'
    BRAND_COUCHSURFING = 'brand-couchsurfing.svg'
    BRAND_CPP = 'brand-cpp.svg'
    BRAND_CRAFT = 'brand-craft.svg'
    BRAND_CRUNCHBASE = 'brand-crunchbase.svg'
    BRAND_CSS3 = 'brand-css3.svg'
    BRAND_CTEMPLAR = 'brand-ctemplar.svg'
    BRAND_CUCUMBER = 'brand-cucumber.svg'
    BRAND_CUPRA = 'brand-cupra.svg'
    BRAND_CYPRESS = 'brand-cypress.svg'
    BRAND_D3 = 'brand-d3.svg'
    BRAND_DATABRICKS = 'brand-databricks.svg'
    BRAND_DAYS_COUNTER = 'brand-days-counter.svg'
    BRAND_DCOS = 'brand-dcos.svg'
    BRAND_DEBIAN = 'brand-debian.svg'
    BRAND_DEEZER = 'brand-deezer.svg'
    BRAND_DELIVEROO = 'brand-deliveroo.svg'
    BRAND_DENO = 'brand-deno.svg'
    BRAND_DENODO = 'brand-denodo.svg'
    BRAND_DEVIANTART = 'brand-deviantart.svg'
    BRAND_DIGG = 'brand-digg.svg'
    BRAND_DINGTALK = 'brand-dingtalk.svg'
    BRAND_DISCORD = 'brand-discord.svg'
    BRAND_DISNEY = 'brand-disney.svg'
    BRAND_DISQUS = 'brand-disqus.svg'
    BRAND_DJANGO = 'brand-django.svg'
    BRAND_DOCKER = 'brand-docker.svg'
    BRAND_DOCTRINE = 'brand-doctrine.svg'
    BRAND_DOLBY_DIGITAL = 'brand-dolby-digital.svg'
    BRAND_DOUBAN = 'brand-douban.svg'
    BRAND_DRIBBBLE = 'brand-dribbble.svg'
    BRAND_DROPS = 'brand-drops.svg'
    BRAND_DRUPAL = 'brand-drupal.svg'
    BRAND_EDGE = 'brand-edge.svg'
    BRAND_ELASTIC = 'brand-elastic.svg'
    BRAND_ELECTRONIC_ARTS = 'brand-electronic-arts.svg'
    BRAND_EMBER = 'brand-ember.svg'
    BRAND_ENVATO = 'brand-envato.svg'
    BRAND_ETSY = 'brand-etsy.svg'
    BRAND_EVERNOTE = 'brand-evernote.svg'
    BRAND_FACEBOOK = 'brand-facebook.svg'
    BRAND_FEEDLY = 'brand-feedly.svg'
    BRAND_FIGMA = 'brand-figma.svg'
    BRAND_FILEZILLA = 'brand-filezilla.svg'
    BRAND_FINDER = 'brand-finder.svg'
    BRAND_FIREBASE = 'brand-firebase.svg'
    BRAND_FIREFOX = 'brand-firefox.svg'
    BRAND_FIVERR = 'brand-fiverr.svg'
    BRAND_FLICKR = 'brand-flickr.svg'
    BRAND_FLIGHTRADAR24 = 'brand-flightradar24.svg'
    BRAND_FLIPBOARD = 'brand-flipboard.svg'
    BRAND_FLUTTER = 'brand-flutter.svg'
    BRAND_FORTNITE = 'brand-fortnite.svg'
    BRAND_FOURSQUARE = 'brand-foursquare.svg'
    BRAND_FRAMER_MOTION = 'brand-framer-motion.svg'
    BRAND_FRAMER = 'brand-framer.svg'
    BRAND_FUNIMATION = 'brand-funimation.svg'
    BRAND_GATSBY = 'brand-gatsby.svg'
    BRAND_GIT = 'brand-git.svg'
    BRAND_GITHUB_COPILOT = 'brand-github-copilot.svg'
    BRAND_GITHUB = 'brand-github.svg'
    BRAND_GITLAB = 'brand-gitlab.svg'
    BRAND_GMAIL = 'brand-gmail.svg'
    BRAND_GOLANG = 'brand-golang.svg'
    BRAND_GOOGLE_ANALYTICS = 'brand-google-analytics.svg'
    BRAND_GOOGLE_BIG_QUERY = 'brand-google-big-query.svg'
    BRAND_GOOGLE_DRIVE = 'brand-google-drive.svg'
    BRAND_GOOGLE_FIT = 'brand-google-fit.svg'
    BRAND_GOOGLE_HOME = 'brand-google-home.svg'
    BRAND_GOOGLE_MAPS = 'brand-google-maps.svg'
    BRAND_GOOGLE_ONE = 'brand-google-one.svg'
    BRAND_GOOGLE_PHOTOS = 'brand-google-photos.svg'
    BRAND_GOOGLE_PLAY = 'brand-google-play.svg'
    BRAND_GOOGLE_PODCASTS = 'brand-google-podcasts.svg'
    BRAND_GOOGLE = 'brand-google.svg'
    BRAND_GRAMMARLY = 'brand-grammarly.svg'
    BRAND_GRAPHQL = 'brand-graphql.svg'
    BRAND_GRAVATAR = 'brand-gravatar.svg'
    BRAND_GRINDR = 'brand-grindr.svg'
    BRAND_GUARDIAN = 'brand-guardian.svg'
    BRAND_GUMROAD = 'brand-gumroad.svg'
    BRAND_HBO = 'brand-hbo.svg'
    BRAND_HEADLESSUI = 'brand-headlessui.svg'
    BRAND_HEXO = 'brand-hexo.svg'
    BRAND_HIPCHAT = 'brand-hipchat.svg'
    BRAND_HTML5 = 'brand-html5.svg'
    BRAND_INERTIA = 'brand-inertia.svg'
    BRAND_INSTAGRAM = 'brand-instagram.svg'
    BRAND_INTERCOM = 'brand-intercom.svg'
    BRAND_ITCH = 'brand-itch.svg'
    BRAND_JAVASCRIPT = 'brand-javascript.svg'
    BRAND_JUEJIN = 'brand-juejin.svg'
    BRAND_KAKO_TALK = 'brand-kako-talk.svg'
    BRAND_KBIN = 'brand-kbin.svg'
    BRAND_KICK = 'brand-kick.svg'
    BRAND_KICKSTARTER = 'brand-kickstarter.svg'
    BRAND_KOTLIN = 'brand-kotlin.svg'
    BRAND_LARAVEL = 'brand-laravel.svg'
    BRAND_LASTFM = 'brand-lastfm.svg'
    BRAND_LEETCODE = 'brand-leetcode.svg'
    BRAND_LETTERBOXD = 'brand-letterboxd.svg'
    BRAND_LINE = 'brand-line.svg'
    BRAND_LINKEDIN = 'brand-linkedin.svg'
    BRAND_LINKTREE = 'brand-linktree.svg'
    BRAND_LINQPAD = 'brand-linqpad.svg'
    BRAND_LIVEWIRE = 'brand-livewire.svg'
    BRAND_LOOM = 'brand-loom.svg'
    BRAND_MAILGUN = 'brand-mailgun.svg'
    BRAND_MANTINE = 'brand-mantine.svg'
    BRAND_MASTERCARD = 'brand-mastercard.svg'
    BRAND_MASTODON = 'brand-mastodon.svg'
    BRAND_MATRIX = 'brand-matrix.svg'
    BRAND_MCDONALDS = 'brand-mcdonalds.svg'
    BRAND_MEDIUM = 'brand-medium.svg'
    BRAND_MEETUP = 'brand-meetup.svg'
    BRAND_MERCEDES = 'brand-mercedes.svg'
    BRAND_MESSENGER = 'brand-messenger.svg'
    BRAND_META = 'brand-meta.svg'
    BRAND_MINECRAFT = 'brand-minecraft.svg'
    BRAND_MINIPROGRAM = 'brand-miniprogram.svg'
    BRAND_MIXPANEL = 'brand-mixpanel.svg'
    BRAND_MONDAY = 'brand-monday.svg'
    BRAND_MONGODB = 'brand-mongodb.svg'
    BRAND_MY_OPPO = 'brand-my-oppo.svg'
    BRAND_MYSQL = 'brand-mysql.svg'
    BRAND_NATIONAL_GEOGRAPHIC = 'brand-national-geographic.svg'
    BRAND_NEM = 'brand-nem.svg'
    BRAND_NETBEANS = 'brand-netbeans.svg'
    BRAND_NETEASE_MUSIC = 'brand-netease-music.svg'
    BRAND_NETFLIX = 'brand-netflix.svg'
    BRAND_NEXO = 'brand-nexo.svg'
    BRAND_NEXTCLOUD = 'brand-nextcloud.svg'
    BRAND_NEXTJS = 'brand-nextjs.svg'
    BRAND_NODEJS = 'brand-nodejs.svg'
    BRAND_NORD_VPN = 'brand-nord-vpn.svg'
    BRAND_NOTION = 'brand-notion.svg'
    BRAND_NPM = 'brand-npm.svg'
    BRAND_NUXT = 'brand-nuxt.svg'
    BRAND_NYTIMES = 'brand-nytimes.svg'
    BRAND_OAUTH = 'brand-oauth.svg'
    BRAND_OFFICE = 'brand-office.svg'
    BRAND_OK_RU = 'brand-ok-ru.svg'
    BRAND_ONEDRIVE = 'brand-onedrive.svg'
    BRAND_ONLYFANS = 'brand-onlyfans.svg'
    BRAND_OPEN_SOURCE = 'brand-open-source.svg'
    BRAND_OPENAI = 'brand-openai.svg'
    BRAND_OPENVPN = 'brand-openvpn.svg'
    BRAND_OPERA = 'brand-opera.svg'
    BRAND_PAGEKIT = 'brand-pagekit.svg'
    BRAND_PARSINTA = 'brand-parsinta.svg'
    BRAND_PATREON = 'brand-patreon.svg'
    BRAND_PAYPAL = 'brand-paypal.svg'
    BRAND_PAYPAY = 'brand-paypay.svg'
    BRAND_PEANUT = 'brand-peanut.svg'
    BRAND_PEPSI = 'brand-pepsi.svg'
    BRAND_PHP = 'brand-php.svg'
    BRAND_PICSART = 'brand-picsart.svg'
    BRAND_PINTEREST = 'brand-pinterest.svg'
    BRAND_PLANETSCALE = 'brand-planetscale.svg'
    BRAND_PNPM = 'brand-pnpm.svg'
    BRAND_POCKET = 'brand-pocket.svg'
    BRAND_POLYMER = 'brand-polymer.svg'
    BRAND_POWERSHELL = 'brand-powershell.svg'
    BRAND_PRINTABLES = 'brand-printables.svg'
    BRAND_PRISMA = 'brand-prisma.svg'
    BRAND_PRODUCTHUNT = 'brand-producthunt.svg'
    BRAND_PUSHBULLET = 'brand-pushbullet.svg'
    BRAND_PUSHOVER = 'brand-pushover.svg'
    BRAND_PYTHON = 'brand-python.svg'
    BRAND_QQ = 'brand-qq.svg'
    BRAND_RADIX_UI = 'brand-radix-ui.svg'
    BRAND_REACT_NATIVE = 'brand-react-native.svg'
    BRAND_REACT = 'brand-react.svg'
    BRAND_REASON = 'brand-reason.svg'
    BRAND_REDDIT = 'brand-reddit.svg'
    BRAND_REDHAT = 'brand-redhat.svg'
    BRAND_REDUX = 'brand-redux.svg'
    BRAND_REVOLUT = 'brand-revolut.svg'
    BRAND_RUMBLE = 'brand-rumble.svg'
    BRAND_RUST = 'brand-rust.svg'
    BRAND_SAFARI = 'brand-safari.svg'
    BRAND_SAMSUNGPASS = 'brand-samsungpass.svg'
    BRAND_SASS = 'brand-sass.svg'
    BRAND_SENTRY = 'brand-sentry.svg'
    BRAND_SHARIK = 'brand-sharik.svg'
    BRAND_SHAZAM = 'brand-shazam.svg'
    BRAND_SHOPEE = 'brand-shopee.svg'
    BRAND_SKETCH = 'brand-sketch.svg'
    BRAND_SKYPE = 'brand-skype.svg'
    BRAND_SLACK = 'brand-slack.svg'
    BRAND_SNAPCHAT = 'brand-snapchat.svg'
    BRAND_SNAPSEED = 'brand-snapseed.svg'
    BRAND_SNOWFLAKE = 'brand-snowflake.svg'
    BRAND_SOCKET_IO = 'brand-socket-io.svg'
    BRAND_SOLIDJS = 'brand-solidjs.svg'
    BRAND_SOUNDCLOUD = 'brand-soundcloud.svg'
    BRAND_SPACEHEY = 'brand-spacehey.svg'
    BRAND_SPEEDTEST = 'brand-speedtest.svg'
    BRAND_SPOTIFY = 'brand-spotify.svg'
    BRAND_STACKOVERFLOW = 'brand-stackoverflow.svg'
    BRAND_STACKSHARE = 'brand-stackshare.svg'
    BRAND_STEAM = 'brand-steam.svg'
    BRAND_STOCKTWITS = 'brand-stocktwits.svg'
    BRAND_STORJ = 'brand-storj.svg'
    BRAND_STORYBOOK = 'brand-storybook.svg'
    BRAND_STORYTEL = 'brand-storytel.svg'
    BRAND_STRAVA = 'brand-strava.svg'
    BRAND_STRIPE = 'brand-stripe.svg'
    BRAND_SUBLIME_TEXT = 'brand-sublime-text.svg'
    BRAND_SUGARIZER = 'brand-sugarizer.svg'
    BRAND_SUPABASE = 'brand-supabase.svg'
    BRAND_SUPERHUMAN = 'brand-superhuman.svg'
    BRAND_SUPERNOVA = 'brand-supernova.svg'
    BRAND_SURFSHARK = 'brand-surfshark.svg'
    BRAND_SVELTE = 'brand-svelte.svg'
    BRAND_SWIFT = 'brand-swift.svg'
    BRAND_SYMFONY = 'brand-symfony.svg'
    BRAND_TABLER = 'brand-tabler.svg'
    BRAND_TAILWIND = 'brand-tailwind.svg'
    BRAND_TAOBAO = 'brand-taobao.svg'
    BRAND_TEAMS = 'brand-teams.svg'
    BRAND_TED = 'brand-ted.svg'
    BRAND_TELEGRAM = 'brand-telegram.svg'
    BRAND_TERRAFORM = 'brand-terraform.svg'
    BRAND_TETHER = 'brand-tether.svg'
    BRAND_THINGIVERSE = 'brand-thingiverse.svg'
    BRAND_THREADS = 'brand-threads.svg'
    BRAND_THREEJS = 'brand-threejs.svg'
    BRAND_TIDAL = 'brand-tidal.svg'
    BRAND_TIKTOK = 'brand-tiktok.svg'
    BRAND_TINDER = 'brand-tinder.svg'
    BRAND_TOPBUZZ = 'brand-topbuzz.svg'
    BRAND_TORCHAIN = 'brand-torchain.svg'
    BRAND_TOYOTA = 'brand-toyota.svg'
    BRAND_TRELLO = 'brand-trello.svg'
    BRAND_TRIPADVISOR = 'brand-tripadvisor.svg'
    BRAND_TUMBLR = 'brand-tumblr.svg'
    BRAND_TWILIO = 'brand-twilio.svg'
    BRAND_TWITCH = 'brand-twitch.svg'
    BRAND_TWITTER = 'brand-twitter.svg'
    BRAND_TYPESCRIPT = 'brand-typescript.svg'
    BRAND_UBER = 'brand-uber.svg'
    BRAND_UBUNTU = 'brand-ubuntu.svg'
    BRAND_UNITY = 'brand-unity.svg'
    BRAND_UNSPLASH = 'brand-unsplash.svg'
    BRAND_UPWORK = 'brand-upwork.svg'
    BRAND_VALORANT = 'brand-valorant.svg'
    BRAND_VERCEL = 'brand-vercel.svg'
    BRAND_VIMEO = 'brand-vimeo.svg'
    BRAND_VINTED = 'brand-vinted.svg'
    BRAND_VISA = 'brand-visa.svg'
    BRAND_VISUAL_STUDIO = 'brand-visual-studio.svg'
    BRAND_VITE = 'brand-vite.svg'
    BRAND_VIVALDI = 'brand-vivaldi.svg'
    BRAND_VK = 'brand-vk.svg'
    BRAND_VLC = 'brand-vlc.svg'
    BRAND_VOLKSWAGEN = 'brand-volkswagen.svg'
    BRAND_VSCO = 'brand-vsco.svg'
    BRAND_VSCODE = 'brand-vscode.svg'
    BRAND_VUE = 'brand-vue.svg'
    BRAND_WALMART = 'brand-walmart.svg'
    BRAND_WAZE = 'brand-waze.svg'
    BRAND_WEBFLOW = 'brand-webflow.svg'
    BRAND_WECHAT = 'brand-wechat.svg'
    BRAND_WEIBO = 'brand-weibo.svg'
    BRAND_WHATSAPP = 'brand-whatsapp.svg'
    BRAND_WIKIPEDIA = 'brand-wikipedia.svg'
    BRAND_WINDOWS = 'brand-windows.svg'
    BRAND_WINDY = 'brand-windy.svg'
    BRAND_WISH = 'brand-wish.svg'
    BRAND_WIX = 'brand-wix.svg'
    BRAND_WORDPRESS = 'brand-wordpress.svg'
    BRAND_X = 'brand-x.svg'
    BRAND_XAMARIN = 'brand-xamarin.svg'
    BRAND_XBOX = 'brand-xbox.svg'
    BRAND_XDEEP = 'brand-xdeep.svg'
    BRAND_XING = 'brand-xing.svg'
    BRAND_YAHOO = 'brand-yahoo.svg'
    BRAND_YANDEX = 'brand-yandex.svg'
    BRAND_YARN = 'brand-yarn.svg'
    BRAND_YATSE = 'brand-yatse.svg'
    BRAND_YCOMBINATOR = 'brand-ycombinator.svg'
    BRAND_YOUTUBE_KIDS = 'brand-youtube-kids.svg'
    BRAND_YOUTUBE = 'brand-youtube.svg'
    BRAND_ZALANDO = 'brand-zalando.svg'
    BRAND_ZAPIER = 'brand-zapier.svg'
    BRAND_ZEIT = 'brand-zeit.svg'
    BRAND_ZHIHU = 'brand-zhihu.svg'
    BRAND_ZOOM = 'brand-zoom.svg'
    BRAND_ZULIP = 'brand-zulip.svg'
    BRAND_ZWIFT = 'brand-zwift.svg'
    BREAD_OFF = 'bread-off.svg'
    BREAD = 'bread.svg'
    BRIEFCASE_2 = 'briefcase-2.svg'
    BRIEFCASE_OFF = 'briefcase-off.svg'
    BRIEFCASE = 'briefcase.svg'
    BRIGHTNESS_2 = 'brightness-2.svg'
    BRIGHTNESS_AUTO = 'brightness-auto.svg'
    BRIGHTNESS_DOWN = 'brightness-down.svg'
    BRIGHTNESS_HALF = 'brightness-half.svg'
    BRIGHTNESS_OFF = 'brightness-off.svg'
    BRIGHTNESS_UP = 'brightness-up.svg'
    BRIGHTNESS = 'brightness.svg'
    BROADCAST_OFF = 'broadcast-off.svg'
    BROADCAST = 'broadcast.svg'
    BROWSER_CHECK = 'browser-check.svg'
    BROWSER_OFF = 'browser-off.svg'
    BROWSER_PLUS = 'browser-plus.svg'
    BROWSER_X = 'browser-x.svg'
    BROWSER = 'browser.svg'
    BRUSH_OFF = 'brush-off.svg'
    BRUSH = 'brush.svg'
    BUBBLE_MINUS = 'bubble-minus.svg'
    BUBBLE_PLUS = 'bubble-plus.svg'
    BUBBLE_TEXT = 'bubble-text.svg'
    BUBBLE_X = 'bubble-x.svg'
    BUBBLE = 'bubble.svg'
    BUCKET_DROPLET = 'bucket-droplet.svg'
    BUCKET_OFF = 'bucket-off.svg'
    BUCKET = 'bucket.svg'
    BUG_OFF = 'bug-off.svg'
    BUG = 'bug.svg'
    BUILDING_ARCH = 'building-arch.svg'
    BUILDING_BANK = 'building-bank.svg'
    BUILDING_BRIDGE_2 = 'building-bridge-2.svg'
    BUILDING_BRIDGE = 'building-bridge.svg'
    BUILDING_BROADCAST_TOWER = 'building-broadcast-tower.svg'
    BUILDING_CAROUSEL = 'building-carousel.svg'
    BUILDING_CASTLE = 'building-castle.svg'
    BUILDING_CHURCH = 'building-church.svg'
    BUILDING_CIRCUS = 'building-circus.svg'
    BUILDING_COMMUNITY = 'building-community.svg'
    BUILDING_COTTAGE = 'building-cottage.svg'
    BUILDING_ESTATE = 'building-estate.svg'
    BUILDING_FACTORY_2 = 'building-factory-2.svg'
    BUILDING_FACTORY = 'building-factory.svg'
    BUILDING_FORTRESS = 'building-fortress.svg'
    BUILDING_HOSPITAL = 'building-hospital.svg'
    BUILDING_LIGHTHOUSE = 'building-lighthouse.svg'
    BUILDING_MONUMENT = 'building-monument.svg'
    BUILDING_MOSQUE = 'building-mosque.svg'
    BUILDING_PAVILION = 'building-pavilion.svg'
    BUILDING_SKYSCRAPER = 'building-skyscraper.svg'
    BUILDING_STADIUM = 'building-stadium.svg'
    BUILDING_STORE = 'building-store.svg'
    BUILDING_TUNNEL = 'building-tunnel.svg'
    BUILDING_WAREHOUSE = 'building-warehouse.svg'
    BUILDING_WIND_TURBINE = 'building-wind-turbine.svg'
    BUILDING = 'building.svg'
    BULB_OFF = 'bulb-off.svg'
    BULB = 'bulb.svg'
    BULLDOZER = 'bulldozer.svg'
    BURGER = 'burger.svg'
    BUS_OFF = 'bus-off.svg'
    BUS_STOP = 'bus-stop.svg'
    BUS = 'bus.svg'
    BUSINESSPLAN = 'businessplan.svg'
    BUTTERFLY = 'butterfly.svg'
    CACTUS_OFF = 'cactus-off.svg'
    CACTUS = 'cactus.svg'
    CAKE_OFF = 'cake-off.svg'
    CAKE = 'cake.svg'
    CALCULATOR_OFF = 'calculator-off.svg'
    CALCULATOR = 'calculator.svg'
    CALENDAR_BOLT = 'calendar-bolt.svg'
    CALENDAR_CANCEL = 'calendar-cancel.svg'
    CALENDAR_CHECK = 'calendar-check.svg'
    CALENDAR_CLOCK = 'calendar-clock.svg'
    CALENDAR_CODE = 'calendar-code.svg'
    CALENDAR_COG = 'calendar-cog.svg'
    CALENDAR_DOLLAR = 'calendar-dollar.svg'
    CALENDAR_DOT = 'calendar-dot.svg'
    CALENDAR_DOWN = 'calendar-down.svg'
    CALENDAR_DUE = 'calendar-due.svg'
    CALENDAR_EVENT = 'calendar-event.svg'
    CALENDAR_EXCLAMATION = 'calendar-exclamation.svg'
    CALENDAR_HEART = 'calendar-heart.svg'
    CALENDAR_MINUS = 'calendar-minus.svg'
    CALENDAR_MONTH = 'calendar-month.svg'
    CALENDAR_OFF = 'calendar-off.svg'
    CALENDAR_PAUSE = 'calendar-pause.svg'
    CALENDAR_PIN = 'calendar-pin.svg'
    CALENDAR_PLUS = 'calendar-plus.svg'
    CALENDAR_QUESTION = 'calendar-question.svg'
    CALENDAR_REPEAT = 'calendar-repeat.svg'
    CALENDAR_SAD = 'calendar-sad.svg'
    CALENDAR_SEARCH = 'calendar-search.svg'
    CALENDAR_SHARE = 'calendar-share.svg'
    CALENDAR_SMILE = 'calendar-smile.svg'
    CALENDAR_STAR = 'calendar-star.svg'
    CALENDAR_STATS = 'calendar-stats.svg'
    CALENDAR_TIME = 'calendar-time.svg'
    CALENDAR_UP = 'calendar-up.svg'
    CALENDAR_USER = 'calendar-user.svg'
    CALENDAR_WEEK = 'calendar-week.svg'
    CALENDAR_X = 'calendar-x.svg'
    CALENDAR = 'calendar.svg'
    CAMERA_BOLT = 'camera-bolt.svg'
    CAMERA_CANCEL = 'camera-cancel.svg'
    CAMERA_CHECK = 'camera-check.svg'
    CAMERA_CODE = 'camera-code.svg'
    CAMERA_COG = 'camera-cog.svg'
    CAMERA_DOLLAR = 'camera-dollar.svg'
    CAMERA_DOWN = 'camera-down.svg'
    CAMERA_EXCLAMATION = 'camera-exclamation.svg'
    CAMERA_HEART = 'camera-heart.svg'
    CAMERA_MINUS = 'camera-minus.svg'
    CAMERA_OFF = 'camera-off.svg'
    CAMERA_PAUSE = 'camera-pause.svg'
    CAMERA_PIN = 'camera-pin.svg'
    CAMERA_PLUS = 'camera-plus.svg'
    CAMERA_QUESTION = 'camera-question.svg'
    CAMERA_ROTATE = 'camera-rotate.svg'
    CAMERA_SEARCH = 'camera-search.svg'
    CAMERA_SELFIE = 'camera-selfie.svg'
    CAMERA_SHARE = 'camera-share.svg'
    CAMERA_STAR = 'camera-star.svg'
    CAMERA_UP = 'camera-up.svg'
    CAMERA_X = 'camera-x.svg'
    CAMERA = 'camera.svg'
    CAMPER = 'camper.svg'
    CAMPFIRE = 'campfire.svg'
    CANDLE = 'candle.svg'
    CANDY_OFF = 'candy-off.svg'
    CANDY = 'candy.svg'
    CANE = 'cane.svg'
    CANNABIS = 'cannabis.svg'
    CAPSULE_HORIZONTAL = 'capsule-horizontal.svg'
    CAPSULE = 'capsule.svg'
    CAPTURE_OFF = 'capture-off.svg'
    CAPTURE = 'capture.svg'
    CAR_4WD = 'car-4wd.svg'
    CAR_CRANE = 'car-crane.svg'
    CAR_CRASH = 'car-crash.svg'
    CAR_FAN_1 = 'car-fan-1.svg'
    CAR_FAN_2 = 'car-fan-2.svg'
    CAR_FAN_3 = 'car-fan-3.svg'
    CAR_FAN_AUTO = 'car-fan-auto.svg'
    CAR_FAN = 'car-fan.svg'
    CAR_GARAGE = 'car-garage.svg'
    CAR_OFF = 'car-off.svg'
    CAR_SUV = 'car-suv.svg'
    CAR_TURBINE = 'car-turbine.svg'
    CAR = 'car.svg'
    CARAMBOLA = 'carambola.svg'
    CARAVAN = 'caravan.svg'
    CARDBOARDS_OFF = 'cardboards-off.svg'
    CARDBOARDS = 'cardboards.svg'
    CARDS = 'cards.svg'
    CARET_DOWN = 'caret-down.svg'
    CARET_LEFT_RIGHT = 'caret-left-right.svg'
    CARET_LEFT = 'caret-left.svg'
    CARET_RIGHT = 'caret-right.svg'
    CARET_UP_DOWN = 'caret-up-down.svg'
    CARET_UP = 'caret-up.svg'
    CAROUSEL_HORIZONTAL = 'carousel-horizontal.svg'
    CAROUSEL_VERTICAL = 'carousel-vertical.svg'
    CARROT_OFF = 'carrot-off.svg'
    CARROT = 'carrot.svg'
    CASH_BANKNOTE_OFF = 'cash-banknote-off.svg'
    CASH_BANKNOTE = 'cash-banknote.svg'
    CASH_OFF = 'cash-off.svg'
    CASH = 'cash.svg'
    CAST_OFF = 'cast-off.svg'
    CAST = 'cast.svg'
    CAT = 'cat.svg'
    CATEGORY_2 = 'category-2.svg'
    CATEGORY_MINUS = 'category-minus.svg'
    CATEGORY_PLUS = 'category-plus.svg'
    CATEGORY = 'category.svg'
    CE_OFF = 'ce-off.svg'
    CE = 'ce.svg'
    CELL_SIGNAL_1 = 'cell-signal-1.svg'
    CELL_SIGNAL_2 = 'cell-signal-2.svg'
    CELL_SIGNAL_3 = 'cell-signal-3.svg'
    CELL_SIGNAL_4 = 'cell-signal-4.svg'
    CELL_SIGNAL_5 = 'cell-signal-5.svg'
    CELL_SIGNAL_OFF = 'cell-signal-off.svg'
    CELL = 'cell.svg'
    CERTIFICATE_2_OFF = 'certificate-2-off.svg'
    CERTIFICATE_2 = 'certificate-2.svg'
    CERTIFICATE_OFF = 'certificate-off.svg'
    CERTIFICATE = 'certificate.svg'
    CHAIR_DIRECTOR = 'chair-director.svg'
    CHALKBOARD_OFF = 'chalkboard-off.svg'
    CHALKBOARD = 'chalkboard.svg'
    CHARGING_PILE = 'charging-pile.svg'
    CHART_ARCS_3 = 'chart-arcs-3.svg'
    CHART_ARCS = 'chart-arcs.svg'
    CHART_AREA_LINE = 'chart-area-line.svg'
    CHART_AREA = 'chart-area.svg'
    CHART_ARROWS_VERTICAL = 'chart-arrows-vertical.svg'
    CHART_ARROWS = 'chart-arrows.svg'
    CHART_BAR_OFF = 'chart-bar-off.svg'
    CHART_BAR = 'chart-bar.svg'
    CHART_BUBBLE = 'chart-bubble.svg'
    CHART_CANDLE = 'chart-candle.svg'
    CHART_CIRCLES = 'chart-circles.svg'
    CHART_DONUT_2 = 'chart-donut-2.svg'
    CHART_DONUT_3 = 'chart-donut-3.svg'
    CHART_DONUT_4 = 'chart-donut-4.svg'
    CHART_DONUT = 'chart-donut.svg'
    CHART_DOTS_2 = 'chart-dots-2.svg'
    CHART_DOTS_3 = 'chart-dots-3.svg'
    CHART_DOTS = 'chart-dots.svg'
    CHART_GRID_DOTS = 'chart-grid-dots.svg'
    CHART_HISTOGRAM = 'chart-histogram.svg'
    CHART_INFOGRAPHIC = 'chart-infographic.svg'
    CHART_LINE = 'chart-line.svg'
    CHART_PIE_2 = 'chart-pie-2.svg'
    CHART_PIE_3 = 'chart-pie-3.svg'
    CHART_PIE_4 = 'chart-pie-4.svg'
    CHART_PIE_OFF = 'chart-pie-off.svg'
    CHART_PIE = 'chart-pie.svg'
    CHART_PPF = 'chart-ppf.svg'
    CHART_RADAR = 'chart-radar.svg'
    CHART_SANKEY = 'chart-sankey.svg'
    CHART_SCATTER_3D = 'chart-scatter-3d.svg'
    CHART_SCATTER = 'chart-scatter.svg'
    CHART_TREEMAP = 'chart-treemap.svg'
    CHECK = 'check.svg'
    CHECKBOX = 'checkbox.svg'
    CHECKLIST = 'checklist.svg'
    CHECKS = 'checks.svg'
    CHECKUP_LIST = 'checkup-list.svg'
    CHEESE = 'cheese.svg'
    CHEF_HAT_OFF = 'chef-hat-off.svg'
    CHEF_HAT = 'chef-hat.svg'
    CHERRY = 'cherry.svg'
    CHESS_BISHOP = 'chess-bishop.svg'
    CHESS_KING = 'chess-king.svg'
    CHESS_KNIGHT = 'chess-knight.svg'
    CHESS_QUEEN = 'chess-queen.svg'
    CHESS_ROOK = 'chess-rook.svg'
    CHESS = 'chess.svg'
    CHEVRON_COMPACT_DOWN = 'chevron-compact-down.svg'
    CHEVRON_COMPACT_LEFT = 'chevron-compact-left.svg'
    CHEVRON_COMPACT_RIGHT = 'chevron-compact-right.svg'
    CHEVRON_COMPACT_UP = 'chevron-compact-up.svg'
    CHEVRON_DOWN_LEFT = 'chevron-down-left.svg'
    CHEVRON_DOWN_RIGHT = 'chevron-down-right.svg'
    CHEVRON_DOWN = 'chevron-down.svg'
    CHEVRON_LEFT_PIPE = 'chevron-left-pipe.svg'
    CHEVRON_LEFT = 'chevron-left.svg'
    CHEVRON_RIGHT_PIPE = 'chevron-right-pipe.svg'
    CHEVRON_RIGHT = 'chevron-right.svg'
    CHEVRON_UP_LEFT = 'chevron-up-left.svg'
    CHEVRON_UP_RIGHT = 'chevron-up-right.svg'
    CHEVRON_UP = 'chevron-up.svg'
    CHEVRONS_DOWN_LEFT = 'chevrons-down-left.svg'
    CHEVRONS_DOWN_RIGHT = 'chevrons-down-right.svg'
    CHEVRONS_DOWN = 'chevrons-down.svg'
    CHEVRONS_LEFT = 'chevrons-left.svg'
    CHEVRONS_RIGHT = 'chevrons-right.svg'
    CHEVRONS_UP_LEFT = 'chevrons-up-left.svg'
    CHEVRONS_UP_RIGHT = 'chevrons-up-right.svg'
    CHEVRONS_UP = 'chevrons-up.svg'
    CHISEL = 'chisel.svg'
    CHRISTMAS_BALL = 'christmas-ball.svg'
    CHRISTMAS_TREE_OFF = 'christmas-tree-off.svg'
    CHRISTMAS_TREE = 'christmas-tree.svg'
    CIRCLE_ARROW_DOWN_LEFT = 'circle-arrow-down-left.svg'
    CIRCLE_ARROW_DOWN_RIGHT = 'circle-arrow-down-right.svg'
    CIRCLE_ARROW_DOWN = 'circle-arrow-down.svg'
    CIRCLE_ARROW_LEFT = 'circle-arrow-left.svg'
    CIRCLE_ARROW_RIGHT = 'circle-arrow-right.svg'
    CIRCLE_ARROW_UP_LEFT = 'circle-arrow-up-left.svg'
    CIRCLE_ARROW_UP_RIGHT = 'circle-arrow-up-right.svg'
    CIRCLE_ARROW_UP = 'circle-arrow-up.svg'
    CIRCLE_CARET_DOWN = 'circle-caret-down.svg'
    CIRCLE_CARET_LEFT = 'circle-caret-left.svg'
    CIRCLE_CARET_RIGHT = 'circle-caret-right.svg'
    CIRCLE_CARET_UP = 'circle-caret-up.svg'
    CIRCLE_CHECK = 'circle-check.svg'
    CIRCLE_CHEVRON_DOWN = 'circle-chevron-down.svg'
    CIRCLE_CHEVRON_LEFT = 'circle-chevron-left.svg'
    CIRCLE_CHEVRON_RIGHT = 'circle-chevron-right.svg'
    CIRCLE_CHEVRON_UP = 'circle-chevron-up.svg'
    CIRCLE_CHEVRONS_DOWN = 'circle-chevrons-down.svg'
    CIRCLE_CHEVRONS_LEFT = 'circle-chevrons-left.svg'
    CIRCLE_CHEVRONS_RIGHT = 'circle-chevrons-right.svg'
    CIRCLE_CHEVRONS_UP = 'circle-chevrons-up.svg'
    CIRCLE_DASHED_CHECK = 'circle-dashed-check.svg'
    CIRCLE_DASHED_MINUS = 'circle-dashed-minus.svg'
    CIRCLE_DASHED_NUMBER_0 = 'circle-dashed-number-0.svg'
    CIRCLE_DASHED_NUMBER_1 = 'circle-dashed-number-1.svg'
    CIRCLE_DASHED_NUMBER_2 = 'circle-dashed-number-2.svg'
    CIRCLE_DASHED_NUMBER_3 = 'circle-dashed-number-3.svg'
    CIRCLE_DASHED_NUMBER_4 = 'circle-dashed-number-4.svg'
    CIRCLE_DASHED_NUMBER_5 = 'circle-dashed-number-5.svg'
    CIRCLE_DASHED_NUMBER_6 = 'circle-dashed-number-6.svg'
    CIRCLE_DASHED_NUMBER_7 = 'circle-dashed-number-7.svg'
    CIRCLE_DASHED_NUMBER_8 = 'circle-dashed-number-8.svg'
    CIRCLE_DASHED_NUMBER_9 = 'circle-dashed-number-9.svg'
    CIRCLE_DASHED_PERCENTAGE = 'circle-dashed-percentage.svg'
    CIRCLE_DASHED_PLUS = 'circle-dashed-plus.svg'
    CIRCLE_DASHED_X = 'circle-dashed-x.svg'
    CIRCLE_DASHED = 'circle-dashed.svg'
    CIRCLE_DOT = 'circle-dot.svg'
    CIRCLE_DOTTED = 'circle-dotted.svg'
    CIRCLE_HALF_2 = 'circle-half-2.svg'
    CIRCLE_HALF_VERTICAL = 'circle-half-vertical.svg'
    CIRCLE_HALF = 'circle-half.svg'
    CIRCLE_KEY = 'circle-key.svg'
    CIRCLE_LETTER_A = 'circle-letter-a.svg'
    CIRCLE_LETTER_B = 'circle-letter-b.svg'
    CIRCLE_LETTER_C = 'circle-letter-c.svg'
    CIRCLE_LETTER_D = 'circle-letter-d.svg'
    CIRCLE_LETTER_E = 'circle-letter-e.svg'
    CIRCLE_LETTER_F = 'circle-letter-f.svg'
    CIRCLE_LETTER_G = 'circle-letter-g.svg'
    CIRCLE_LETTER_H = 'circle-letter-h.svg'
    CIRCLE_LETTER_I = 'circle-letter-i.svg'
    CIRCLE_LETTER_J = 'circle-letter-j.svg'
    CIRCLE_LETTER_K = 'circle-letter-k.svg'
    CIRCLE_LETTER_L = 'circle-letter-l.svg'
    CIRCLE_LETTER_M = 'circle-letter-m.svg'
    CIRCLE_LETTER_N = 'circle-letter-n.svg'
    CIRCLE_LETTER_O = 'circle-letter-o.svg'
    CIRCLE_LETTER_P = 'circle-letter-p.svg'
    CIRCLE_LETTER_Q = 'circle-letter-q.svg'
    CIRCLE_LETTER_R = 'circle-letter-r.svg'
    CIRCLE_LETTER_S = 'circle-letter-s.svg'
    CIRCLE_LETTER_T = 'circle-letter-t.svg'
    CIRCLE_LETTER_U = 'circle-letter-u.svg'
    CIRCLE_LETTER_V = 'circle-letter-v.svg'
    CIRCLE_LETTER_W = 'circle-letter-w.svg'
    CIRCLE_LETTER_X = 'circle-letter-x.svg'
    CIRCLE_LETTER_Y = 'circle-letter-y.svg'
    CIRCLE_LETTER_Z = 'circle-letter-z.svg'
    CIRCLE_MINUS_2 = 'circle-minus-2.svg'
    CIRCLE_MINUS = 'circle-minus.svg'
    CIRCLE_NUMBER_0 = 'circle-number-0.svg'
    CIRCLE_NUMBER_1 = 'circle-number-1.svg'
    CIRCLE_NUMBER_2 = 'circle-number-2.svg'
    CIRCLE_NUMBER_3 = 'circle-number-3.svg'
    CIRCLE_NUMBER_4 = 'circle-number-4.svg'
    CIRCLE_NUMBER_5 = 'circle-number-5.svg'
    CIRCLE_NUMBER_6 = 'circle-number-6.svg'
    CIRCLE_NUMBER_7 = 'circle-number-7.svg'
    CIRCLE_NUMBER_8 = 'circle-number-8.svg'
    CIRCLE_NUMBER_9 = 'circle-number-9.svg'
    CIRCLE_OFF = 'circle-off.svg'
    CIRCLE_PERCENTAGE = 'circle-percentage.svg'
    CIRCLE_PLUS_2 = 'circle-plus-2.svg'
    CIRCLE_PLUS = 'circle-plus.svg'
    CIRCLE_RECTANGLE_OFF = 'circle-rectangle-off.svg'
    CIRCLE_RECTANGLE = 'circle-rectangle.svg'
    CIRCLE_SQUARE = 'circle-square.svg'
    CIRCLE_TRIANGLE = 'circle-triangle.svg'
    CIRCLE_X = 'circle-x.svg'
    CIRCLE = 'circle.svg'
    CIRCLES_RELATION = 'circles-relation.svg'
    CIRCLES = 'circles.svg'
    CIRCUIT_AMMETER = 'circuit-ammeter.svg'
    CIRCUIT_BATTERY = 'circuit-battery.svg'
    CIRCUIT_BULB = 'circuit-bulb.svg'
    CIRCUIT_CAPACITOR_POLARIZED = 'circuit-capacitor-polarized.svg'
    CIRCUIT_CAPACITOR = 'circuit-capacitor.svg'
    CIRCUIT_CELL_PLUS = 'circuit-cell-plus.svg'
    CIRCUIT_CELL = 'circuit-cell.svg'
    CIRCUIT_CHANGEOVER = 'circuit-changeover.svg'
    CIRCUIT_DIODE_ZENER = 'circuit-diode-zener.svg'
    CIRCUIT_DIODE = 'circuit-diode.svg'
    CIRCUIT_GROUND_DIGITAL = 'circuit-ground-digital.svg'
    CIRCUIT_GROUND = 'circuit-ground.svg'
    CIRCUIT_INDUCTOR = 'circuit-inductor.svg'
    CIRCUIT_MOTOR = 'circuit-motor.svg'
    CIRCUIT_PUSHBUTTON = 'circuit-pushbutton.svg'
    CIRCUIT_RESISTOR = 'circuit-resistor.svg'
    CIRCUIT_SWITCH_CLOSED = 'circuit-switch-closed.svg'
    CIRCUIT_SWITCH_OPEN = 'circuit-switch-open.svg'
    CIRCUIT_VOLTMETER = 'circuit-voltmeter.svg'
    CLEAR_ALL = 'clear-all.svg'
    CLEAR_FORMATTING = 'clear-formatting.svg'
    CLICK = 'click.svg'
    CLIPBOARD_CHECK = 'clipboard-check.svg'
    CLIPBOARD_COPY = 'clipboard-copy.svg'
    CLIPBOARD_DATA = 'clipboard-data.svg'
    CLIPBOARD_HEART = 'clipboard-heart.svg'
    CLIPBOARD_LIST = 'clipboard-list.svg'
    CLIPBOARD_OFF = 'clipboard-off.svg'
    CLIPBOARD_PLUS = 'clipboard-plus.svg'
    CLIPBOARD_SMILE = 'clipboard-smile.svg'
    CLIPBOARD_TEXT = 'clipboard-text.svg'
    CLIPBOARD_TYPOGRAPHY = 'clipboard-typography.svg'
    CLIPBOARD_X = 'clipboard-x.svg'
    CLIPBOARD = 'clipboard.svg'
    CLOCK_12 = 'clock-12.svg'
    CLOCK_2 = 'clock-2.svg'
    CLOCK_24 = 'clock-24.svg'
    CLOCK_BOLT = 'clock-bolt.svg'
    CLOCK_CANCEL = 'clock-cancel.svg'
    CLOCK_CHECK = 'clock-check.svg'
    CLOCK_CODE = 'clock-code.svg'
    CLOCK_COG = 'clock-cog.svg'
    CLOCK_DOLLAR = 'clock-dollar.svg'
    CLOCK_DOWN = 'clock-down.svg'
    CLOCK_EDIT = 'clock-edit.svg'
    CLOCK_EXCLAMATION = 'clock-exclamation.svg'
    CLOCK_HEART = 'clock-heart.svg'
    CLOCK_HOUR_1 = 'clock-hour-1.svg'
    CLOCK_HOUR_10 = 'clock-hour-10.svg'
    CLOCK_HOUR_11 = 'clock-hour-11.svg'
    CLOCK_HOUR_12 = 'clock-hour-12.svg'
    CLOCK_HOUR_2 = 'clock-hour-2.svg'
    CLOCK_HOUR_3 = 'clock-hour-3.svg'
    CLOCK_HOUR_4 = 'clock-hour-4.svg'
    CLOCK_HOUR_5 = 'clock-hour-5.svg'
    CLOCK_HOUR_6 = 'clock-hour-6.svg'
    CLOCK_HOUR_7 = 'clock-hour-7.svg'
    CLOCK_HOUR_8 = 'clock-hour-8.svg'
    CLOCK_HOUR_9 = 'clock-hour-9.svg'
    CLOCK_MINUS = 'clock-minus.svg'
    CLOCK_OFF = 'clock-off.svg'
    CLOCK_PAUSE = 'clock-pause.svg'
    CLOCK_PIN = 'clock-pin.svg'
    CLOCK_PLAY = 'clock-play.svg'
    CLOCK_PLUS = 'clock-plus.svg'
    CLOCK_QUESTION = 'clock-question.svg'
    CLOCK_RECORD = 'clock-record.svg'
    CLOCK_SEARCH = 'clock-search.svg'
    CLOCK_SHARE = 'clock-share.svg'
    CLOCK_SHIELD = 'clock-shield.svg'
    CLOCK_STAR = 'clock-star.svg'
    CLOCK_STOP = 'clock-stop.svg'
    CLOCK_UP = 'clock-up.svg'
    CLOCK_X = 'clock-x.svg'
    CLOCK = 'clock.svg'
    CLOTHES_RACK_OFF = 'clothes-rack-off.svg'
    CLOTHES_RACK = 'clothes-rack.svg'
    CLOUD_BOLT = 'cloud-bolt.svg'
    CLOUD_CANCEL = 'cloud-cancel.svg'
    CLOUD_CHECK = 'cloud-check.svg'
    CLOUD_CODE = 'cloud-code.svg'
    CLOUD_COG = 'cloud-cog.svg'
    CLOUD_COMPUTING = 'cloud-computing.svg'
    CLOUD_DATA_CONNECTION = 'cloud-data-connection.svg'
    CLOUD_DOLLAR = 'cloud-dollar.svg'
    CLOUD_DOWN = 'cloud-down.svg'
    CLOUD_DOWNLOAD = 'cloud-download.svg'
    CLOUD_EXCLAMATION = 'cloud-exclamation.svg'
    CLOUD_FOG = 'cloud-fog.svg'
    CLOUD_HEART = 'cloud-heart.svg'
    CLOUD_LOCK_OPEN = 'cloud-lock-open.svg'
    CLOUD_LOCK = 'cloud-lock.svg'
    CLOUD_MINUS = 'cloud-minus.svg'
    CLOUD_NETWORK = 'cloud-network.svg'
    CLOUD_OFF = 'cloud-off.svg'
    CLOUD_PAUSE = 'cloud-pause.svg'
    CLOUD_PIN = 'cloud-pin.svg'
    CLOUD_PLUS = 'cloud-plus.svg'
    CLOUD_QUESTION = 'cloud-question.svg'
    CLOUD_RAIN = 'cloud-rain.svg'
    CLOUD_SEARCH = 'cloud-search.svg'
    CLOUD_SHARE = 'cloud-share.svg'
    CLOUD_SNOW = 'cloud-snow.svg'
    CLOUD_STAR = 'cloud-star.svg'
    CLOUD_STORM = 'cloud-storm.svg'
    CLOUD_UP = 'cloud-up.svg'
    CLOUD_UPLOAD = 'cloud-upload.svg'
    CLOUD_X = 'cloud-x.svg'
    CLOUD = 'cloud.svg'
    CLOVER_2 = 'clover-2.svg'
    CLOVER = 'clover.svg'
    CLUBS = 'clubs.svg'
    CODE_ASTERISK = 'code-asterisk.svg'
    CODE_CIRCLE_2 = 'code-circle-2.svg'
    CODE_CIRCLE = 'code-circle.svg'
    CODE_DOTS = 'code-dots.svg'
    CODE_MINUS = 'code-minus.svg'
    CODE_OFF = 'code-off.svg'
    CODE_PLUS = 'code-plus.svg'
    CODE = 'code.svg'
    COFFEE_OFF = 'coffee-off.svg'
    COFFEE = 'coffee.svg'
    COFFIN = 'coffin.svg'
    COIN_BITCOIN = 'coin-bitcoin.svg'
    COIN_EURO = 'coin-euro.svg'
    COIN_MONERO = 'coin-monero.svg'
    COIN_OFF = 'coin-off.svg'
    COIN_POUND = 'coin-pound.svg'
    COIN_RUPEE = 'coin-rupee.svg'
    COIN_TAKA = 'coin-taka.svg'
    COIN_YEN = 'coin-yen.svg'
    COIN_YUAN = 'coin-yuan.svg'
    COIN = 'coin.svg'
    COINS = 'coins.svg'
    COLOR_FILTER = 'color-filter.svg'
    COLOR_PICKER_OFF = 'color-picker-off.svg'
    COLOR_PICKER = 'color-picker.svg'
    COLOR_SWATCH_OFF = 'color-swatch-off.svg'
    COLOR_SWATCH = 'color-swatch.svg'
    COLUMN_INSERT_LEFT = 'column-insert-left.svg'
    COLUMN_INSERT_RIGHT = 'column-insert-right.svg'
    COLUMN_REMOVE = 'column-remove.svg'
    COLUMNS_1 = 'columns-1.svg'
    COLUMNS_2 = 'columns-2.svg'
    COLUMNS_3 = 'columns-3.svg'
    COLUMNS_OFF = 'columns-off.svg'
    COLUMNS = 'columns.svg'
    COMET = 'comet.svg'
    COMMAND_OFF = 'command-off.svg'
    COMMAND = 'command.svg'
    COMPASS_OFF = 'compass-off.svg'
    COMPASS = 'compass.svg'
    COMPONENTS_OFF = 'components-off.svg'
    COMPONENTS = 'components.svg'
    CONE_2 = 'cone-2.svg'
    CONE_OFF = 'cone-off.svg'
    CONE_PLUS = 'cone-plus.svg'
    CONE = 'cone.svg'
    CONFETTI_OFF = 'confetti-off.svg'
    CONFETTI = 'confetti.svg'
    CONFUCIUS = 'confucius.svg'
    CONTAINER_OFF = 'container-off.svg'
    CONTAINER = 'container.svg'
    CONTRAST_2_OFF = 'contrast-2-off.svg'
    CONTRAST_2 = 'contrast-2.svg'
    CONTRAST_OFF = 'contrast-off.svg'
    CONTRAST = 'contrast.svg'
    COOKER = 'cooker.svg'
    COOKIE_MAN = 'cookie-man.svg'
    COOKIE_OFF = 'cookie-off.svg'
    COOKIE = 'cookie.svg'
    COPY_CHECK = 'copy-check.svg'
    COPY_MINUS = 'copy-minus.svg'
    COPY_OFF = 'copy-off.svg'
    COPY_PLUS = 'copy-plus.svg'
    COPY_X = 'copy-x.svg'
    COPY = 'copy.svg'
    COPYLEFT_OFF = 'copyleft-off.svg'
    COPYLEFT = 'copyleft.svg'
    COPYRIGHT_OFF = 'copyright-off.svg'
    COPYRIGHT = 'copyright.svg'
    CORNER_DOWN_LEFT_DOUBLE = 'corner-down-left-double.svg'
    CORNER_DOWN_LEFT = 'corner-down-left.svg'
    CORNER_DOWN_RIGHT_DOUBLE = 'corner-down-right-double.svg'
    CORNER_DOWN_RIGHT = 'corner-down-right.svg'
    CORNER_LEFT_DOWN_DOUBLE = 'corner-left-down-double.svg'
    CORNER_LEFT_DOWN = 'corner-left-down.svg'
    CORNER_LEFT_UP_DOUBLE = 'corner-left-up-double.svg'
    CORNER_LEFT_UP = 'corner-left-up.svg'
    CORNER_RIGHT_DOWN_DOUBLE = 'corner-right-down-double.svg'
    CORNER_RIGHT_DOWN = 'corner-right-down.svg'
    CORNER_RIGHT_UP_DOUBLE = 'corner-right-up-double.svg'
    CORNER_RIGHT_UP = 'corner-right-up.svg'
    CORNER_UP_LEFT_DOUBLE = 'corner-up-left-double.svg'
    CORNER_UP_LEFT = 'corner-up-left.svg'
    CORNER_UP_RIGHT_DOUBLE = 'corner-up-right-double.svg'
    CORNER_UP_RIGHT = 'corner-up-right.svg'
    CPU_2 = 'cpu-2.svg'
    CPU_OFF = 'cpu-off.svg'
    CPU = 'cpu.svg'
    CRANE_OFF = 'crane-off.svg'
    CRANE = 'crane.svg'
    CREATIVE_COMMONS_BY = 'creative-commons-by.svg'
    CREATIVE_COMMONS_NC = 'creative-commons-nc.svg'
    CREATIVE_COMMONS_ND = 'creative-commons-nd.svg'
    CREATIVE_COMMONS_OFF = 'creative-commons-off.svg'
    CREATIVE_COMMONS_SA = 'creative-commons-sa.svg'
    CREATIVE_COMMONS_ZERO = 'creative-commons-zero.svg'
    CREATIVE_COMMONS = 'creative-commons.svg'
    CREDIT_CARD_OFF = 'credit-card-off.svg'
    CREDIT_CARD_PAY = 'credit-card-pay.svg'
    CREDIT_CARD_REFUND = 'credit-card-refund.svg'
    CREDIT_CARD = 'credit-card.svg'
    CRICKET = 'cricket.svg'
    CROP_1_1 = 'crop-1-1.svg'
    CROP_16_9 = 'crop-16-9.svg'
    CROP_3_2 = 'crop-3-2.svg'
    CROP_5_4 = 'crop-5-4.svg'
    CROP_7_5 = 'crop-7-5.svg'
    CROP_LANDSCAPE = 'crop-landscape.svg'
    CROP_PORTRAIT = 'crop-portrait.svg'
    CROP = 'crop.svg'
    CROSS_OFF = 'cross-off.svg'
    CROSS = 'cross.svg'
    CROSSHAIR = 'crosshair.svg'
    CROWN_OFF = 'crown-off.svg'
    CROWN = 'crown.svg'
    CRUTCHES_OFF = 'crutches-off.svg'
    CRUTCHES = 'crutches.svg'
    CRYSTAL_BALL = 'crystal-ball.svg'
    CSV = 'csv.svg'
    CUBE_3D_SPHERE_OFF = 'cube-3d-sphere-off.svg'
    CUBE_3D_SPHERE = 'cube-3d-sphere.svg'
    CUBE_OFF = 'cube-off.svg'
    CUBE_PLUS = 'cube-plus.svg'
    CUBE_SEND = 'cube-send.svg'
    CUBE_UNFOLDED = 'cube-unfolded.svg'
    CUBE = 'cube.svg'
    CUP_OFF = 'cup-off.svg'
    CUP = 'cup.svg'
    CURLING = 'curling.svg'
    CURLY_LOOP = 'curly-loop.svg'
    CURRENCY_AFGHANI = 'currency-afghani.svg'
    CURRENCY_BAHRAINI = 'currency-bahraini.svg'
    CURRENCY_BAHT = 'currency-baht.svg'
    CURRENCY_BITCOIN = 'currency-bitcoin.svg'
    CURRENCY_CENT = 'currency-cent.svg'
    CURRENCY_DINAR = 'currency-dinar.svg'
    CURRENCY_DIRHAM = 'currency-dirham.svg'
    CURRENCY_DOGECOIN = 'currency-dogecoin.svg'
    CURRENCY_DOLLAR_AUSTRALIAN = 'currency-dollar-australian.svg'
    CURRENCY_DOLLAR_BRUNEI = 'currency-dollar-brunei.svg'
    CURRENCY_DOLLAR_CANADIAN = 'currency-dollar-canadian.svg'
    CURRENCY_DOLLAR_GUYANESE = 'currency-dollar-guyanese.svg'
    CURRENCY_DOLLAR_OFF = 'currency-dollar-off.svg'
    CURRENCY_DOLLAR_SINGAPORE = 'currency-dollar-singapore.svg'
    CURRENCY_DOLLAR_ZIMBABWEAN = 'currency-dollar-zimbabwean.svg'
    CURRENCY_DOLLAR = 'currency-dollar.svg'
    CURRENCY_DONG = 'currency-dong.svg'
    CURRENCY_DRAM = 'currency-dram.svg'
    CURRENCY_ETHEREUM = 'currency-ethereum.svg'
    CURRENCY_EURO_OFF = 'currency-euro-off.svg'
    CURRENCY_EURO = 'currency-euro.svg'
    CURRENCY_FLORIN = 'currency-florin.svg'
    CURRENCY_FORINT = 'currency-forint.svg'
    CURRENCY_FRANK = 'currency-frank.svg'
    CURRENCY_GUARANI = 'currency-guarani.svg'
    CURRENCY_HRYVNIA = 'currency-hryvnia.svg'
    CURRENCY_IRANIAN_RIAL = 'currency-iranian-rial.svg'
    CURRENCY_KIP = 'currency-kip.svg'
    CURRENCY_KRONE_CZECH = 'currency-krone-czech.svg'
    CURRENCY_KRONE_DANISH = 'currency-krone-danish.svg'
    CURRENCY_KRONE_SWEDISH = 'currency-krone-swedish.svg'
    CURRENCY_LARI = 'currency-lari.svg'
    CURRENCY_LEU = 'currency-leu.svg'
    CURRENCY_LIRA = 'currency-lira.svg'
    CURRENCY_LITECOIN = 'currency-litecoin.svg'
    CURRENCY_LYD = 'currency-lyd.svg'
    CURRENCY_MANAT = 'currency-manat.svg'
    CURRENCY_MONERO = 'currency-monero.svg'
    CURRENCY_NAIRA = 'currency-naira.svg'
    CURRENCY_NANO = 'currency-nano.svg'
    CURRENCY_OFF = 'currency-off.svg'
    CURRENCY_PAANGA = 'currency-paanga.svg'
    CURRENCY_PESO = 'currency-peso.svg'
    CURRENCY_POUND_OFF = 'currency-pound-off.svg'
    CURRENCY_POUND = 'currency-pound.svg'
    CURRENCY_QUETZAL = 'currency-quetzal.svg'
    CURRENCY_REAL = 'currency-real.svg'
    CURRENCY_RENMINBI = 'currency-renminbi.svg'
    CURRENCY_RIPPLE = 'currency-ripple.svg'
    CURRENCY_RIYAL = 'currency-riyal.svg'
    CURRENCY_RUBEL = 'currency-rubel.svg'
    CURRENCY_RUFIYAA = 'currency-rufiyaa.svg'
    CURRENCY_RUPEE_NEPALESE = 'currency-rupee-nepalese.svg'
    CURRENCY_RUPEE = 'currency-rupee.svg'
    CURRENCY_SHEKEL = 'currency-shekel.svg'
    CURRENCY_SOLANA = 'currency-solana.svg'
    CURRENCY_SOM = 'currency-som.svg'
    CURRENCY_TAKA = 'currency-taka.svg'
    CURRENCY_TENGE = 'currency-tenge.svg'
    CURRENCY_TUGRIK = 'currency-tugrik.svg'
    CURRENCY_WON = 'currency-won.svg'
    CURRENCY_XRP = 'currency-xrp.svg'
    CURRENCY_YEN_OFF = 'currency-yen-off.svg'
    CURRENCY_YEN = 'currency-yen.svg'
    CURRENCY_YUAN = 'currency-yuan.svg'
    CURRENCY_ZLOTY = 'currency-zloty.svg'
    CURRENCY = 'currency.svg'
    CURRENT_LOCATION_OFF = 'current-location-off.svg'
    CURRENT_LOCATION = 'current-location.svg'
    CURSOR_OFF = 'cursor-off.svg'
    CURSOR_TEXT = 'cursor-text.svg'
    CUT = 'cut.svg'
    CYLINDER_OFF = 'cylinder-off.svg'
    CYLINDER_PLUS = 'cylinder-plus.svg'
    CYLINDER = 'cylinder.svg'
    DASHBOARD_OFF = 'dashboard-off.svg'
    DASHBOARD = 'dashboard.svg'
    DATABASE_COG = 'database-cog.svg'
    DATABASE_DOLLAR = 'database-dollar.svg'
    DATABASE_EDIT = 'database-edit.svg'
    DATABASE_EXCLAMATION = 'database-exclamation.svg'
    DATABASE_EXPORT = 'database-export.svg'
    DATABASE_HEART = 'database-heart.svg'
    DATABASE_IMPORT = 'database-import.svg'
    DATABASE_LEAK = 'database-leak.svg'
    DATABASE_MINUS = 'database-minus.svg'
    DATABASE_OFF = 'database-off.svg'
    DATABASE_PLUS = 'database-plus.svg'
    DATABASE_SEARCH = 'database-search.svg'
    DATABASE_SHARE = 'database-share.svg'
    DATABASE_SMILE = 'database-smile.svg'
    DATABASE_STAR = 'database-star.svg'
    DATABASE_X = 'database-x.svg'
    DATABASE = 'database.svg'
    DECIMAL = 'decimal.svg'
    DEER = 'deer.svg'
    DELTA = 'delta.svg'
    DENTAL_BROKEN = 'dental-broken.svg'
    DENTAL_OFF = 'dental-off.svg'
    DENTAL = 'dental.svg'
    DESELECT = 'deselect.svg'
    DESK = 'desk.svg'
    DETAILS_OFF = 'details-off.svg'
    DETAILS = 'details.svg'
    DEVICE_AIRPODS_CASE = 'device-airpods-case.svg'
    DEVICE_AIRPODS = 'device-airpods.svg'
    DEVICE_AIRTAG = 'device-airtag.svg'
    DEVICE_ANALYTICS = 'device-analytics.svg'
    DEVICE_AUDIO_TAPE = 'device-audio-tape.svg'
    DEVICE_CAMERA_PHONE = 'device-camera-phone.svg'
    DEVICE_CCTV_OFF = 'device-cctv-off.svg'
    DEVICE_CCTV = 'device-cctv.svg'
    DEVICE_COMPUTER_CAMERA_OFF = 'device-computer-camera-off.svg'
    DEVICE_COMPUTER_CAMERA = 'device-computer-camera.svg'
    DEVICE_DESKTOP_ANALYTICS = 'device-desktop-analytics.svg'
    DEVICE_DESKTOP_BOLT = 'device-desktop-bolt.svg'
    DEVICE_DESKTOP_CANCEL = 'device-desktop-cancel.svg'
    DEVICE_DESKTOP_CHECK = 'device-desktop-check.svg'
    DEVICE_DESKTOP_CODE = 'device-desktop-code.svg'
    DEVICE_DESKTOP_COG = 'device-desktop-cog.svg'
    DEVICE_DESKTOP_DOLLAR = 'device-desktop-dollar.svg'
    DEVICE_DESKTOP_DOWN = 'device-desktop-down.svg'
    DEVICE_DESKTOP_EXCLAMATION = 'device-desktop-exclamation.svg'
    DEVICE_DESKTOP_HEART = 'device-desktop-heart.svg'
    DEVICE_DESKTOP_MINUS = 'device-desktop-minus.svg'
    DEVICE_DESKTOP_OFF = 'device-desktop-off.svg'
    DEVICE_DESKTOP_PAUSE = 'device-desktop-pause.svg'
    DEVICE_DESKTOP_PIN = 'device-desktop-pin.svg'
    DEVICE_DESKTOP_PLUS = 'device-desktop-plus.svg'
    DEVICE_DESKTOP_QUESTION = 'device-desktop-question.svg'
    DEVICE_DESKTOP_SEARCH = 'device-desktop-search.svg'
    DEVICE_DESKTOP_SHARE = 'device-desktop-share.svg'
    DEVICE_DESKTOP_STAR = 'device-desktop-star.svg'
    DEVICE_DESKTOP_UP = 'device-desktop-up.svg'
    DEVICE_DESKTOP_X = 'device-desktop-x.svg'
    DEVICE_DESKTOP = 'device-desktop.svg'
    DEVICE_FLOPPY = 'device-floppy.svg'
    DEVICE_GAMEPAD_2 = 'device-gamepad-2.svg'
    DEVICE_GAMEPAD_3 = 'device-gamepad-3.svg'
    DEVICE_GAMEPAD = 'device-gamepad.svg'
    DEVICE_HEART_MONITOR = 'device-heart-monitor.svg'
    DEVICE_IMAC_BOLT = 'device-imac-bolt.svg'
    DEVICE_IMAC_CANCEL = 'device-imac-cancel.svg'
    DEVICE_IMAC_CHECK = 'device-imac-check.svg'
    DEVICE_IMAC_CODE = 'device-imac-code.svg'
    DEVICE_IMAC_COG = 'device-imac-cog.svg'
    DEVICE_IMAC_DOLLAR = 'device-imac-dollar.svg'
    DEVICE_IMAC_DOWN = 'device-imac-down.svg'
    DEVICE_IMAC_EXCLAMATION = 'device-imac-exclamation.svg'
    DEVICE_IMAC_HEART = 'device-imac-heart.svg'
    DEVICE_IMAC_MINUS = 'device-imac-minus.svg'
    DEVICE_IMAC_OFF = 'device-imac-off.svg'
    DEVICE_IMAC_PAUSE = 'device-imac-pause.svg'
    DEVICE_IMAC_PIN = 'device-imac-pin.svg'
    DEVICE_IMAC_PLUS = 'device-imac-plus.svg'
    DEVICE_IMAC_QUESTION = 'device-imac-question.svg'
    DEVICE_IMAC_SEARCH = 'device-imac-search.svg'
    DEVICE_IMAC_SHARE = 'device-imac-share.svg'
    DEVICE_IMAC_STAR = 'device-imac-star.svg'
    DEVICE_IMAC_UP = 'device-imac-up.svg'
    DEVICE_IMAC_X = 'device-imac-x.svg'
    DEVICE_IMAC = 'device-imac.svg'
    DEVICE_IPAD_BOLT = 'device-ipad-bolt.svg'
    DEVICE_IPAD_CANCEL = 'device-ipad-cancel.svg'
    DEVICE_IPAD_CHECK = 'device-ipad-check.svg'
    DEVICE_IPAD_CODE = 'device-ipad-code.svg'
    DEVICE_IPAD_COG = 'device-ipad-cog.svg'
    DEVICE_IPAD_DOLLAR = 'device-ipad-dollar.svg'
    DEVICE_IPAD_DOWN = 'device-ipad-down.svg'
    DEVICE_IPAD_EXCLAMATION = 'device-ipad-exclamation.svg'
    DEVICE_IPAD_HEART = 'device-ipad-heart.svg'
    DEVICE_IPAD_HORIZONTAL_BOLT = 'device-ipad-horizontal-bolt.svg'
    DEVICE_IPAD_HORIZONTAL_CANCEL = 'device-ipad-horizontal-cancel.svg'
    DEVICE_IPAD_HORIZONTAL_CHECK = 'device-ipad-horizontal-check.svg'
    DEVICE_IPAD_HORIZONTAL_CODE = 'device-ipad-horizontal-code.svg'
    DEVICE_IPAD_HORIZONTAL_COG = 'device-ipad-horizontal-cog.svg'
    DEVICE_IPAD_HORIZONTAL_DOLLAR = 'device-ipad-horizontal-dollar.svg'
    DEVICE_IPAD_HORIZONTAL_DOWN = 'device-ipad-horizontal-down.svg'
    DEVICE_IPAD_HORIZONTAL_EXCLAMATION = 'device-ipad-horizontal-exclamation.svg'
    DEVICE_IPAD_HORIZONTAL_HEART = 'device-ipad-horizontal-heart.svg'
    DEVICE_IPAD_HORIZONTAL_MINUS = 'device-ipad-horizontal-minus.svg'
    DEVICE_IPAD_HORIZONTAL_OFF = 'device-ipad-horizontal-off.svg'
    DEVICE_IPAD_HORIZONTAL_PAUSE = 'device-ipad-horizontal-pause.svg'
    DEVICE_IPAD_HORIZONTAL_PIN = 'device-ipad-horizontal-pin.svg'
    DEVICE_IPAD_HORIZONTAL_PLUS = 'device-ipad-horizontal-plus.svg'
    DEVICE_IPAD_HORIZONTAL_QUESTION = 'device-ipad-horizontal-question.svg'
    DEVICE_IPAD_HORIZONTAL_SEARCH = 'device-ipad-horizontal-search.svg'
    DEVICE_IPAD_HORIZONTAL_SHARE = 'device-ipad-horizontal-share.svg'
    DEVICE_IPAD_HORIZONTAL_STAR = 'device-ipad-horizontal-star.svg'
    DEVICE_IPAD_HORIZONTAL_UP = 'device-ipad-horizontal-up.svg'
    DEVICE_IPAD_HORIZONTAL_X = 'device-ipad-horizontal-x.svg'
    DEVICE_IPAD_HORIZONTAL = 'device-ipad-horizontal.svg'
    DEVICE_IPAD_MINUS = 'device-ipad-minus.svg'
    DEVICE_IPAD_OFF = 'device-ipad-off.svg'
    DEVICE_IPAD_PAUSE = 'device-ipad-pause.svg'
    DEVICE_IPAD_PIN = 'device-ipad-pin.svg'
    DEVICE_IPAD_PLUS = 'device-ipad-plus.svg'
    DEVICE_IPAD_QUESTION = 'device-ipad-question.svg'
    DEVICE_IPAD_SEARCH = 'device-ipad-search.svg'
    DEVICE_IPAD_SHARE = 'device-ipad-share.svg'
    DEVICE_IPAD_STAR = 'device-ipad-star.svg'
    DEVICE_IPAD_UP = 'device-ipad-up.svg'
    DEVICE_IPAD_X = 'device-ipad-x.svg'
    DEVICE_IPAD = 'device-ipad.svg'
    DEVICE_LANDLINE_PHONE = 'device-landline-phone.svg'
    DEVICE_LAPTOP_OFF = 'device-laptop-off.svg'
    DEVICE_LAPTOP = 'device-laptop.svg'
    DEVICE_MOBILE_BOLT = 'device-mobile-bolt.svg'
    DEVICE_MOBILE_CANCEL = 'device-mobile-cancel.svg'
    DEVICE_MOBILE_CHARGING = 'device-mobile-charging.svg'
    DEVICE_MOBILE_CHECK = 'device-mobile-check.svg'
    DEVICE_MOBILE_CODE = 'device-mobile-code.svg'
    DEVICE_MOBILE_COG = 'device-mobile-cog.svg'
    DEVICE_MOBILE_DOLLAR = 'device-mobile-dollar.svg'
    DEVICE_MOBILE_DOWN = 'device-mobile-down.svg'
    DEVICE_MOBILE_EXCLAMATION = 'device-mobile-exclamation.svg'
    DEVICE_MOBILE_HEART = 'device-mobile-heart.svg'
    DEVICE_MOBILE_MESSAGE = 'device-mobile-message.svg'
    DEVICE_MOBILE_MINUS = 'device-mobile-minus.svg'
    DEVICE_MOBILE_OFF = 'device-mobile-off.svg'
    DEVICE_MOBILE_PAUSE = 'device-mobile-pause.svg'
    DEVICE_MOBILE_PIN = 'device-mobile-pin.svg'
    DEVICE_MOBILE_PLUS = 'device-mobile-plus.svg'
    DEVICE_MOBILE_QUESTION = 'device-mobile-question.svg'
    DEVICE_MOBILE_ROTATED = 'device-mobile-rotated.svg'
    DEVICE_MOBILE_SEARCH = 'device-mobile-search.svg'
    DEVICE_MOBILE_SHARE = 'device-mobile-share.svg'
    DEVICE_MOBILE_STAR = 'device-mobile-star.svg'
    DEVICE_MOBILE_UP = 'device-mobile-up.svg'
    DEVICE_MOBILE_VIBRATION = 'device-mobile-vibration.svg'
    DEVICE_MOBILE_X = 'device-mobile-x.svg'
    DEVICE_MOBILE = 'device-mobile.svg'
    DEVICE_NINTENDO_OFF = 'device-nintendo-off.svg'
    DEVICE_NINTENDO = 'device-nintendo.svg'
    DEVICE_PROJECTOR = 'device-projector.svg'
    DEVICE_REMOTE = 'device-remote.svg'
    DEVICE_SD_CARD = 'device-sd-card.svg'
    DEVICE_SIM_1 = 'device-sim-1.svg'
    DEVICE_SIM_2 = 'device-sim-2.svg'
    DEVICE_SIM_3 = 'device-sim-3.svg'
    DEVICE_SIM = 'device-sim.svg'
    DEVICE_SPEAKER_OFF = 'device-speaker-off.svg'
    DEVICE_SPEAKER = 'device-speaker.svg'
    DEVICE_TABLET_BOLT = 'device-tablet-bolt.svg'
    DEVICE_TABLET_CANCEL = 'device-tablet-cancel.svg'
    DEVICE_TABLET_CHECK = 'device-tablet-check.svg'
    DEVICE_TABLET_CODE = 'device-tablet-code.svg'
    DEVICE_TABLET_COG = 'device-tablet-cog.svg'
    DEVICE_TABLET_DOLLAR = 'device-tablet-dollar.svg'
    DEVICE_TABLET_DOWN = 'device-tablet-down.svg'
    DEVICE_TABLET_EXCLAMATION = 'device-tablet-exclamation.svg'
    DEVICE_TABLET_HEART = 'device-tablet-heart.svg'
    DEVICE_TABLET_MINUS = 'device-tablet-minus.svg'
    DEVICE_TABLET_OFF = 'device-tablet-off.svg'
    DEVICE_TABLET_PAUSE = 'device-tablet-pause.svg'
    DEVICE_TABLET_PIN = 'device-tablet-pin.svg'
    DEVICE_TABLET_PLUS = 'device-tablet-plus.svg'
    DEVICE_TABLET_QUESTION = 'device-tablet-question.svg'
    DEVICE_TABLET_SEARCH = 'device-tablet-search.svg'
    DEVICE_TABLET_SHARE = 'device-tablet-share.svg'
    DEVICE_TABLET_STAR = 'device-tablet-star.svg'
    DEVICE_TABLET_UP = 'device-tablet-up.svg'
    DEVICE_TABLET_X = 'device-tablet-x.svg'
    DEVICE_TABLET = 'device-tablet.svg'
    DEVICE_TV_OFF = 'device-tv-off.svg'
    DEVICE_TV_OLD = 'device-tv-old.svg'
    DEVICE_TV = 'device-tv.svg'
    DEVICE_USB = 'device-usb.svg'
    DEVICE_VISION_PRO = 'device-vision-pro.svg'
    DEVICE_WATCH_BOLT = 'device-watch-bolt.svg'
    DEVICE_WATCH_CANCEL = 'device-watch-cancel.svg'
    DEVICE_WATCH_CHECK = 'device-watch-check.svg'
    DEVICE_WATCH_CODE = 'device-watch-code.svg'
    DEVICE_WATCH_COG = 'device-watch-cog.svg'
    DEVICE_WATCH_DOLLAR = 'device-watch-dollar.svg'
    DEVICE_WATCH_DOWN = 'device-watch-down.svg'
    DEVICE_WATCH_EXCLAMATION = 'device-watch-exclamation.svg'
    DEVICE_WATCH_HEART = 'device-watch-heart.svg'
    DEVICE_WATCH_MINUS = 'device-watch-minus.svg'
    DEVICE_WATCH_OFF = 'device-watch-off.svg'
    DEVICE_WATCH_PAUSE = 'device-watch-pause.svg'
    DEVICE_WATCH_PIN = 'device-watch-pin.svg'
    DEVICE_WATCH_PLUS = 'device-watch-plus.svg'
    DEVICE_WATCH_QUESTION = 'device-watch-question.svg'
    DEVICE_WATCH_SEARCH = 'device-watch-search.svg'
    DEVICE_WATCH_SHARE = 'device-watch-share.svg'
    DEVICE_WATCH_STAR = 'device-watch-star.svg'
    DEVICE_WATCH_STATS_2 = 'device-watch-stats-2.svg'
    DEVICE_WATCH_STATS = 'device-watch-stats.svg'
    DEVICE_WATCH_UP = 'device-watch-up.svg'
    DEVICE_WATCH_X = 'device-watch-x.svg'
    DEVICE_WATCH = 'device-watch.svg'
    DEVICES_2 = 'devices-2.svg'
    DEVICES_BOLT = 'devices-bolt.svg'
    DEVICES_CANCEL = 'devices-cancel.svg'
    DEVICES_CHECK = 'devices-check.svg'
    DEVICES_CODE = 'devices-code.svg'
    DEVICES_COG = 'devices-cog.svg'
    DEVICES_DOLLAR = 'devices-dollar.svg'
    DEVICES_DOWN = 'devices-down.svg'
    DEVICES_EXCLAMATION = 'devices-exclamation.svg'
    DEVICES_HEART = 'devices-heart.svg'
    DEVICES_MINUS = 'devices-minus.svg'
    DEVICES_OFF = 'devices-off.svg'
    DEVICES_PAUSE = 'devices-pause.svg'
    DEVICES_PC_OFF = 'devices-pc-off.svg'
    DEVICES_PC = 'devices-pc.svg'
    DEVICES_PIN = 'devices-pin.svg'
    DEVICES_PLUS = 'devices-plus.svg'
    DEVICES_QUESTION = 'devices-question.svg'
    DEVICES_SEARCH = 'devices-search.svg'
    DEVICES_SHARE = 'devices-share.svg'
    DEVICES_STAR = 'devices-star.svg'
    DEVICES_UP = 'devices-up.svg'
    DEVICES_X = 'devices-x.svg'
    DEVICES = 'devices.svg'
    DIABOLO_OFF = 'diabolo-off.svg'
    DIABOLO_PLUS = 'diabolo-plus.svg'
    DIABOLO = 'diabolo.svg'
    DIALPAD_OFF = 'dialpad-off.svg'
    DIALPAD = 'dialpad.svg'
    DIAMOND_OFF = 'diamond-off.svg'
    DIAMOND = 'diamond.svg'
    DIAMONDS = 'diamonds.svg'
    DICE_1 = 'dice-1.svg'
    DICE_2 = 'dice-2.svg'
    DICE_3 = 'dice-3.svg'
    DICE_4 = 'dice-4.svg'
    DICE_5 = 'dice-5.svg'
    DICE_6 = 'dice-6.svg'
    DICE = 'dice.svg'
    DIMENSIONS = 'dimensions.svg'
    DIRECTION_ARROWS = 'direction-arrows.svg'
    DIRECTION_HORIZONTAL = 'direction-horizontal.svg'
    DIRECTION_SIGN_OFF = 'direction-sign-off.svg'
    DIRECTION_SIGN = 'direction-sign.svg'
    DIRECTION = 'direction.svg'
    DIRECTIONS_OFF = 'directions-off.svg'
    DIRECTIONS = 'directions.svg'
    DISABLED_2 = 'disabled-2.svg'
    DISABLED_OFF = 'disabled-off.svg'
    DISABLED = 'disabled.svg'
    DISC_GOLF = 'disc-golf.svg'
    DISC_OFF = 'disc-off.svg'
    DISC = 'disc.svg'
    DISCOUNT_OFF = 'discount-off.svg'
    DISCOUNT = 'discount.svg'
    DIVIDE = 'divide.svg'
    DNA_2_OFF = 'dna-2-off.svg'
    DNA_2 = 'dna-2.svg'
    DNA_OFF = 'dna-off.svg'
    DNA = 'dna.svg'
    DOG_BOWL = 'dog-bowl.svg'
    DOG = 'dog.svg'
    DOOR_ENTER = 'door-enter.svg'
    DOOR_EXIT = 'door-exit.svg'
    DOOR_OFF = 'door-off.svg'
    DOOR = 'door.svg'
    DOTS_CIRCLE_HORIZONTAL = 'dots-circle-horizontal.svg'
    DOTS_DIAGONAL_2 = 'dots-diagonal-2.svg'
    DOTS_DIAGONAL = 'dots-diagonal.svg'
    DOTS_VERTICAL = 'dots-vertical.svg'
    DOTS = 'dots.svg'
    DOWNLOAD_OFF = 'download-off.svg'
    DOWNLOAD = 'download.svg'
    DRAG_DROP_2 = 'drag-drop-2.svg'
    DRAG_DROP = 'drag-drop.svg'
    DRONE_OFF = 'drone-off.svg'
    DRONE = 'drone.svg'
    DROP_CIRCLE = 'drop-circle.svg'
    DROPLET_BOLT = 'droplet-bolt.svg'
    DROPLET_CANCEL = 'droplet-cancel.svg'
    DROPLET_CHECK = 'droplet-check.svg'
    DROPLET_CODE = 'droplet-code.svg'
    DROPLET_COG = 'droplet-cog.svg'
    DROPLET_DOLLAR = 'droplet-dollar.svg'
    DROPLET_DOWN = 'droplet-down.svg'
    DROPLET_EXCLAMATION = 'droplet-exclamation.svg'
    DROPLET_HALF_2 = 'droplet-half-2.svg'
    DROPLET_HALF = 'droplet-half.svg'
    DROPLET_HEART = 'droplet-heart.svg'
    DROPLET_MINUS = 'droplet-minus.svg'
    DROPLET_OFF = 'droplet-off.svg'
    DROPLET_PAUSE = 'droplet-pause.svg'
    DROPLET_PIN = 'droplet-pin.svg'
    DROPLET_PLUS = 'droplet-plus.svg'
    DROPLET_QUESTION = 'droplet-question.svg'
    DROPLET_SEARCH = 'droplet-search.svg'
    DROPLET_SHARE = 'droplet-share.svg'
    DROPLET_STAR = 'droplet-star.svg'
    DROPLET_UP = 'droplet-up.svg'
    DROPLET_X = 'droplet-x.svg'
    DROPLET = 'droplet.svg'
    DROPLETS = 'droplets.svg'
    DUAL_SCREEN = 'dual-screen.svg'
    DUMPLING = 'dumpling.svg'
    E_PASSPORT = 'e-passport.svg'
    EAR_OFF = 'ear-off.svg'
    EAR_SCAN = 'ear-scan.svg'
    EAR = 'ear.svg'
    EASE_IN_CONTROL_POINT = 'ease-in-control-point.svg'
    EASE_IN_OUT_CONTROL_POINTS = 'ease-in-out-control-points.svg'
    EASE_IN_OUT = 'ease-in-out.svg'
    EASE_IN = 'ease-in.svg'
    EASE_OUT_CONTROL_POINT = 'ease-out-control-point.svg'
    EASE_OUT = 'ease-out.svg'
    EDIT_CIRCLE_OFF = 'edit-circle-off.svg'
    EDIT_CIRCLE = 'edit-circle.svg'
    EDIT_OFF = 'edit-off.svg'
    EDIT = 'edit.svg'
    EGG_CRACKED = 'egg-cracked.svg'
    EGG_FRIED = 'egg-fried.svg'
    EGG_OFF = 'egg-off.svg'
    EGG = 'egg.svg'
    EGGS = 'eggs.svg'
    ELEVATOR_OFF = 'elevator-off.svg'
    ELEVATOR = 'elevator.svg'
    EMERGENCY_BED = 'emergency-bed.svg'
    EMPATHIZE_OFF = 'empathize-off.svg'
    EMPATHIZE = 'empathize.svg'
    EMPHASIS = 'emphasis.svg'
    ENGINE_OFF = 'engine-off.svg'
    ENGINE = 'engine.svg'
    EQUAL_DOUBLE = 'equal-double.svg'
    EQUAL_NOT = 'equal-not.svg'
    EQUAL = 'equal.svg'
    ERASER_OFF = 'eraser-off.svg'
    ERASER = 'eraser.svg'
    ERROR_404_OFF = 'error-404-off.svg'
    ERROR_404 = 'error-404.svg'
    ESCALATOR_DOWN = 'escalator-down.svg'
    ESCALATOR_UP = 'escalator-up.svg'
    ESCALATOR = 'escalator.svg'
    EXCHANGE_OFF = 'exchange-off.svg'
    EXCHANGE = 'exchange.svg'
    EXCLAMATION_CIRCLE = 'exclamation-circle.svg'
    EXCLAMATION_MARK_OFF = 'exclamation-mark-off.svg'
    EXCLAMATION_MARK = 'exclamation-mark.svg'
    EXPLICIT_OFF = 'explicit-off.svg'
    EXPLICIT = 'explicit.svg'
    EXPOSURE_0 = 'exposure-0.svg'
    EXPOSURE_MINUS_1 = 'exposure-minus-1.svg'
    EXPOSURE_MINUS_2 = 'exposure-minus-2.svg'
    EXPOSURE_OFF = 'exposure-off.svg'
    EXPOSURE_PLUS_1 = 'exposure-plus-1.svg'
    EXPOSURE_PLUS_2 = 'exposure-plus-2.svg'
    EXPOSURE = 'exposure.svg'
    EXTERNAL_LINK_OFF = 'external-link-off.svg'
    EXTERNAL_LINK = 'external-link.svg'
    EYE_BOLT = 'eye-bolt.svg'
    EYE_CANCEL = 'eye-cancel.svg'
    EYE_CHECK = 'eye-check.svg'
    EYE_CLOSED = 'eye-closed.svg'
    EYE_CODE = 'eye-code.svg'
    EYE_COG = 'eye-cog.svg'
    EYE_DISCOUNT = 'eye-discount.svg'
    EYE_DOLLAR = 'eye-dollar.svg'
    EYE_DOTTED = 'eye-dotted.svg'
    EYE_DOWN = 'eye-down.svg'
    EYE_EDIT = 'eye-edit.svg'
    EYE_EXCLAMATION = 'eye-exclamation.svg'
    EYE_HEART = 'eye-heart.svg'
    EYE_MINUS = 'eye-minus.svg'
    EYE_OFF = 'eye-off.svg'
    EYE_PAUSE = 'eye-pause.svg'
    EYE_PIN = 'eye-pin.svg'
    EYE_PLUS = 'eye-plus.svg'
    EYE_QUESTION = 'eye-question.svg'
    EYE_SEARCH = 'eye-search.svg'
    EYE_SHARE = 'eye-share.svg'
    EYE_STAR = 'eye-star.svg'
    EYE_TABLE = 'eye-table.svg'
    EYE_UP = 'eye-up.svg'
    EYE_X = 'eye-x.svg'
    EYE = 'eye.svg'
    EYEGLASS_2 = 'eyeglass-2.svg'
    EYEGLASS_OFF = 'eyeglass-off.svg'
    EYEGLASS = 'eyeglass.svg'
    FACE_ID_ERROR = 'face-id-error.svg'
    FACE_ID = 'face-id.svg'
    FACE_MASK_OFF = 'face-mask-off.svg'
    FACE_MASK = 'face-mask.svg'
    FALL = 'fall.svg'
    FAVICON = 'favicon.svg'
    FEATHER_OFF = 'feather-off.svg'
    FEATHER = 'feather.svg'
    FENCE_OFF = 'fence-off.svg'
    FENCE = 'fence.svg'
    FIDGET_SPINNER = 'fidget-spinner.svg'
    FILE_3D = 'file-3d.svg'
    FILE_ALERT = 'file-alert.svg'
    FILE_ANALYTICS = 'file-analytics.svg'
    FILE_ARROW_LEFT = 'file-arrow-left.svg'
    FILE_ARROW_RIGHT = 'file-arrow-right.svg'
    FILE_BARCODE = 'file-barcode.svg'
    FILE_BROKEN = 'file-broken.svg'
    FILE_CERTIFICATE = 'file-certificate.svg'
    FILE_CHART = 'file-chart.svg'
    FILE_CHECK = 'file-check.svg'
    FILE_CODE_2 = 'file-code-2.svg'
    FILE_CODE = 'file-code.svg'
    FILE_CV = 'file-cv.svg'
    FILE_DATABASE = 'file-database.svg'
    FILE_DELTA = 'file-delta.svg'
    FILE_DESCRIPTION = 'file-description.svg'
    FILE_DIFF = 'file-diff.svg'
    FILE_DIGIT = 'file-digit.svg'
    FILE_DISLIKE = 'file-dislike.svg'
    FILE_DOLLAR = 'file-dollar.svg'
    FILE_DOTS = 'file-dots.svg'
    FILE_DOWNLOAD = 'file-download.svg'
    FILE_EURO = 'file-euro.svg'
    FILE_EXPORT = 'file-export.svg'
    FILE_FUNCTION = 'file-function.svg'
    FILE_HORIZONTAL = 'file-horizontal.svg'
    FILE_IMPORT = 'file-import.svg'
    FILE_INFINITY = 'file-infinity.svg'
    FILE_INFO = 'file-info.svg'
    FILE_INVOICE = 'file-invoice.svg'
    FILE_ISR = 'file-isr.svg'
    FILE_LAMBDA = 'file-lambda.svg'
    FILE_LIKE = 'file-like.svg'
    FILE_MINUS = 'file-minus.svg'
    FILE_MUSIC = 'file-music.svg'
    FILE_NEUTRAL = 'file-neutral.svg'
    FILE_OFF = 'file-off.svg'
    FILE_ORIENTATION = 'file-orientation.svg'
    FILE_PENCIL = 'file-pencil.svg'
    FILE_PERCENT = 'file-percent.svg'
    FILE_PHONE = 'file-phone.svg'
    FILE_PLUS = 'file-plus.svg'
    FILE_POWER = 'file-power.svg'
    FILE_REPORT = 'file-report.svg'
    FILE_RSS = 'file-rss.svg'
    FILE_SAD = 'file-sad.svg'
    FILE_SCISSORS = 'file-scissors.svg'
    FILE_SEARCH = 'file-search.svg'
    FILE_SETTINGS = 'file-settings.svg'
    FILE_SHREDDER = 'file-shredder.svg'
    FILE_SIGNAL = 'file-signal.svg'
    FILE_SMILE = 'file-smile.svg'
    FILE_SPREADSHEET = 'file-spreadsheet.svg'
    FILE_STACK = 'file-stack.svg'
    FILE_STAR = 'file-star.svg'
    FILE_SYMLINK = 'file-symlink.svg'
    FILE_TEXT_AI = 'file-text-ai.svg'
    FILE_TEXT = 'file-text.svg'
    FILE_TIME = 'file-time.svg'
    FILE_TYPE_BMP = 'file-type-bmp.svg'
    FILE_TYPE_CSS = 'file-type-css.svg'
    FILE_TYPE_CSV = 'file-type-csv.svg'
    FILE_TYPE_DOC = 'file-type-doc.svg'
    FILE_TYPE_DOCX = 'file-type-docx.svg'
    FILE_TYPE_HTML = 'file-type-html.svg'
    FILE_TYPE_JPG = 'file-type-jpg.svg'
    FILE_TYPE_JS = 'file-type-js.svg'
    FILE_TYPE_JSX = 'file-type-jsx.svg'
    FILE_TYPE_PDF = 'file-type-pdf.svg'
    FILE_TYPE_PHP = 'file-type-php.svg'
    FILE_TYPE_PNG = 'file-type-png.svg'
    FILE_TYPE_PPT = 'file-type-ppt.svg'
    FILE_TYPE_RS = 'file-type-rs.svg'
    FILE_TYPE_SQL = 'file-type-sql.svg'
    FILE_TYPE_SVG = 'file-type-svg.svg'
    FILE_TYPE_TS = 'file-type-ts.svg'
    FILE_TYPE_TSX = 'file-type-tsx.svg'
    FILE_TYPE_TXT = 'file-type-txt.svg'
    FILE_TYPE_VUE = 'file-type-vue.svg'
    FILE_TYPE_XLS = 'file-type-xls.svg'
    FILE_TYPE_XML = 'file-type-xml.svg'
    FILE_TYPE_ZIP = 'file-type-zip.svg'
    FILE_TYPOGRAPHY = 'file-typography.svg'
    FILE_UNKNOWN = 'file-unknown.svg'
    FILE_UPLOAD = 'file-upload.svg'
    FILE_VECTOR = 'file-vector.svg'
    FILE_X = 'file-x.svg'
    FILE_ZIP = 'file-zip.svg'
    FILE = 'file.svg'
    FILES_OFF = 'files-off.svg'
    FILES = 'files.svg'
    FILTER_BOLT = 'filter-bolt.svg'
    FILTER_CANCEL = 'filter-cancel.svg'
    FILTER_CHECK = 'filter-check.svg'
    FILTER_CODE = 'filter-code.svg'
    FILTER_COG = 'filter-cog.svg'
    FILTER_DISCOUNT = 'filter-discount.svg'
    FILTER_DOLLAR = 'filter-dollar.svg'
    FILTER_DOWN = 'filter-down.svg'
    FILTER_EDIT = 'filter-edit.svg'
    FILTER_EXCLAMATION = 'filter-exclamation.svg'
    FILTER_HEART = 'filter-heart.svg'
    FILTER_MINUS = 'filter-minus.svg'
    FILTER_OFF = 'filter-off.svg'
    FILTER_PAUSE = 'filter-pause.svg'
    FILTER_PIN = 'filter-pin.svg'
    FILTER_PLUS = 'filter-plus.svg'
    FILTER_QUESTION = 'filter-question.svg'
    FILTER_SEARCH = 'filter-search.svg'
    FILTER_SHARE = 'filter-share.svg'
    FILTER_STAR = 'filter-star.svg'
    FILTER_UP = 'filter-up.svg'
    FILTER_X = 'filter-x.svg'
    FILTER = 'filter.svg'
    FILTERS = 'filters.svg'
    FINGERPRINT_OFF = 'fingerprint-off.svg'
    FINGERPRINT_SCAN = 'fingerprint-scan.svg'
    FINGERPRINT = 'fingerprint.svg'
    FIRE_EXTINGUISHER = 'fire-extinguisher.svg'
    FIRE_HYDRANT_OFF = 'fire-hydrant-off.svg'
    FIRE_HYDRANT = 'fire-hydrant.svg'
    FIRETRUCK = 'firetruck.svg'
    FIRST_AID_KIT_OFF = 'first-aid-kit-off.svg'
    FIRST_AID_KIT = 'first-aid-kit.svg'
    FISH_BONE = 'fish-bone.svg'
    FISH_CHRISTIANITY = 'fish-christianity.svg'
    FISH_HOOK_OFF = 'fish-hook-off.svg'
    FISH_HOOK = 'fish-hook.svg'
    FISH_OFF = 'fish-off.svg'
    FISH = 'fish.svg'
    FLAG_2_OFF = 'flag-2-off.svg'
    FLAG_2 = 'flag-2.svg'
    FLAG_3 = 'flag-3.svg'
    FLAG_BOLT = 'flag-bolt.svg'
    FLAG_CANCEL = 'flag-cancel.svg'
    FLAG_CHECK = 'flag-check.svg'
    FLAG_CODE = 'flag-code.svg'
    FLAG_COG = 'flag-cog.svg'
    FLAG_DISCOUNT = 'flag-discount.svg'
    FLAG_DOLLAR = 'flag-dollar.svg'
    FLAG_DOWN = 'flag-down.svg'
    FLAG_EXCLAMATION = 'flag-exclamation.svg'
    FLAG_HEART = 'flag-heart.svg'
    FLAG_MINUS = 'flag-minus.svg'
    FLAG_OFF = 'flag-off.svg'
    FLAG_PAUSE = 'flag-pause.svg'
    FLAG_PIN = 'flag-pin.svg'
    FLAG_PLUS = 'flag-plus.svg'
    FLAG_QUESTION = 'flag-question.svg'
    FLAG_SEARCH = 'flag-search.svg'
    FLAG_SHARE = 'flag-share.svg'
    FLAG_STAR = 'flag-star.svg'
    FLAG_UP = 'flag-up.svg'
    FLAG_X = 'flag-x.svg'
    FLAG = 'flag.svg'
    FLAME_OFF = 'flame-off.svg'
    FLAME = 'flame.svg'
    FLARE = 'flare.svg'
    FLASK_2_OFF = 'flask-2-off.svg'
    FLASK_2 = 'flask-2.svg'
    FLASK_OFF = 'flask-off.svg'
    FLASK = 'flask.svg'
    FLIP_FLOPS = 'flip-flops.svg'
    FLIP_HORIZONTAL = 'flip-horizontal.svg'
    FLIP_VERTICAL = 'flip-vertical.svg'
    FLOAT_CENTER = 'float-center.svg'
    FLOAT_LEFT = 'float-left.svg'
    FLOAT_NONE = 'float-none.svg'
    FLOAT_RIGHT = 'float-right.svg'
    FLOWER_OFF = 'flower-off.svg'
    FLOWER = 'flower.svg'
    FOCUS_2 = 'focus-2.svg'
    FOCUS_AUTO = 'focus-auto.svg'
    FOCUS_CENTERED = 'focus-centered.svg'
    FOCUS = 'focus.svg'
    FOLD_DOWN = 'fold-down.svg'
    FOLD_UP = 'fold-up.svg'
    FOLD = 'fold.svg'
    FOLDER_BOLT = 'folder-bolt.svg'
    FOLDER_CANCEL = 'folder-cancel.svg'
    FOLDER_CHECK = 'folder-check.svg'
    FOLDER_CODE = 'folder-code.svg'
    FOLDER_COG = 'folder-cog.svg'
    FOLDER_DOLLAR = 'folder-dollar.svg'
    FOLDER_DOWN = 'folder-down.svg'
    FOLDER_EXCLAMATION = 'folder-exclamation.svg'
    FOLDER_HEART = 'folder-heart.svg'
    FOLDER_MINUS = 'folder-minus.svg'
    FOLDER_OFF = 'folder-off.svg'
    FOLDER_OPEN = 'folder-open.svg'
    FOLDER_PAUSE = 'folder-pause.svg'
    FOLDER_PIN = 'folder-pin.svg'
    FOLDER_PLUS = 'folder-plus.svg'
    FOLDER_QUESTION = 'folder-question.svg'
    FOLDER_ROOT = 'folder-root.svg'
    FOLDER_SEARCH = 'folder-search.svg'
    FOLDER_SHARE = 'folder-share.svg'
    FOLDER_STAR = 'folder-star.svg'
    FOLDER_SYMLINK = 'folder-symlink.svg'
    FOLDER_UP = 'folder-up.svg'
    FOLDER_X = 'folder-x.svg'
    FOLDER = 'folder.svg'
    FOLDERS_OFF = 'folders-off.svg'
    FOLDERS = 'folders.svg'
    FORBID_2 = 'forbid-2.svg'
    FORBID = 'forbid.svg'
    FORKLIFT = 'forklift.svg'
    FORMS = 'forms.svg'
    FOUNTAIN_OFF = 'fountain-off.svg'
    FOUNTAIN = 'fountain.svg'
    FRAME_OFF = 'frame-off.svg'
    FRAME = 'frame.svg'
    FREE_RIGHTS = 'free-rights.svg'
    FREEZE_COLUMN = 'freeze-column.svg'
    FREEZE_ROW_COLUMN = 'freeze-row-column.svg'
    FREEZE_ROW = 'freeze-row.svg'
    FRIDGE_OFF = 'fridge-off.svg'
    FRIDGE = 'fridge.svg'
    FRIENDS_OFF = 'friends-off.svg'
    FRIENDS = 'friends.svg'
    FRUSTUM_OFF = 'frustum-off.svg'
    FRUSTUM_PLUS = 'frustum-plus.svg'
    FRUSTUM = 'frustum.svg'
    FUNCTION_OFF = 'function-off.svg'
    FUNCTION = 'function.svg'
    GALAXY = 'galaxy.svg'
    GARDEN_CART_OFF = 'garden-cart-off.svg'
    GARDEN_CART = 'garden-cart.svg'
    GAS_STATION_OFF = 'gas-station-off.svg'
    GAS_STATION = 'gas-station.svg'
    GAUGE_OFF = 'gauge-off.svg'
    GAUGE = 'gauge.svg'
    GAVEL = 'gavel.svg'
    GENDER_AGENDER = 'gender-agender.svg'
    GENDER_ANDROGYNE = 'gender-androgyne.svg'
    GENDER_BIGENDER = 'gender-bigender.svg'
    GENDER_DEMIBOY = 'gender-demiboy.svg'
    GENDER_DEMIGIRL = 'gender-demigirl.svg'
    GENDER_EPICENE = 'gender-epicene.svg'
    GENDER_FEMALE = 'gender-female.svg'
    GENDER_FEMME = 'gender-femme.svg'
    GENDER_GENDERFLUID = 'gender-genderfluid.svg'
    GENDER_GENDERLESS = 'gender-genderless.svg'
    GENDER_GENDERQUEER = 'gender-genderqueer.svg'
    GENDER_HERMAPHRODITE = 'gender-hermaphrodite.svg'
    GENDER_INTERGENDER = 'gender-intergender.svg'
    GENDER_MALE = 'gender-male.svg'
    GENDER_NEUTROIS = 'gender-neutrois.svg'
    GENDER_THIRD = 'gender-third.svg'
    GENDER_TRANSGENDER = 'gender-transgender.svg'
    GENDER_TRASVESTI = 'gender-trasvesti.svg'
    GEOMETRY = 'geometry.svg'
    GHOST_2 = 'ghost-2.svg'
    GHOST_3 = 'ghost-3.svg'
    GHOST_OFF = 'ghost-off.svg'
    GHOST = 'ghost.svg'
    GIF = 'gif.svg'
    GIFT_CARD = 'gift-card.svg'
    GIFT_OFF = 'gift-off.svg'
    GIFT = 'gift.svg'
    GIT_BRANCH_DELETED = 'git-branch-deleted.svg'
    GIT_BRANCH = 'git-branch.svg'
    GIT_CHERRY_PICK = 'git-cherry-pick.svg'
    GIT_COMMIT = 'git-commit.svg'
    GIT_COMPARE = 'git-compare.svg'
    GIT_FORK = 'git-fork.svg'
    GIT_MERGE = 'git-merge.svg'
    GIT_PULL_REQUEST_CLOSED = 'git-pull-request-closed.svg'
    GIT_PULL_REQUEST_DRAFT = 'git-pull-request-draft.svg'
    GIT_PULL_REQUEST = 'git-pull-request.svg'
    GIZMO = 'gizmo.svg'
    GLASS_CHAMPAGNE = 'glass-champagne.svg'
    GLASS_COCKTAIL = 'glass-cocktail.svg'
    GLASS_FULL = 'glass-full.svg'
    GLASS_GIN = 'glass-gin.svg'
    GLASS_OFF = 'glass-off.svg'
    GLASS = 'glass.svg'
    GLOBE_OFF = 'globe-off.svg'
    GLOBE = 'globe.svg'
    GO_GAME = 'go-game.svg'
    GOLF_OFF = 'golf-off.svg'
    GOLF = 'golf.svg'
    GPS = 'gps.svg'
    GRADIENTER = 'gradienter.svg'
    GRAIN = 'grain.svg'
    GRAPH_OFF = 'graph-off.svg'
    GRAPH = 'graph.svg'
    GRAVE_2 = 'grave-2.svg'
    GRAVE = 'grave.svg'
    GRID_3X3 = 'grid-3x3.svg'
    GRID_4X4 = 'grid-4x4.svg'
    GRID_DOTS = 'grid-dots.svg'
    GRID_GOLDENRATIO = 'grid-goldenratio.svg'
    GRID_PATTERN = 'grid-pattern.svg'
    GRID_SCAN = 'grid-scan.svg'
    GRILL_FORK = 'grill-fork.svg'
    GRILL_OFF = 'grill-off.svg'
    GRILL_SPATULA = 'grill-spatula.svg'
    GRILL = 'grill.svg'
    GRIP_HORIZONTAL = 'grip-horizontal.svg'
    GRIP_VERTICAL = 'grip-vertical.svg'
    GROWTH = 'growth.svg'
    GUITAR_PICK = 'guitar-pick.svg'
    GYMNASTICS = 'gymnastics.svg'
    H_1 = 'h-1.svg'
    H_2 = 'h-2.svg'
    H_3 = 'h-3.svg'
    H_4 = 'h-4.svg'
    H_5 = 'h-5.svg'
    H_6 = 'h-6.svg'
    HAMMER_OFF = 'hammer-off.svg'
    HAMMER = 'hammer.svg'
    HAND_CLICK = 'hand-click.svg'
    HAND_FINGER_OFF = 'hand-finger-off.svg'
    HAND_FINGER = 'hand-finger.svg'
    HAND_GRAB = 'hand-grab.svg'
    HAND_LITTLE_FINGER = 'hand-little-finger.svg'
    HAND_LOVE_YOU = 'hand-love-you.svg'
    HAND_MIDDLE_FINGER = 'hand-middle-finger.svg'
    HAND_MOVE = 'hand-move.svg'
    HAND_OFF = 'hand-off.svg'
    HAND_RING_FINGER = 'hand-ring-finger.svg'
    HAND_SANITIZER = 'hand-sanitizer.svg'
    HAND_STOP = 'hand-stop.svg'
    HAND_THREE_FINGERS = 'hand-three-fingers.svg'
    HAND_TWO_FINGERS = 'hand-two-fingers.svg'
    HANGER_2 = 'hanger-2.svg'
    HANGER_OFF = 'hanger-off.svg'
    HANGER = 'hanger.svg'
    HASH = 'hash.svg'
    HAZE_MOON = 'haze-moon.svg'
    HAZE = 'haze.svg'
    HDR = 'hdr.svg'
    HEADING_OFF = 'heading-off.svg'
    HEADING = 'heading.svg'
    HEADPHONES_OFF = 'headphones-off.svg'
    HEADPHONES = 'headphones.svg'
    HEADSET_OFF = 'headset-off.svg'
    HEADSET = 'headset.svg'
    HEALTH_RECOGNITION = 'health-recognition.svg'
    HEART_BOLT = 'heart-bolt.svg'
    HEART_BROKEN = 'heart-broken.svg'
    HEART_CANCEL = 'heart-cancel.svg'
    HEART_CHECK = 'heart-check.svg'
    HEART_CODE = 'heart-code.svg'
    HEART_COG = 'heart-cog.svg'
    HEART_DISCOUNT = 'heart-discount.svg'
    HEART_DOLLAR = 'heart-dollar.svg'
    HEART_DOWN = 'heart-down.svg'
    HEART_EXCLAMATION = 'heart-exclamation.svg'
    HEART_HANDSHAKE = 'heart-handshake.svg'
    HEART_MINUS = 'heart-minus.svg'
    HEART_OFF = 'heart-off.svg'
    HEART_PAUSE = 'heart-pause.svg'
    HEART_PIN = 'heart-pin.svg'
    HEART_PLUS = 'heart-plus.svg'
    HEART_QUESTION = 'heart-question.svg'
    HEART_RATE_MONITOR = 'heart-rate-monitor.svg'
    HEART_SEARCH = 'heart-search.svg'
    HEART_SHARE = 'heart-share.svg'
    HEART_STAR = 'heart-star.svg'
    HEART_UP = 'heart-up.svg'
    HEART_X = 'heart-x.svg'
    HEART = 'heart.svg'
    HEARTBEAT = 'heartbeat.svg'
    HEARTS_OFF = 'hearts-off.svg'
    HEARTS = 'hearts.svg'
    HELICOPTER_LANDING = 'helicopter-landing.svg'
    HELICOPTER = 'helicopter.svg'
    HELMET_OFF = 'helmet-off.svg'
    HELMET = 'helmet.svg'
    HELP_CIRCLE = 'help-circle.svg'
    HELP_HEXAGON = 'help-hexagon.svg'
    HELP_OCTAGON = 'help-octagon.svg'
    HELP_OFF = 'help-off.svg'
    HELP_SMALL = 'help-small.svg'
    HELP_SQUARE_ROUNDED = 'help-square-rounded.svg'
    HELP_SQUARE = 'help-square.svg'
    HELP_TRIANGLE = 'help-triangle.svg'
    HELP = 'help.svg'
    HEMISPHERE_OFF = 'hemisphere-off.svg'
    HEMISPHERE_PLUS = 'hemisphere-plus.svg'
    HEMISPHERE = 'hemisphere.svg'
    HEXAGON_3D = 'hexagon-3d.svg'
    HEXAGON_LETTER_A = 'hexagon-letter-a.svg'
    HEXAGON_LETTER_B = 'hexagon-letter-b.svg'
    HEXAGON_LETTER_C = 'hexagon-letter-c.svg'
    HEXAGON_LETTER_D = 'hexagon-letter-d.svg'
    HEXAGON_LETTER_E = 'hexagon-letter-e.svg'
    HEXAGON_LETTER_F = 'hexagon-letter-f.svg'
    HEXAGON_LETTER_G = 'hexagon-letter-g.svg'
    HEXAGON_LETTER_H = 'hexagon-letter-h.svg'
    HEXAGON_LETTER_I = 'hexagon-letter-i.svg'
    HEXAGON_LETTER_J = 'hexagon-letter-j.svg'
    HEXAGON_LETTER_K = 'hexagon-letter-k.svg'
    HEXAGON_LETTER_L = 'hexagon-letter-l.svg'
    HEXAGON_LETTER_M = 'hexagon-letter-m.svg'
    HEXAGON_LETTER_N = 'hexagon-letter-n.svg'
    HEXAGON_LETTER_O = 'hexagon-letter-o.svg'
    HEXAGON_LETTER_P = 'hexagon-letter-p.svg'
    HEXAGON_LETTER_Q = 'hexagon-letter-q.svg'
    HEXAGON_LETTER_R = 'hexagon-letter-r.svg'
    HEXAGON_LETTER_S = 'hexagon-letter-s.svg'
    HEXAGON_LETTER_T = 'hexagon-letter-t.svg'
    HEXAGON_LETTER_U = 'hexagon-letter-u.svg'
    HEXAGON_LETTER_V = 'hexagon-letter-v.svg'
    HEXAGON_LETTER_W = 'hexagon-letter-w.svg'
    HEXAGON_LETTER_X = 'hexagon-letter-x.svg'
    HEXAGON_LETTER_Y = 'hexagon-letter-y.svg'
    HEXAGON_LETTER_Z = 'hexagon-letter-z.svg'
    HEXAGON_MINUS_2 = 'hexagon-minus-2.svg'
    HEXAGON_MINUS = 'hexagon-minus.svg'
    HEXAGON_NUMBER_0 = 'hexagon-number-0.svg'
    HEXAGON_NUMBER_1 = 'hexagon-number-1.svg'
    HEXAGON_NUMBER_2 = 'hexagon-number-2.svg'
    HEXAGON_NUMBER_3 = 'hexagon-number-3.svg'
    HEXAGON_NUMBER_4 = 'hexagon-number-4.svg'
    HEXAGON_NUMBER_5 = 'hexagon-number-5.svg'
    HEXAGON_NUMBER_6 = 'hexagon-number-6.svg'
    HEXAGON_NUMBER_7 = 'hexagon-number-7.svg'
    HEXAGON_NUMBER_8 = 'hexagon-number-8.svg'
    HEXAGON_NUMBER_9 = 'hexagon-number-9.svg'
    HEXAGON_OFF = 'hexagon-off.svg'
    HEXAGON_PLUS_2 = 'hexagon-plus-2.svg'
    HEXAGON_PLUS = 'hexagon-plus.svg'
    HEXAGON = 'hexagon.svg'
    HEXAGONAL_PRISM_OFF = 'hexagonal-prism-off.svg'
    HEXAGONAL_PRISM_PLUS = 'hexagonal-prism-plus.svg'
    HEXAGONAL_PRISM = 'hexagonal-prism.svg'
    HEXAGONAL_PYRAMID_OFF = 'hexagonal-pyramid-off.svg'
    HEXAGONAL_PYRAMID_PLUS = 'hexagonal-pyramid-plus.svg'
    HEXAGONAL_PYRAMID = 'hexagonal-pyramid.svg'
    HEXAGONS_OFF = 'hexagons-off.svg'
    HEXAGONS = 'hexagons.svg'
    HIERARCHY_2 = 'hierarchy-2.svg'
    HIERARCHY_3 = 'hierarchy-3.svg'
    HIERARCHY_OFF = 'hierarchy-off.svg'
    HIERARCHY = 'hierarchy.svg'
    HIGHLIGHT_OFF = 'highlight-off.svg'
    HIGHLIGHT = 'highlight.svg'
    HISTORY_OFF = 'history-off.svg'
    HISTORY_TOGGLE = 'history-toggle.svg'
    HISTORY = 'history.svg'
    HOME_2 = 'home-2.svg'
    HOME_BOLT = 'home-bolt.svg'
    HOME_CANCEL = 'home-cancel.svg'
    HOME_CHECK = 'home-check.svg'
    HOME_COG = 'home-cog.svg'
    HOME_DOLLAR = 'home-dollar.svg'
    HOME_DOT = 'home-dot.svg'
    HOME_DOWN = 'home-down.svg'
    HOME_ECO = 'home-eco.svg'
    HOME_EDIT = 'home-edit.svg'
    HOME_EXCLAMATION = 'home-exclamation.svg'
    HOME_HAND = 'home-hand.svg'
    HOME_HEART = 'home-heart.svg'
    HOME_INFINITY = 'home-infinity.svg'
    HOME_LINK = 'home-link.svg'
    HOME_MINUS = 'home-minus.svg'
    HOME_MOVE = 'home-move.svg'
    HOME_OFF = 'home-off.svg'
    HOME_PLUS = 'home-plus.svg'
    HOME_QUESTION = 'home-question.svg'
    HOME_RIBBON = 'home-ribbon.svg'
    HOME_SEARCH = 'home-search.svg'
    HOME_SHARE = 'home-share.svg'
    HOME_SHIELD = 'home-shield.svg'
    HOME_SIGNAL = 'home-signal.svg'
    HOME_STAR = 'home-star.svg'
    HOME_STATS = 'home-stats.svg'
    HOME_UP = 'home-up.svg'
    HOME_X = 'home-x.svg'
    HOME = 'home.svg'
    HORSE_TOY = 'horse-toy.svg'
    HORSE = 'horse.svg'
    HORSESHOE = 'horseshoe.svg'
    HOSPITAL_CIRCLE = 'hospital-circle.svg'
    HOSPITAL = 'hospital.svg'
    HOTEL_SERVICE = 'hotel-service.svg'
    HOURGLASS_EMPTY = 'hourglass-empty.svg'
    HOURGLASS_HIGH = 'hourglass-high.svg'
    HOURGLASS_LOW = 'hourglass-low.svg'
    HOURGLASS_OFF = 'hourglass-off.svg'
    HOURGLASS = 'hourglass.svg'
    HOURS_12 = 'hours-12.svg'
    HOURS_24 = 'hours-24.svg'
    HTML = 'html.svg'
    HTTP_CONNECT = 'http-connect.svg'
    HTTP_DELETE = 'http-delete.svg'
    HTTP_GET = 'http-get.svg'
    HTTP_HEAD = 'http-head.svg'
    HTTP_OPTIONS = 'http-options.svg'
    HTTP_PATCH = 'http-patch.svg'
    HTTP_POST = 'http-post.svg'
    HTTP_PUT = 'http-put.svg'
    HTTP_QUE = 'http-que.svg'
    HTTP_TRACE = 'http-trace.svg'
    ICE_CREAM_2 = 'ice-cream-2.svg'
    ICE_CREAM_OFF = 'ice-cream-off.svg'
    ICE_CREAM = 'ice-cream.svg'
    ICE_SKATING = 'ice-skating.svg'
    ICONS_OFF = 'icons-off.svg'
    ICONS = 'icons.svg'
    ID_BADGE_2 = 'id-badge-2.svg'
    ID_BADGE_OFF = 'id-badge-off.svg'
    ID_BADGE = 'id-badge.svg'
    ID_OFF = 'id-off.svg'
    ID = 'id.svg'
    IMAGE_IN_PICTURE = 'image-in-picture.svg'
    INBOX_OFF = 'inbox-off.svg'
    INBOX = 'inbox.svg'
    INDENT_DECREASE = 'indent-decrease.svg'
    INDENT_INCREASE = 'indent-increase.svg'
    INFINITY_OFF = 'infinity-off.svg'
    INFINITY = 'infinity.svg'
    INFO_CIRCLE = 'info-circle.svg'
    INFO_HEXAGON = 'info-hexagon.svg'
    INFO_OCTAGON = 'info-octagon.svg'
    INFO_SMALL = 'info-small.svg'
    INFO_SQUARE_ROUNDED = 'info-square-rounded.svg'
    INFO_SQUARE = 'info-square.svg'
    INFO_TRIANGLE = 'info-triangle.svg'
    INNER_SHADOW_BOTTOM_LEFT = 'inner-shadow-bottom-left.svg'
    INNER_SHADOW_BOTTOM_RIGHT = 'inner-shadow-bottom-right.svg'
    INNER_SHADOW_BOTTOM = 'inner-shadow-bottom.svg'
    INNER_SHADOW_LEFT = 'inner-shadow-left.svg'
    INNER_SHADOW_RIGHT = 'inner-shadow-right.svg'
    INNER_SHADOW_TOP_LEFT = 'inner-shadow-top-left.svg'
    INNER_SHADOW_TOP_RIGHT = 'inner-shadow-top-right.svg'
    INNER_SHADOW_TOP = 'inner-shadow-top.svg'
    INPUT_AI = 'input-ai.svg'
    INPUT_CHECK = 'input-check.svg'
    INPUT_SEARCH = 'input-search.svg'
    INPUT_X = 'input-x.svg'
    INVOICE = 'invoice.svg'
    IRONING_1 = 'ironing-1.svg'
    IRONING_2 = 'ironing-2.svg'
    IRONING_3 = 'ironing-3.svg'
    IRONING_OFF = 'ironing-off.svg'
    IRONING_STEAM_OFF = 'ironing-steam-off.svg'
    IRONING_STEAM = 'ironing-steam.svg'
    IRONING = 'ironing.svg'
    IRREGULAR_POLYHEDRON_OFF = 'irregular-polyhedron-off.svg'
    IRREGULAR_POLYHEDRON_PLUS = 'irregular-polyhedron-plus.svg'
    IRREGULAR_POLYHEDRON = 'irregular-polyhedron.svg'
    ITALIC = 'italic.svg'
    JACKET = 'jacket.svg'
    JETPACK = 'jetpack.svg'
    JEWISH_STAR = 'jewish-star.svg'
    JPG = 'jpg.svg'
    JSON = 'json.svg'
    JUMP_ROPE = 'jump-rope.svg'
    KARATE = 'karate.svg'
    KAYAK = 'kayak.svg'
    KERNING = 'kerning.svg'
    KEY_OFF = 'key-off.svg'
    KEY = 'key.svg'
    KEYBOARD_HIDE = 'keyboard-hide.svg'
    KEYBOARD_OFF = 'keyboard-off.svg'
    KEYBOARD_SHOW = 'keyboard-show.svg'
    KEYBOARD = 'keyboard.svg'
    KEYFRAME_ALIGN_CENTER = 'keyframe-align-center.svg'
    KEYFRAME_ALIGN_HORIZONTAL = 'keyframe-align-horizontal.svg'
    KEYFRAME_ALIGN_VERTICAL = 'keyframe-align-vertical.svg'
    KEYFRAME = 'keyframe.svg'
    KEYFRAMES = 'keyframes.svg'
    LADDER_OFF = 'ladder-off.svg'
    LADDER = 'ladder.svg'
    LADLE = 'ladle.svg'
    LAMBDA = 'lambda.svg'
    LAMP_2 = 'lamp-2.svg'
    LAMP_OFF = 'lamp-off.svg'
    LAMP = 'lamp.svg'
    LANE = 'lane.svg'
    LANGUAGE_HIRAGANA = 'language-hiragana.svg'
    LANGUAGE_KATAKANA = 'language-katakana.svg'
    LANGUAGE_OFF = 'language-off.svg'
    LANGUAGE = 'language.svg'
    LASSO_OFF = 'lasso-off.svg'
    LASSO_POLYGON = 'lasso-polygon.svg'
    LASSO = 'lasso.svg'
    LAYERS_DIFFERENCE = 'layers-difference.svg'
    LAYERS_INTERSECT_2 = 'layers-intersect-2.svg'
    LAYERS_INTERSECT = 'layers-intersect.svg'
    LAYERS_LINKED = 'layers-linked.svg'
    LAYERS_OFF = 'layers-off.svg'
    LAYERS_SELECTED_BOTTOM = 'layers-selected-bottom.svg'
    LAYERS_SELECTED = 'layers-selected.svg'
    LAYERS_SUBTRACT = 'layers-subtract.svg'
    LAYERS_UNION = 'layers-union.svg'
    LAYOUT_2 = 'layout-2.svg'
    LAYOUT_ALIGN_BOTTOM = 'layout-align-bottom.svg'
    LAYOUT_ALIGN_CENTER = 'layout-align-center.svg'
    LAYOUT_ALIGN_LEFT = 'layout-align-left.svg'
    LAYOUT_ALIGN_MIDDLE = 'layout-align-middle.svg'
    LAYOUT_ALIGN_RIGHT = 'layout-align-right.svg'
    LAYOUT_ALIGN_TOP = 'layout-align-top.svg'
    LAYOUT_BOARD_SPLIT = 'layout-board-split.svg'
    LAYOUT_BOARD = 'layout-board.svg'
    LAYOUT_BOTTOMBAR_COLLAPSE = 'layout-bottombar-collapse.svg'
    LAYOUT_BOTTOMBAR_EXPAND = 'layout-bottombar-expand.svg'
    LAYOUT_BOTTOMBAR_INACTIVE = 'layout-bottombar-inactive.svg'
    LAYOUT_BOTTOMBAR = 'layout-bottombar.svg'
    LAYOUT_CARDS = 'layout-cards.svg'
    LAYOUT_COLLAGE = 'layout-collage.svg'
    LAYOUT_COLUMNS = 'layout-columns.svg'
    LAYOUT_DASHBOARD = 'layout-dashboard.svg'
    LAYOUT_DISTRIBUTE_HORIZONTAL = 'layout-distribute-horizontal.svg'
    LAYOUT_DISTRIBUTE_VERTICAL = 'layout-distribute-vertical.svg'
    LAYOUT_GRID_ADD = 'layout-grid-add.svg'
    LAYOUT_GRID_REMOVE = 'layout-grid-remove.svg'
    LAYOUT_GRID = 'layout-grid.svg'
    LAYOUT_KANBAN = 'layout-kanban.svg'
    LAYOUT_LIST = 'layout-list.svg'
    LAYOUT_NAVBAR_COLLAPSE = 'layout-navbar-collapse.svg'
    LAYOUT_NAVBAR_EXPAND = 'layout-navbar-expand.svg'
    LAYOUT_NAVBAR_INACTIVE = 'layout-navbar-inactive.svg'
    LAYOUT_NAVBAR = 'layout-navbar.svg'
    LAYOUT_OFF = 'layout-off.svg'
    LAYOUT_ROWS = 'layout-rows.svg'
    LAYOUT_SIDEBAR_INACTIVE = 'layout-sidebar-inactive.svg'
    LAYOUT_SIDEBAR_LEFT_COLLAPSE = 'layout-sidebar-left-collapse.svg'
    LAYOUT_SIDEBAR_LEFT_EXPAND = 'layout-sidebar-left-expand.svg'
    LAYOUT_SIDEBAR_RIGHT_COLLAPSE = 'layout-sidebar-right-collapse.svg'
    LAYOUT_SIDEBAR_RIGHT_EXPAND = 'layout-sidebar-right-expand.svg'
    LAYOUT_SIDEBAR_RIGHT_INACTIVE = 'layout-sidebar-right-inactive.svg'
    LAYOUT_SIDEBAR_RIGHT = 'layout-sidebar-right.svg'
    LAYOUT_SIDEBAR = 'layout-sidebar.svg'
    LAYOUT = 'layout.svg'
    LEAF_OFF = 'leaf-off.svg'
    LEAF = 'leaf.svg'
    LEGO_OFF = 'lego-off.svg'
    LEGO = 'lego.svg'
    LEMON_2 = 'lemon-2.svg'
    LEMON = 'lemon.svg'
    LETTER_A_SMALL = 'letter-a-small.svg'
    LETTER_A = 'letter-a.svg'
    LETTER_B_SMALL = 'letter-b-small.svg'
    LETTER_B = 'letter-b.svg'
    LETTER_C_SMALL = 'letter-c-small.svg'
    LETTER_C = 'letter-c.svg'
    LETTER_CASE_LOWER = 'letter-case-lower.svg'
    LETTER_CASE_TOGGLE = 'letter-case-toggle.svg'
    LETTER_CASE_UPPER = 'letter-case-upper.svg'
    LETTER_CASE = 'letter-case.svg'
    LETTER_D_SMALL = 'letter-d-small.svg'
    LETTER_D = 'letter-d.svg'
    LETTER_E_SMALL = 'letter-e-small.svg'
    LETTER_E = 'letter-e.svg'
    LETTER_F_SMALL = 'letter-f-small.svg'
    LETTER_F = 'letter-f.svg'
    LETTER_G_SMALL = 'letter-g-small.svg'
    LETTER_G = 'letter-g.svg'
    LETTER_H_SMALL = 'letter-h-small.svg'
    LETTER_H = 'letter-h.svg'
    LETTER_I_SMALL = 'letter-i-small.svg'
    LETTER_I = 'letter-i.svg'
    LETTER_J_SMALL = 'letter-j-small.svg'
    LETTER_J = 'letter-j.svg'
    LETTER_K_SMALL = 'letter-k-small.svg'
    LETTER_K = 'letter-k.svg'
    LETTER_L_SMALL = 'letter-l-small.svg'
    LETTER_L = 'letter-l.svg'
    LETTER_M_SMALL = 'letter-m-small.svg'
    LETTER_M = 'letter-m.svg'
    LETTER_N_SMALL = 'letter-n-small.svg'
    LETTER_N = 'letter-n.svg'
    LETTER_O_SMALL = 'letter-o-small.svg'
    LETTER_O = 'letter-o.svg'
    LETTER_P_SMALL = 'letter-p-small.svg'
    LETTER_P = 'letter-p.svg'
    LETTER_Q_SMALL = 'letter-q-small.svg'
    LETTER_Q = 'letter-q.svg'
    LETTER_R_SMALL = 'letter-r-small.svg'
    LETTER_R = 'letter-r.svg'
    LETTER_S_SMALL = 'letter-s-small.svg'
    LETTER_S = 'letter-s.svg'
    LETTER_SPACING = 'letter-spacing.svg'
    LETTER_T_SMALL = 'letter-t-small.svg'
    LETTER_T = 'letter-t.svg'
    LETTER_U_SMALL = 'letter-u-small.svg'
    LETTER_U = 'letter-u.svg'
    LETTER_V_SMALL = 'letter-v-small.svg'
    LETTER_V = 'letter-v.svg'
    LETTER_W_SMALL = 'letter-w-small.svg'
    LETTER_W = 'letter-w.svg'
    LETTER_X_SMALL = 'letter-x-small.svg'
    LETTER_X = 'letter-x.svg'
    LETTER_Y_SMALL = 'letter-y-small.svg'
    LETTER_Y = 'letter-y.svg'
    LETTER_Z_SMALL = 'letter-z-small.svg'
    LETTER_Z = 'letter-z.svg'
    LIBRARY_MINUS = 'library-minus.svg'
    LIBRARY_PHOTO = 'library-photo.svg'
    LIBRARY_PLUS = 'library-plus.svg'
    LIBRARY = 'library.svg'
    LICENSE_OFF = 'license-off.svg'
    LICENSE = 'license.svg'
    LIFEBUOY_OFF = 'lifebuoy-off.svg'
    LIFEBUOY = 'lifebuoy.svg'
    LIGHTER = 'lighter.svg'
    LINE_DASHED = 'line-dashed.svg'
    LINE_DOTTED = 'line-dotted.svg'
    LINE_HEIGHT = 'line-height.svg'
    LINE_SCAN = 'line-scan.svg'
    LINE = 'line.svg'
    LINK_MINUS = 'link-minus.svg'
    LINK_OFF = 'link-off.svg'
    LINK_PLUS = 'link-plus.svg'
    LINK = 'link.svg'
    LIST_CHECK = 'list-check.svg'
    LIST_DETAILS = 'list-details.svg'
    LIST_LETTERS = 'list-letters.svg'
    LIST_NUMBERS = 'list-numbers.svg'
    LIST_SEARCH = 'list-search.svg'
    LIST_TREE = 'list-tree.svg'
    LIST = 'list.svg'
    LIVE_PHOTO_OFF = 'live-photo-off.svg'
    LIVE_PHOTO = 'live-photo.svg'
    LIVE_VIEW = 'live-view.svg'
    LOAD_BALANCER = 'load-balancer.svg'
    LOADER_2 = 'loader-2.svg'
    LOADER_3 = 'loader-3.svg'
    LOADER_QUARTER = 'loader-quarter.svg'
    LOADER = 'loader.svg'
    LOCATION_BOLT = 'location-bolt.svg'
    LOCATION_BROKEN = 'location-broken.svg'
    LOCATION_CANCEL = 'location-cancel.svg'
    LOCATION_CHECK = 'location-check.svg'
    LOCATION_CODE = 'location-code.svg'
    LOCATION_COG = 'location-cog.svg'
    LOCATION_DISCOUNT = 'location-discount.svg'
    LOCATION_DOLLAR = 'location-dollar.svg'
    LOCATION_DOWN = 'location-down.svg'
    LOCATION_EXCLAMATION = 'location-exclamation.svg'
    LOCATION_HEART = 'location-heart.svg'
    LOCATION_MINUS = 'location-minus.svg'
    LOCATION_OFF = 'location-off.svg'
    LOCATION_PAUSE = 'location-pause.svg'
    LOCATION_PIN = 'location-pin.svg'
    LOCATION_PLUS = 'location-plus.svg'
    LOCATION_QUESTION = 'location-question.svg'
    LOCATION_SEARCH = 'location-search.svg'
    LOCATION_SHARE = 'location-share.svg'
    LOCATION_STAR = 'location-star.svg'
    LOCATION_UP = 'location-up.svg'
    LOCATION_X = 'location-x.svg'
    LOCATION = 'location.svg'
    LOCK_ACCESS_OFF = 'lock-access-off.svg'
    LOCK_ACCESS = 'lock-access.svg'
    LOCK_BOLT = 'lock-bolt.svg'
    LOCK_CANCEL = 'lock-cancel.svg'
    LOCK_CHECK = 'lock-check.svg'
    LOCK_CODE = 'lock-code.svg'
    LOCK_COG = 'lock-cog.svg'
    LOCK_DOLLAR = 'lock-dollar.svg'
    LOCK_DOWN = 'lock-down.svg'
    LOCK_EXCLAMATION = 'lock-exclamation.svg'
    LOCK_HEART = 'lock-heart.svg'
    LOCK_MINUS = 'lock-minus.svg'
    LOCK_OFF = 'lock-off.svg'
    LOCK_OPEN_2 = 'lock-open-2.svg'
    LOCK_OPEN_OFF = 'lock-open-off.svg'
    LOCK_OPEN = 'lock-open.svg'
    LOCK_PAUSE = 'lock-pause.svg'
    LOCK_PIN = 'lock-pin.svg'
    LOCK_PLUS = 'lock-plus.svg'
    LOCK_QUESTION = 'lock-question.svg'
    LOCK_SEARCH = 'lock-search.svg'
    LOCK_SHARE = 'lock-share.svg'
    LOCK_SQUARE_ROUNDED = 'lock-square-rounded.svg'
    LOCK_SQUARE = 'lock-square.svg'
    LOCK_STAR = 'lock-star.svg'
    LOCK_UP = 'lock-up.svg'
    LOCK_X = 'lock-x.svg'
    LOCK = 'lock.svg'
    LOGIC_AND = 'logic-and.svg'
    LOGIC_BUFFER = 'logic-buffer.svg'
    LOGIC_NAND = 'logic-nand.svg'
    LOGIC_NOR = 'logic-nor.svg'
    LOGIC_NOT = 'logic-not.svg'
    LOGIC_OR = 'logic-or.svg'
    LOGIC_XNOR = 'logic-xnor.svg'
    LOGIC_XOR = 'logic-xor.svg'
    LOGIN_2 = 'login-2.svg'
    LOGIN = 'login.svg'
    LOGOUT_2 = 'logout-2.svg'
    LOGOUT = 'logout.svg'
    LOGS = 'logs.svg'
    LOLLIPOP_OFF = 'lollipop-off.svg'
    LOLLIPOP = 'lollipop.svg'
    LUGGAGE_OFF = 'luggage-off.svg'
    LUGGAGE = 'luggage.svg'
    LUNGS_OFF = 'lungs-off.svg'
    LUNGS = 'lungs.svg'
    MACRO_OFF = 'macro-off.svg'
    MACRO = 'macro.svg'
    MAGNET_OFF = 'magnet-off.svg'
    MAGNET = 'magnet.svg'
    MAGNETIC = 'magnetic.svg'
    MAIL_AI = 'mail-ai.svg'
    MAIL_BOLT = 'mail-bolt.svg'
    MAIL_CANCEL = 'mail-cancel.svg'
    MAIL_CHECK = 'mail-check.svg'
    MAIL_CODE = 'mail-code.svg'
    MAIL_COG = 'mail-cog.svg'
    MAIL_DOLLAR = 'mail-dollar.svg'
    MAIL_DOWN = 'mail-down.svg'
    MAIL_EXCLAMATION = 'mail-exclamation.svg'
    MAIL_FAST = 'mail-fast.svg'
    MAIL_FORWARD = 'mail-forward.svg'
    MAIL_HEART = 'mail-heart.svg'
    MAIL_MINUS = 'mail-minus.svg'
    MAIL_OFF = 'mail-off.svg'
    MAIL_OPENED = 'mail-opened.svg'
    MAIL_PAUSE = 'mail-pause.svg'
    MAIL_PIN = 'mail-pin.svg'
    MAIL_PLUS = 'mail-plus.svg'
    MAIL_QUESTION = 'mail-question.svg'
    MAIL_SEARCH = 'mail-search.svg'
    MAIL_SHARE = 'mail-share.svg'
    MAIL_STAR = 'mail-star.svg'
    MAIL_UP = 'mail-up.svg'
    MAIL_X = 'mail-x.svg'
    MAIL = 'mail.svg'
    MAILBOX_OFF = 'mailbox-off.svg'
    MAILBOX = 'mailbox.svg'
    MAN = 'man.svg'
    MANUAL_GEARBOX = 'manual-gearbox.svg'
    MAP_2 = 'map-2.svg'
    MAP_BOLT = 'map-bolt.svg'
    MAP_CANCEL = 'map-cancel.svg'
    MAP_CHECK = 'map-check.svg'
    MAP_CODE = 'map-code.svg'
    MAP_COG = 'map-cog.svg'
    MAP_DISCOUNT = 'map-discount.svg'
    MAP_DOLLAR = 'map-dollar.svg'
    MAP_DOWN = 'map-down.svg'
    MAP_EAST = 'map-east.svg'
    MAP_EXCLAMATION = 'map-exclamation.svg'
    MAP_HEART = 'map-heart.svg'
    MAP_MINUS = 'map-minus.svg'
    MAP_NORTH = 'map-north.svg'
    MAP_OFF = 'map-off.svg'
    MAP_PAUSE = 'map-pause.svg'
    MAP_PIN_2 = 'map-pin-2.svg'
    MAP_PIN_BOLT = 'map-pin-bolt.svg'
    MAP_PIN_CANCEL = 'map-pin-cancel.svg'
    MAP_PIN_CHECK = 'map-pin-check.svg'
    MAP_PIN_CODE = 'map-pin-code.svg'
    MAP_PIN_COG = 'map-pin-cog.svg'
    MAP_PIN_DOLLAR = 'map-pin-dollar.svg'
    MAP_PIN_DOWN = 'map-pin-down.svg'
    MAP_PIN_EXCLAMATION = 'map-pin-exclamation.svg'
    MAP_PIN_HEART = 'map-pin-heart.svg'
    MAP_PIN_MINUS = 'map-pin-minus.svg'
    MAP_PIN_OFF = 'map-pin-off.svg'
    MAP_PIN_PAUSE = 'map-pin-pause.svg'
    MAP_PIN_PIN = 'map-pin-pin.svg'
    MAP_PIN_PLUS = 'map-pin-plus.svg'
    MAP_PIN_QUESTION = 'map-pin-question.svg'
    MAP_PIN_SEARCH = 'map-pin-search.svg'
    MAP_PIN_SHARE = 'map-pin-share.svg'
    MAP_PIN_STAR = 'map-pin-star.svg'
    MAP_PIN_UP = 'map-pin-up.svg'
    MAP_PIN_X = 'map-pin-x.svg'
    MAP_PIN = 'map-pin.svg'
    MAP_PINS = 'map-pins.svg'
    MAP_PLUS = 'map-plus.svg'
    MAP_QUESTION = 'map-question.svg'
    MAP_ROUTE = 'map-route.svg'
    MAP_SEARCH = 'map-search.svg'
    MAP_SHARE = 'map-share.svg'
    MAP_SOUTH = 'map-south.svg'
    MAP_STAR = 'map-star.svg'
    MAP_UP = 'map-up.svg'
    MAP_WEST = 'map-west.svg'
    MAP_X = 'map-x.svg'
    MAP = 'map.svg'
    MARKDOWN_OFF = 'markdown-off.svg'
    MARKDOWN = 'markdown.svg'
    MARQUEE_2 = 'marquee-2.svg'
    MARQUEE_OFF = 'marquee-off.svg'
    MARQUEE = 'marquee.svg'
    MARS = 'mars.svg'
    MASK_OFF = 'mask-off.svg'
    MASK = 'mask.svg'
    MASKS_THEATER_OFF = 'masks-theater-off.svg'
    MASKS_THEATER = 'masks-theater.svg'
    MASSAGE = 'massage.svg'
    MATCHSTICK = 'matchstick.svg'
    MATH_1_DIVIDE_2 = 'math-1-divide-2.svg'
    MATH_1_DIVIDE_3 = 'math-1-divide-3.svg'
    MATH_AVG = 'math-avg.svg'
    MATH_EQUAL_GREATER = 'math-equal-greater.svg'
    MATH_EQUAL_LOWER = 'math-equal-lower.svg'
    MATH_FUNCTION_OFF = 'math-function-off.svg'
    MATH_FUNCTION_Y = 'math-function-y.svg'
    MATH_FUNCTION = 'math-function.svg'
    MATH_GREATER = 'math-greater.svg'
    MATH_INTEGRAL_X = 'math-integral-x.svg'
    MATH_INTEGRAL = 'math-integral.svg'
    MATH_INTEGRALS = 'math-integrals.svg'
    MATH_LOWER = 'math-lower.svg'
    MATH_MAX_MIN = 'math-max-min.svg'
    MATH_MAX = 'math-max.svg'
    MATH_MIN = 'math-min.svg'
    MATH_NOT = 'math-not.svg'
    MATH_OFF = 'math-off.svg'
    MATH_PI_DIVIDE_2 = 'math-pi-divide-2.svg'
    MATH_PI = 'math-pi.svg'
    MATH_SYMBOLS = 'math-symbols.svg'
    MATH_X_DIVIDE_2 = 'math-x-divide-2.svg'
    MATH_X_DIVIDE_Y_2 = 'math-x-divide-y-2.svg'
    MATH_X_DIVIDE_Y = 'math-x-divide-y.svg'
    MATH_X_MINUS_X = 'math-x-minus-x.svg'
    MATH_X_MINUS_Y = 'math-x-minus-y.svg'
    MATH_X_PLUS_X = 'math-x-plus-x.svg'
    MATH_X_PLUS_Y = 'math-x-plus-y.svg'
    MATH_XY = 'math-xy.svg'
    MATH_Y_MINUS_Y = 'math-y-minus-y.svg'
    MATH_Y_PLUS_Y = 'math-y-plus-y.svg'
    MATH = 'math.svg'
    MAXIMIZE_OFF = 'maximize-off.svg'
    MAXIMIZE = 'maximize.svg'
    MEAT_OFF = 'meat-off.svg'
    MEAT = 'meat.svg'
    MEDAL_2 = 'medal-2.svg'
    MEDAL = 'medal.svg'
    MEDICAL_CROSS_CIRCLE = 'medical-cross-circle.svg'
    MEDICAL_CROSS_OFF = 'medical-cross-off.svg'
    MEDICAL_CROSS = 'medical-cross.svg'
    MEDICINE_SYRUP = 'medicine-syrup.svg'
    MEEPLE = 'meeple.svg'
    MELON = 'melon.svg'
    MENORAH = 'menorah.svg'
    MENU_2 = 'menu-2.svg'
    MENU_DEEP = 'menu-deep.svg'
    MENU_ORDER = 'menu-order.svg'
    MENU = 'menu.svg'
    MESSAGE_2_BOLT = 'message-2-bolt.svg'
    MESSAGE_2_CANCEL = 'message-2-cancel.svg'
    MESSAGE_2_CHECK = 'message-2-check.svg'
    MESSAGE_2_CODE = 'message-2-code.svg'
    MESSAGE_2_COG = 'message-2-cog.svg'
    MESSAGE_2_DOLLAR = 'message-2-dollar.svg'
    MESSAGE_2_DOWN = 'message-2-down.svg'
    MESSAGE_2_EXCLAMATION = 'message-2-exclamation.svg'
    MESSAGE_2_HEART = 'message-2-heart.svg'
    MESSAGE_2_MINUS = 'message-2-minus.svg'
    MESSAGE_2_OFF = 'message-2-off.svg'
    MESSAGE_2_PAUSE = 'message-2-pause.svg'
    MESSAGE_2_PIN = 'message-2-pin.svg'
    MESSAGE_2_PLUS = 'message-2-plus.svg'
    MESSAGE_2_QUESTION = 'message-2-question.svg'
    MESSAGE_2_SEARCH = 'message-2-search.svg'
    MESSAGE_2_SHARE = 'message-2-share.svg'
    MESSAGE_2_STAR = 'message-2-star.svg'
    MESSAGE_2_UP = 'message-2-up.svg'
    MESSAGE_2_X = 'message-2-x.svg'
    MESSAGE_2 = 'message-2.svg'
    MESSAGE_BOLT = 'message-bolt.svg'
    MESSAGE_CANCEL = 'message-cancel.svg'
    MESSAGE_CHATBOT = 'message-chatbot.svg'
    MESSAGE_CHECK = 'message-check.svg'
    MESSAGE_CIRCLE_2 = 'message-circle-2.svg'
    MESSAGE_CIRCLE_BOLT = 'message-circle-bolt.svg'
    MESSAGE_CIRCLE_CANCEL = 'message-circle-cancel.svg'
    MESSAGE_CIRCLE_CHECK = 'message-circle-check.svg'
    MESSAGE_CIRCLE_CODE = 'message-circle-code.svg'
    MESSAGE_CIRCLE_COG = 'message-circle-cog.svg'
    MESSAGE_CIRCLE_DOLLAR = 'message-circle-dollar.svg'
    MESSAGE_CIRCLE_DOWN = 'message-circle-down.svg'
    MESSAGE_CIRCLE_EXCLAMATION = 'message-circle-exclamation.svg'
    MESSAGE_CIRCLE_HEART = 'message-circle-heart.svg'
    MESSAGE_CIRCLE_MINUS = 'message-circle-minus.svg'
    MESSAGE_CIRCLE_OFF = 'message-circle-off.svg'
    MESSAGE_CIRCLE_PAUSE = 'message-circle-pause.svg'
    MESSAGE_CIRCLE_PIN = 'message-circle-pin.svg'
    MESSAGE_CIRCLE_PLUS = 'message-circle-plus.svg'
    MESSAGE_CIRCLE_QUESTION = 'message-circle-question.svg'
    MESSAGE_CIRCLE_SEARCH = 'message-circle-search.svg'
    MESSAGE_CIRCLE_SHARE = 'message-circle-share.svg'
    MESSAGE_CIRCLE_STAR = 'message-circle-star.svg'
    MESSAGE_CIRCLE_UP = 'message-circle-up.svg'
    MESSAGE_CIRCLE_X = 'message-circle-x.svg'
    MESSAGE_CIRCLE = 'message-circle.svg'
    MESSAGE_CODE = 'message-code.svg'
    MESSAGE_COG = 'message-cog.svg'
    MESSAGE_DOLLAR = 'message-dollar.svg'
    MESSAGE_DOTS = 'message-dots.svg'
    MESSAGE_DOWN = 'message-down.svg'
    MESSAGE_EXCLAMATION = 'message-exclamation.svg'
    MESSAGE_FORWARD = 'message-forward.svg'
    MESSAGE_HEART = 'message-heart.svg'
    MESSAGE_LANGUAGE = 'message-language.svg'
    MESSAGE_MINUS = 'message-minus.svg'
    MESSAGE_OFF = 'message-off.svg'
    MESSAGE_PAUSE = 'message-pause.svg'
    MESSAGE_PIN = 'message-pin.svg'
    MESSAGE_PLUS = 'message-plus.svg'
    MESSAGE_QUESTION = 'message-question.svg'
    MESSAGE_REPLY = 'message-reply.svg'
    MESSAGE_REPORT = 'message-report.svg'
    MESSAGE_SEARCH = 'message-search.svg'
    MESSAGE_SHARE = 'message-share.svg'
    MESSAGE_STAR = 'message-star.svg'
    MESSAGE_UP = 'message-up.svg'
    MESSAGE_X = 'message-x.svg'
    MESSAGE = 'message.svg'
    MESSAGES_OFF = 'messages-off.svg'
    MESSAGES = 'messages.svg'
    METEOR_OFF = 'meteor-off.svg'
    METEOR = 'meteor.svg'
    METER_CUBE = 'meter-cube.svg'
    METER_SQUARE = 'meter-square.svg'
    METRONOME = 'metronome.svg'
    MICHELIN_BIB_GOURMAND = 'michelin-bib-gourmand.svg'
    MICHELIN_STAR_GREEN = 'michelin-star-green.svg'
    MICHELIN_STAR = 'michelin-star.svg'
    MICKEY = 'mickey.svg'
    MICROPHONE_2_OFF = 'microphone-2-off.svg'
    MICROPHONE_2 = 'microphone-2.svg'
    MICROPHONE_OFF = 'microphone-off.svg'
    MICROPHONE = 'microphone.svg'
    MICROSCOPE_OFF = 'microscope-off.svg'
    MICROSCOPE = 'microscope.svg'
    MICROWAVE_OFF = 'microwave-off.svg'
    MICROWAVE = 'microwave.svg'
    MILITARY_AWARD = 'military-award.svg'
    MILITARY_RANK = 'military-rank.svg'
    MILK_OFF = 'milk-off.svg'
    MILK = 'milk.svg'
    MILKSHAKE = 'milkshake.svg'
    MINIMIZE = 'minimize.svg'
    MINUS_VERTICAL = 'minus-vertical.svg'
    MINUS = 'minus.svg'
    MIST_OFF = 'mist-off.svg'
    MIST = 'mist.svg'
    MOBILEDATA_OFF = 'mobiledata-off.svg'
    MOBILEDATA = 'mobiledata.svg'
    MONEYBAG = 'moneybag.svg'
    MONKEYBAR = 'monkeybar.svg'
    MOOD_ANGRY = 'mood-angry.svg'
    MOOD_ANNOYED_2 = 'mood-annoyed-2.svg'
    MOOD_ANNOYED = 'mood-annoyed.svg'
    MOOD_BOY = 'mood-boy.svg'
    MOOD_CHECK = 'mood-check.svg'
    MOOD_COG = 'mood-cog.svg'
    MOOD_CONFUZED = 'mood-confuzed.svg'
    MOOD_CRAZY_HAPPY = 'mood-crazy-happy.svg'
    MOOD_CRY = 'mood-cry.svg'
    MOOD_DOLLAR = 'mood-dollar.svg'
    MOOD_EDIT = 'mood-edit.svg'
    MOOD_EMPTY = 'mood-empty.svg'
    MOOD_HAPPY = 'mood-happy.svg'
    MOOD_HEART = 'mood-heart.svg'
    MOOD_KID = 'mood-kid.svg'
    MOOD_LOOK_DOWN = 'mood-look-down.svg'
    MOOD_LOOK_LEFT = 'mood-look-left.svg'
    MOOD_LOOK_RIGHT = 'mood-look-right.svg'
    MOOD_LOOK_UP = 'mood-look-up.svg'
    MOOD_MINUS = 'mood-minus.svg'
    MOOD_NERD = 'mood-nerd.svg'
    MOOD_NERVOUS = 'mood-nervous.svg'
    MOOD_NEUTRAL = 'mood-neutral.svg'
    MOOD_OFF = 'mood-off.svg'
    MOOD_PIN = 'mood-pin.svg'
    MOOD_PLUS = 'mood-plus.svg'
    MOOD_PUZZLED = 'mood-puzzled.svg'
    MOOD_SAD_2 = 'mood-sad-2.svg'
    MOOD_SAD_DIZZY = 'mood-sad-dizzy.svg'
    MOOD_SAD_SQUINT = 'mood-sad-squint.svg'
    MOOD_SAD = 'mood-sad.svg'
    MOOD_SEARCH = 'mood-search.svg'
    MOOD_SHARE = 'mood-share.svg'
    MOOD_SICK = 'mood-sick.svg'
    MOOD_SILENCE = 'mood-silence.svg'
    MOOD_SING = 'mood-sing.svg'
    MOOD_SMILE_BEAM = 'mood-smile-beam.svg'
    MOOD_SMILE_DIZZY = 'mood-smile-dizzy.svg'
    MOOD_SMILE = 'mood-smile.svg'
    MOOD_SUPRISED = 'mood-suprised.svg'
    MOOD_TONGUE_WINK_2 = 'mood-tongue-wink-2.svg'
    MOOD_TONGUE_WINK = 'mood-tongue-wink.svg'
    MOOD_TONGUE = 'mood-tongue.svg'
    MOOD_UNAMUSED = 'mood-unamused.svg'
    MOOD_UP = 'mood-up.svg'
    MOOD_WINK_2 = 'mood-wink-2.svg'
    MOOD_WINK = 'mood-wink.svg'
    MOOD_WRRR = 'mood-wrrr.svg'
    MOOD_X = 'mood-x.svg'
    MOOD_XD = 'mood-xd.svg'
    MOON_2 = 'moon-2.svg'
    MOON_OFF = 'moon-off.svg'
    MOON_STARS = 'moon-stars.svg'
    MOON = 'moon.svg'
    MOPED = 'moped.svg'
    MOTORBIKE = 'motorbike.svg'
    MOUNTAIN_OFF = 'mountain-off.svg'
    MOUNTAIN = 'mountain.svg'
    MOUSE_2 = 'mouse-2.svg'
    MOUSE_OFF = 'mouse-off.svg'
    MOUSE = 'mouse.svg'
    MOUSTACHE = 'moustache.svg'
    MOVIE_OFF = 'movie-off.svg'
    MOVIE = 'movie.svg'
    MUG_OFF = 'mug-off.svg'
    MUG = 'mug.svg'
    MULTIPLIER_0_5X = 'multiplier-0-5x.svg'
    MULTIPLIER_1_5X = 'multiplier-1-5x.svg'
    MULTIPLIER_1X = 'multiplier-1x.svg'
    MULTIPLIER_2X = 'multiplier-2x.svg'
    MUSHROOM_OFF = 'mushroom-off.svg'
    MUSHROOM = 'mushroom.svg'
    MUSIC_BOLT = 'music-bolt.svg'
    MUSIC_CANCEL = 'music-cancel.svg'
    MUSIC_CHECK = 'music-check.svg'
    MUSIC_CODE = 'music-code.svg'
    MUSIC_COG = 'music-cog.svg'
    MUSIC_DISCOUNT = 'music-discount.svg'
    MUSIC_DOLLAR = 'music-dollar.svg'
    MUSIC_DOWN = 'music-down.svg'
    MUSIC_EXCLAMATION = 'music-exclamation.svg'
    MUSIC_HEART = 'music-heart.svg'
    MUSIC_MINUS = 'music-minus.svg'
    MUSIC_OFF = 'music-off.svg'
    MUSIC_PAUSE = 'music-pause.svg'
    MUSIC_PIN = 'music-pin.svg'
    MUSIC_PLUS = 'music-plus.svg'
    MUSIC_QUESTION = 'music-question.svg'
    MUSIC_SEARCH = 'music-search.svg'
    MUSIC_SHARE = 'music-share.svg'
    MUSIC_STAR = 'music-star.svg'
    MUSIC_UP = 'music-up.svg'
    MUSIC_X = 'music-x.svg'
    MUSIC = 'music.svg'
    NAVIGATION_BOLT = 'navigation-bolt.svg'
    NAVIGATION_CANCEL = 'navigation-cancel.svg'
    NAVIGATION_CHECK = 'navigation-check.svg'
    NAVIGATION_CODE = 'navigation-code.svg'
    NAVIGATION_COG = 'navigation-cog.svg'
    NAVIGATION_DISCOUNT = 'navigation-discount.svg'
    NAVIGATION_DOLLAR = 'navigation-dollar.svg'
    NAVIGATION_DOWN = 'navigation-down.svg'
    NAVIGATION_EAST = 'navigation-east.svg'
    NAVIGATION_EXCLAMATION = 'navigation-exclamation.svg'
    NAVIGATION_HEART = 'navigation-heart.svg'
    NAVIGATION_MINUS = 'navigation-minus.svg'
    NAVIGATION_NORTH = 'navigation-north.svg'
    NAVIGATION_OFF = 'navigation-off.svg'
    NAVIGATION_PAUSE = 'navigation-pause.svg'
    NAVIGATION_PIN = 'navigation-pin.svg'
    NAVIGATION_PLUS = 'navigation-plus.svg'
    NAVIGATION_QUESTION = 'navigation-question.svg'
    NAVIGATION_SEARCH = 'navigation-search.svg'
    NAVIGATION_SHARE = 'navigation-share.svg'
    NAVIGATION_SOUTH = 'navigation-south.svg'
    NAVIGATION_STAR = 'navigation-star.svg'
    NAVIGATION_TOP = 'navigation-top.svg'
    NAVIGATION_UP = 'navigation-up.svg'
    NAVIGATION_WEST = 'navigation-west.svg'
    NAVIGATION_X = 'navigation-x.svg'
    NAVIGATION = 'navigation.svg'
    NEEDLE_THREAD = 'needle-thread.svg'
    NEEDLE = 'needle.svg'
    NETWORK_OFF = 'network-off.svg'
    NETWORK = 'network.svg'
    NEW_SECTION = 'new-section.svg'
    NEWS_OFF = 'news-off.svg'
    NEWS = 'news.svg'
    NFC_OFF = 'nfc-off.svg'
    NFC = 'nfc.svg'
    NO_COPYRIGHT = 'no-copyright.svg'
    NO_CREATIVE_COMMONS = 'no-creative-commons.svg'
    NO_DERIVATIVES = 'no-derivatives.svg'
    NORTH_STAR = 'north-star.svg'
    NOTE_OFF = 'note-off.svg'
    NOTE = 'note.svg'
    NOTEBOOK_OFF = 'notebook-off.svg'
    NOTEBOOK = 'notebook.svg'
    NOTES_OFF = 'notes-off.svg'
    NOTES = 'notes.svg'
    NOTIFICATION_OFF = 'notification-off.svg'
    NOTIFICATION = 'notification.svg'
    NUMBER_0_SMALL = 'number-0-small.svg'
    NUMBER_0 = 'number-0.svg'
    NUMBER_1_SMALL = 'number-1-small.svg'
    NUMBER_1 = 'number-1.svg'
    NUMBER_10_SMALL = 'number-10-small.svg'
    NUMBER_11_SMALL = 'number-11-small.svg'
    NUMBER_12_SMALL = 'number-12-small.svg'
    NUMBER_123 = 'number-123.svg'
    NUMBER_13_SMALL = 'number-13-small.svg'
    NUMBER_14_SMALL = 'number-14-small.svg'
    NUMBER_15_SMALL = 'number-15-small.svg'
    NUMBER_16_SMALL = 'number-16-small.svg'
    NUMBER_17_SMALL = 'number-17-small.svg'
    NUMBER_18_SMALL = 'number-18-small.svg'
    NUMBER_19_SMALL = 'number-19-small.svg'
    NUMBER_2_SMALL = 'number-2-small.svg'
    NUMBER_2 = 'number-2.svg'
    NUMBER_20_SMALL = 'number-20-small.svg'
    NUMBER_21_SMALL = 'number-21-small.svg'
    NUMBER_22_SMALL = 'number-22-small.svg'
    NUMBER_23_SMALL = 'number-23-small.svg'
    NUMBER_24_SMALL = 'number-24-small.svg'
    NUMBER_25_SMALL = 'number-25-small.svg'
    NUMBER_26_SMALL = 'number-26-small.svg'
    NUMBER_27_SMALL = 'number-27-small.svg'
    NUMBER_28_SMALL = 'number-28-small.svg'
    NUMBER_29_SMALL = 'number-29-small.svg'
    NUMBER_3_SMALL = 'number-3-small.svg'
    NUMBER_3 = 'number-3.svg'
    NUMBER_4_SMALL = 'number-4-small.svg'
    NUMBER_4 = 'number-4.svg'
    NUMBER_5_SMALL = 'number-5-small.svg'
    NUMBER_5 = 'number-5.svg'
    NUMBER_6_SMALL = 'number-6-small.svg'
    NUMBER_6 = 'number-6.svg'
    NUMBER_7_SMALL = 'number-7-small.svg'
    NUMBER_7 = 'number-7.svg'
    NUMBER_8_SMALL = 'number-8-small.svg'
    NUMBER_8 = 'number-8.svg'
    NUMBER_9_SMALL = 'number-9-small.svg'
    NUMBER_9 = 'number-9.svg'
    NUMBER = 'number.svg'
    NUMBERS = 'numbers.svg'
    NURSE = 'nurse.svg'
    NUT = 'nut.svg'
    OCTAGON_MINUS_2 = 'octagon-minus-2.svg'
    OCTAGON_MINUS = 'octagon-minus.svg'
    OCTAGON_OFF = 'octagon-off.svg'
    OCTAGON_PLUS_2 = 'octagon-plus-2.svg'
    OCTAGON_PLUS = 'octagon-plus.svg'
    OCTAGON = 'octagon.svg'
    OCTAHEDRON_OFF = 'octahedron-off.svg'
    OCTAHEDRON_PLUS = 'octahedron-plus.svg'
    OCTAHEDRON = 'octahedron.svg'
    OLD = 'old.svg'
    OLYMPICS_OFF = 'olympics-off.svg'
    OLYMPICS = 'olympics.svg'
    OM = 'om.svg'
    OMEGA = 'omega.svg'
    OUTBOUND = 'outbound.svg'
    OUTLET = 'outlet.svg'
    OVAL_VERTICAL = 'oval-vertical.svg'
    OVAL = 'oval.svg'
    OVERLINE = 'overline.svg'
    PACKAGE_EXPORT = 'package-export.svg'
    PACKAGE_IMPORT = 'package-import.svg'
    PACKAGE_OFF = 'package-off.svg'
    PACKAGE = 'package.svg'
    PACKAGES = 'packages.svg'
    PACMAN = 'pacman.svg'
    PAGE_BREAK = 'page-break.svg'
    PAINT_OFF = 'paint-off.svg'
    PAINT = 'paint.svg'
    PALETTE_OFF = 'palette-off.svg'
    PALETTE = 'palette.svg'
    PANORAMA_HORIZONTAL_OFF = 'panorama-horizontal-off.svg'
    PANORAMA_HORIZONTAL = 'panorama-horizontal.svg'
    PANORAMA_VERTICAL_OFF = 'panorama-vertical-off.svg'
    PANORAMA_VERTICAL = 'panorama-vertical.svg'
    PAPER_BAG_OFF = 'paper-bag-off.svg'
    PAPER_BAG = 'paper-bag.svg'
    PAPERCLIP = 'paperclip.svg'
    PARACHUTE_OFF = 'parachute-off.svg'
    PARACHUTE = 'parachute.svg'
    PARENTHESES_OFF = 'parentheses-off.svg'
    PARENTHESES = 'parentheses.svg'
    PARKING_CIRCLE = 'parking-circle.svg'
    PARKING_OFF = 'parking-off.svg'
    PARKING = 'parking.svg'
    PASSWORD_FINGERPRINT = 'password-fingerprint.svg'
    PASSWORD_MOBILE_PHONE = 'password-mobile-phone.svg'
    PASSWORD_USER = 'password-user.svg'
    PASSWORD = 'password.svg'
    PAW_OFF = 'paw-off.svg'
    PAW = 'paw.svg'
    PAYWALL = 'paywall.svg'
    PDF = 'pdf.svg'
    PEACE = 'peace.svg'
    PENCIL_BOLT = 'pencil-bolt.svg'
    PENCIL_CANCEL = 'pencil-cancel.svg'
    PENCIL_CHECK = 'pencil-check.svg'
    PENCIL_CODE = 'pencil-code.svg'
    PENCIL_COG = 'pencil-cog.svg'
    PENCIL_DISCOUNT = 'pencil-discount.svg'
    PENCIL_DOLLAR = 'pencil-dollar.svg'
    PENCIL_DOWN = 'pencil-down.svg'
    PENCIL_EXCLAMATION = 'pencil-exclamation.svg'
    PENCIL_HEART = 'pencil-heart.svg'
    PENCIL_MINUS = 'pencil-minus.svg'
    PENCIL_OFF = 'pencil-off.svg'
    PENCIL_PAUSE = 'pencil-pause.svg'
    PENCIL_PIN = 'pencil-pin.svg'
    PENCIL_PLUS = 'pencil-plus.svg'
    PENCIL_QUESTION = 'pencil-question.svg'
    PENCIL_SEARCH = 'pencil-search.svg'
    PENCIL_SHARE = 'pencil-share.svg'
    PENCIL_STAR = 'pencil-star.svg'
    PENCIL_UP = 'pencil-up.svg'
    PENCIL_X = 'pencil-x.svg'
    PENCIL = 'pencil.svg'
    PENNANT_2 = 'pennant-2.svg'
    PENNANT_OFF = 'pennant-off.svg'
    PENNANT = 'pennant.svg'
    PENTAGON_MINUS = 'pentagon-minus.svg'
    PENTAGON_NUMBER_0 = 'pentagon-number-0.svg'
    PENTAGON_NUMBER_1 = 'pentagon-number-1.svg'
    PENTAGON_NUMBER_2 = 'pentagon-number-2.svg'
    PENTAGON_NUMBER_3 = 'pentagon-number-3.svg'
    PENTAGON_NUMBER_4 = 'pentagon-number-4.svg'
    PENTAGON_NUMBER_5 = 'pentagon-number-5.svg'
    PENTAGON_NUMBER_6 = 'pentagon-number-6.svg'
    PENTAGON_NUMBER_7 = 'pentagon-number-7.svg'
    PENTAGON_NUMBER_8 = 'pentagon-number-8.svg'
    PENTAGON_NUMBER_9 = 'pentagon-number-9.svg'
    PENTAGON_OFF = 'pentagon-off.svg'
    PENTAGON_PLUS = 'pentagon-plus.svg'
    PENTAGON_X = 'pentagon-x.svg'
    PENTAGON = 'pentagon.svg'
    PENTAGRAM = 'pentagram.svg'
    PEPPER_OFF = 'pepper-off.svg'
    PEPPER = 'pepper.svg'
    PERCENTAGE = 'percentage.svg'
    PERFUME = 'perfume.svg'
    PERSPECTIVE_OFF = 'perspective-off.svg'
    PERSPECTIVE = 'perspective.svg'
    PHONE_CALL = 'phone-call.svg'
    PHONE_CALLING = 'phone-calling.svg'
    PHONE_CHECK = 'phone-check.svg'
    PHONE_INCOMING = 'phone-incoming.svg'
    PHONE_OFF = 'phone-off.svg'
    PHONE_OUTGOING = 'phone-outgoing.svg'
    PHONE_PAUSE = 'phone-pause.svg'
    PHONE_PLUS = 'phone-plus.svg'
    PHONE_X = 'phone-x.svg'
    PHONE = 'phone.svg'
    PHOTO_AI = 'photo-ai.svg'
    PHOTO_BOLT = 'photo-bolt.svg'
    PHOTO_CANCEL = 'photo-cancel.svg'
    PHOTO_CHECK = 'photo-check.svg'
    PHOTO_CIRCLE_MINUS = 'photo-circle-minus.svg'
    PHOTO_CIRCLE_PLUS = 'photo-circle-plus.svg'
    PHOTO_CIRCLE = 'photo-circle.svg'
    PHOTO_CODE = 'photo-code.svg'
    PHOTO_COG = 'photo-cog.svg'
    PHOTO_DOLLAR = 'photo-dollar.svg'
    PHOTO_DOWN = 'photo-down.svg'
    PHOTO_EDIT = 'photo-edit.svg'
    PHOTO_EXCLAMATION = 'photo-exclamation.svg'
    PHOTO_HEART = 'photo-heart.svg'
    PHOTO_HEXAGON = 'photo-hexagon.svg'
    PHOTO_MINUS = 'photo-minus.svg'
    PHOTO_OFF = 'photo-off.svg'
    PHOTO_PAUSE = 'photo-pause.svg'
    PHOTO_PENTAGON = 'photo-pentagon.svg'
    PHOTO_PIN = 'photo-pin.svg'
    PHOTO_PLUS = 'photo-plus.svg'
    PHOTO_QUESTION = 'photo-question.svg'
    PHOTO_SCAN = 'photo-scan.svg'
    PHOTO_SEARCH = 'photo-search.svg'
    PHOTO_SENSOR_2 = 'photo-sensor-2.svg'
    PHOTO_SENSOR_3 = 'photo-sensor-3.svg'
    PHOTO_SENSOR = 'photo-sensor.svg'
    PHOTO_SHARE = 'photo-share.svg'
    PHOTO_SHIELD = 'photo-shield.svg'
    PHOTO_SQUARE_ROUNDED = 'photo-square-rounded.svg'
    PHOTO_STAR = 'photo-star.svg'
    PHOTO_UP = 'photo-up.svg'
    PHOTO_VIDEO = 'photo-video.svg'
    PHOTO_X = 'photo-x.svg'
    PHOTO = 'photo.svg'
    PHYSOTHERAPIST = 'physotherapist.svg'
    PIANO = 'piano.svg'
    PICK = 'pick.svg'
    PICTURE_IN_PICTURE_OFF = 'picture-in-picture-off.svg'
    PICTURE_IN_PICTURE_ON = 'picture-in-picture-on.svg'
    PICTURE_IN_PICTURE_TOP = 'picture-in-picture-top.svg'
    PICTURE_IN_PICTURE = 'picture-in-picture.svg'
    PIG_MONEY = 'pig-money.svg'
    PIG_OFF = 'pig-off.svg'
    PIG = 'pig.svg'
    PILCROW_LEFT = 'pilcrow-left.svg'
    PILCROW_RIGHT = 'pilcrow-right.svg'
    PILCROW = 'pilcrow.svg'
    PILL_OFF = 'pill-off.svg'
    PILL = 'pill.svg'
    PILLS = 'pills.svg'
    PIN_END = 'pin-end.svg'
    PIN_INVOKE = 'pin-invoke.svg'
    PIN = 'pin.svg'
    PING_PONG = 'ping-pong.svg'
    PINNED_OFF = 'pinned-off.svg'
    PINNED = 'pinned.svg'
    PIZZA_OFF = 'pizza-off.svg'
    PIZZA = 'pizza.svg'
    PLACEHOLDER = 'placeholder.svg'
    PLANE_ARRIVAL = 'plane-arrival.svg'
    PLANE_DEPARTURE = 'plane-departure.svg'
    PLANE_INFLIGHT = 'plane-inflight.svg'
    PLANE_OFF = 'plane-off.svg'
    PLANE_TILT = 'plane-tilt.svg'
    PLANE = 'plane.svg'
    PLANET_OFF = 'planet-off.svg'
    PLANET = 'planet.svg'
    PLANT_2_OFF = 'plant-2-off.svg'
    PLANT_2 = 'plant-2.svg'
    PLANT_OFF = 'plant-off.svg'
    PLANT = 'plant.svg'
    PLAY_BASKETBALL = 'play-basketball.svg'
    PLAY_CARD_OFF = 'play-card-off.svg'
    PLAY_CARD = 'play-card.svg'
    PLAY_FOOTBALL = 'play-football.svg'
    PLAY_HANDBALL = 'play-handball.svg'
    PLAY_VOLLEYBALL = 'play-volleyball.svg'
    PLAYER_EJECT = 'player-eject.svg'
    PLAYER_PAUSE = 'player-pause.svg'
    PLAYER_PLAY = 'player-play.svg'
    PLAYER_RECORD = 'player-record.svg'
    PLAYER_SKIP_BACK = 'player-skip-back.svg'
    PLAYER_SKIP_FORWARD = 'player-skip-forward.svg'
    PLAYER_STOP = 'player-stop.svg'
    PLAYER_TRACK_NEXT = 'player-track-next.svg'
    PLAYER_TRACK_PREV = 'player-track-prev.svg'
    PLAYLIST_ADD = 'playlist-add.svg'
    PLAYLIST_OFF = 'playlist-off.svg'
    PLAYLIST_X = 'playlist-x.svg'
    PLAYLIST = 'playlist.svg'
    PLAYSTATION_CIRCLE = 'playstation-circle.svg'
    PLAYSTATION_SQUARE = 'playstation-square.svg'
    PLAYSTATION_TRIANGLE = 'playstation-triangle.svg'
    PLAYSTATION_X = 'playstation-x.svg'
    PLUG_CONNECTED_X = 'plug-connected-x.svg'
    PLUG_CONNECTED = 'plug-connected.svg'
    PLUG_OFF = 'plug-off.svg'
    PLUG_X = 'plug-x.svg'
    PLUG = 'plug.svg'
    PLUS_EQUAL = 'plus-equal.svg'
    PLUS_MINUS = 'plus-minus.svg'
    PLUS = 'plus.svg'
    PNG = 'png.svg'
    PODIUM_OFF = 'podium-off.svg'
    PODIUM = 'podium.svg'
    POINT_OFF = 'point-off.svg'
    POINT = 'point.svg'
    POINTER_BOLT = 'pointer-bolt.svg'
    POINTER_CANCEL = 'pointer-cancel.svg'
    POINTER_CHECK = 'pointer-check.svg'
    POINTER_CODE = 'pointer-code.svg'
    POINTER_COG = 'pointer-cog.svg'
    POINTER_DOLLAR = 'pointer-dollar.svg'
    POINTER_DOWN = 'pointer-down.svg'
    POINTER_EXCLAMATION = 'pointer-exclamation.svg'
    POINTER_HEART = 'pointer-heart.svg'
    POINTER_MINUS = 'pointer-minus.svg'
    POINTER_OFF = 'pointer-off.svg'
    POINTER_PAUSE = 'pointer-pause.svg'
    POINTER_PIN = 'pointer-pin.svg'
    POINTER_PLUS = 'pointer-plus.svg'
    POINTER_QUESTION = 'pointer-question.svg'
    POINTER_SEARCH = 'pointer-search.svg'
    POINTER_SHARE = 'pointer-share.svg'
    POINTER_STAR = 'pointer-star.svg'
    POINTER_UP = 'pointer-up.svg'
    POINTER_X = 'pointer-x.svg'
    POINTER = 'pointer.svg'
    POKEBALL_OFF = 'pokeball-off.svg'
    POKEBALL = 'pokeball.svg'
    POKER_CHIP = 'poker-chip.svg'
    POLAROID = 'polaroid.svg'
    POLYGON_OFF = 'polygon-off.svg'
    POLYGON = 'polygon.svg'
    POO = 'poo.svg'
    POOL_OFF = 'pool-off.svg'
    POOL = 'pool.svg'
    POWER = 'power.svg'
    PRAY = 'pray.svg'
    PREMIUM_RIGHTS = 'premium-rights.svg'
    PRESCRIPTION = 'prescription.svg'
    PRESENTATION_ANALYTICS = 'presentation-analytics.svg'
    PRESENTATION_OFF = 'presentation-off.svg'
    PRESENTATION = 'presentation.svg'
    PRINTER_OFF = 'printer-off.svg'
    PRINTER = 'printer.svg'
    PRISM_LIGHT = 'prism-light.svg'
    PRISM_OFF = 'prism-off.svg'
    PRISM_PLUS = 'prism-plus.svg'
    PRISM = 'prism.svg'
    PRISON = 'prison.svg'
    PROGRESS_ALERT = 'progress-alert.svg'
    PROGRESS_BOLT = 'progress-bolt.svg'
    PROGRESS_CHECK = 'progress-check.svg'
    PROGRESS_DOWN = 'progress-down.svg'
    PROGRESS_HELP = 'progress-help.svg'
    PROGRESS_X = 'progress-x.svg'
    PROGRESS = 'progress.svg'
    PROMPT = 'prompt.svg'
    PRONG = 'prong.svg'
    PROPELLER_OFF = 'propeller-off.svg'
    PROPELLER = 'propeller.svg'
    PROTOCOL = 'protocol.svg'
    PUMPKIN_SCARY = 'pumpkin-scary.svg'
    PUZZLE_2 = 'puzzle-2.svg'
    PUZZLE_OFF = 'puzzle-off.svg'
    PUZZLE = 'puzzle.svg'
    PYRAMID_OFF = 'pyramid-off.svg'
    PYRAMID_PLUS = 'pyramid-plus.svg'
    PYRAMID = 'pyramid.svg'
    QRCODE_OFF = 'qrcode-off.svg'
    QRCODE = 'qrcode.svg'
    QUESTION_MARK = 'question-mark.svg'
    QUOTE_OFF = 'quote-off.svg'
    QUOTE = 'quote.svg'
    QUOTES = 'quotes.svg'
    RADAR_2 = 'radar-2.svg'
    RADAR_OFF = 'radar-off.svg'
    RADAR = 'radar.svg'
    RADIO_OFF = 'radio-off.svg'
    RADIO = 'radio.svg'
    RADIOACTIVE_OFF = 'radioactive-off.svg'
    RADIOACTIVE = 'radioactive.svg'
    RADIUS_BOTTOM_LEFT = 'radius-bottom-left.svg'
    RADIUS_BOTTOM_RIGHT = 'radius-bottom-right.svg'
    RADIUS_TOP_LEFT = 'radius-top-left.svg'
    RADIUS_TOP_RIGHT = 'radius-top-right.svg'
    RAINBOW_OFF = 'rainbow-off.svg'
    RAINBOW = 'rainbow.svg'
    RATING_12_PLUS = 'rating-12-plus.svg'
    RATING_14_PLUS = 'rating-14-plus.svg'
    RATING_16_PLUS = 'rating-16-plus.svg'
    RATING_18_PLUS = 'rating-18-plus.svg'
    RATING_21_PLUS = 'rating-21-plus.svg'
    RAZOR_ELECTRIC = 'razor-electric.svg'
    RAZOR = 'razor.svg'
    RECEIPT_2 = 'receipt-2.svg'
    RECEIPT_BITCOIN = 'receipt-bitcoin.svg'
    RECEIPT_DOLLAR = 'receipt-dollar.svg'
    RECEIPT_EURO = 'receipt-euro.svg'
    RECEIPT_OFF = 'receipt-off.svg'
    RECEIPT_POUND = 'receipt-pound.svg'
    RECEIPT_REFUND = 'receipt-refund.svg'
    RECEIPT_RUPEE = 'receipt-rupee.svg'
    RECEIPT_TAX = 'receipt-tax.svg'
    RECEIPT_YEN = 'receipt-yen.svg'
    RECEIPT_YUAN = 'receipt-yuan.svg'
    RECEIPT = 'receipt.svg'
    RECHARGING = 'recharging.svg'
    RECORD_MAIL_OFF = 'record-mail-off.svg'
    RECORD_MAIL = 'record-mail.svg'
    RECTANGLE_ROUNDED_BOTTOM = 'rectangle-rounded-bottom.svg'
    RECTANGLE_ROUNDED_TOP = 'rectangle-rounded-top.svg'
    RECTANGLE_VERTICAL = 'rectangle-vertical.svg'
    RECTANGLE = 'rectangle.svg'
    RECTANGULAR_PRISM_OFF = 'rectangular-prism-off.svg'
    RECTANGULAR_PRISM_PLUS = 'rectangular-prism-plus.svg'
    RECTANGULAR_PRISM = 'rectangular-prism.svg'
    RECYCLE_OFF = 'recycle-off.svg'
    RECYCLE = 'recycle.svg'
    REFRESH_ALERT = 'refresh-alert.svg'
    REFRESH_DOT = 'refresh-dot.svg'
    REFRESH_OFF = 'refresh-off.svg'
    REFRESH = 'refresh.svg'
    REGEX_OFF = 'regex-off.svg'
    REGEX = 'regex.svg'
    REGISTERED = 'registered.svg'
    RELATION_MANY_TO_MANY = 'relation-many-to-many.svg'
    RELATION_ONE_TO_MANY = 'relation-one-to-many.svg'
    RELATION_ONE_TO_ONE = 'relation-one-to-one.svg'
    RELOAD = 'reload.svg'
    REORDER = 'reorder.svg'
    REPEAT_OFF = 'repeat-off.svg'
    REPEAT_ONCE = 'repeat-once.svg'
    REPEAT = 'repeat.svg'
    REPLACE_OFF = 'replace-off.svg'
    REPLACE = 'replace.svg'
    REPORT_ANALYTICS = 'report-analytics.svg'
    REPORT_MEDICAL = 'report-medical.svg'
    REPORT_MONEY = 'report-money.svg'
    REPORT_OFF = 'report-off.svg'
    REPORT_SEARCH = 'report-search.svg'
    REPORT = 'report.svg'
    RESERVED_LINE = 'reserved-line.svg'
    RESIZE = 'resize.svg'
    RESTORE = 'restore.svg'
    REWIND_BACKWARD_10 = 'rewind-backward-10.svg'
    REWIND_BACKWARD_15 = 'rewind-backward-15.svg'
    REWIND_BACKWARD_20 = 'rewind-backward-20.svg'
    REWIND_BACKWARD_30 = 'rewind-backward-30.svg'
    REWIND_BACKWARD_40 = 'rewind-backward-40.svg'
    REWIND_BACKWARD_5 = 'rewind-backward-5.svg'
    REWIND_BACKWARD_50 = 'rewind-backward-50.svg'
    REWIND_BACKWARD_60 = 'rewind-backward-60.svg'
    REWIND_FORWARD_10 = 'rewind-forward-10.svg'
    REWIND_FORWARD_15 = 'rewind-forward-15.svg'
    REWIND_FORWARD_20 = 'rewind-forward-20.svg'
    REWIND_FORWARD_30 = 'rewind-forward-30.svg'
    REWIND_FORWARD_40 = 'rewind-forward-40.svg'
    REWIND_FORWARD_5 = 'rewind-forward-5.svg'
    REWIND_FORWARD_50 = 'rewind-forward-50.svg'
    REWIND_FORWARD_60 = 'rewind-forward-60.svg'
    RIBBON_HEALTH = 'ribbon-health.svg'
    RINGS = 'rings.svg'
    RIPPLE_OFF = 'ripple-off.svg'
    RIPPLE = 'ripple.svg'
    ROAD_OFF = 'road-off.svg'
    ROAD_SIGN = 'road-sign.svg'
    ROAD = 'road.svg'
    ROBOT_FACE = 'robot-face.svg'
    ROBOT_OFF = 'robot-off.svg'
    ROBOT = 'robot.svg'
    ROCKET_OFF = 'rocket-off.svg'
    ROCKET = 'rocket.svg'
    ROLLER_SKATING = 'roller-skating.svg'
    ROLLERCOASTER_OFF = 'rollercoaster-off.svg'
    ROLLERCOASTER = 'rollercoaster.svg'
    ROSETTE_DISCOUNT_CHECK = 'rosette-discount-check.svg'
    ROSETTE_DISCOUNT_OFF = 'rosette-discount-off.svg'
    ROSETTE_DISCOUNT = 'rosette-discount.svg'
    ROSETTE_NUMBER_0 = 'rosette-number-0.svg'
    ROSETTE_NUMBER_1 = 'rosette-number-1.svg'
    ROSETTE_NUMBER_2 = 'rosette-number-2.svg'
    ROSETTE_NUMBER_3 = 'rosette-number-3.svg'
    ROSETTE_NUMBER_4 = 'rosette-number-4.svg'
    ROSETTE_NUMBER_5 = 'rosette-number-5.svg'
    ROSETTE_NUMBER_6 = 'rosette-number-6.svg'
    ROSETTE_NUMBER_7 = 'rosette-number-7.svg'
    ROSETTE_NUMBER_8 = 'rosette-number-8.svg'
    ROSETTE_NUMBER_9 = 'rosette-number-9.svg'
    ROSETTE = 'rosette.svg'
    ROTATE_2 = 'rotate-2.svg'
    ROTATE_360 = 'rotate-360.svg'
    ROTATE_3D = 'rotate-3d.svg'
    ROTATE_CLOCKWISE_2 = 'rotate-clockwise-2.svg'
    ROTATE_CLOCKWISE = 'rotate-clockwise.svg'
    ROTATE_DOT = 'rotate-dot.svg'
    ROTATE_RECTANGLE = 'rotate-rectangle.svg'
    ROTATE = 'rotate.svg'
    ROUTE_2 = 'route-2.svg'
    ROUTE_ALT_LEFT = 'route-alt-left.svg'
    ROUTE_ALT_RIGHT = 'route-alt-right.svg'
    ROUTE_OFF = 'route-off.svg'
    ROUTE_SCAN = 'route-scan.svg'
    ROUTE_SQUARE_2 = 'route-square-2.svg'
    ROUTE_SQUARE = 'route-square.svg'
    ROUTE_X_2 = 'route-x-2.svg'
    ROUTE_X = 'route-x.svg'
    ROUTE = 'route.svg'
    ROUTER_OFF = 'router-off.svg'
    ROUTER = 'router.svg'
    ROW_INSERT_BOTTOM = 'row-insert-bottom.svg'
    ROW_INSERT_TOP = 'row-insert-top.svg'
    ROW_REMOVE = 'row-remove.svg'
    RSS = 'rss.svg'
    RUBBER_STAMP_OFF = 'rubber-stamp-off.svg'
    RUBBER_STAMP = 'rubber-stamp.svg'
    RULER_2_OFF = 'ruler-2-off.svg'
    RULER_2 = 'ruler-2.svg'
    RULER_3 = 'ruler-3.svg'
    RULER_MEASURE = 'ruler-measure.svg'
    RULER_OFF = 'ruler-off.svg'
    RULER = 'ruler.svg'
    RUN = 'run.svg'
    RV_TRUCK = 'rv-truck.svg'
    S_TURN_DOWN = 's-turn-down.svg'
    S_TURN_LEFT = 's-turn-left.svg'
    S_TURN_RIGHT = 's-turn-right.svg'
    S_TURN_UP = 's-turn-up.svg'
    SAILBOAT_2 = 'sailboat-2.svg'
    SAILBOAT_OFF = 'sailboat-off.svg'
    SAILBOAT = 'sailboat.svg'
    SALAD = 'salad.svg'
    SALT = 'salt.svg'
    SANDBOX = 'sandbox.svg'
    SATELLITE_OFF = 'satellite-off.svg'
    SATELLITE = 'satellite.svg'
    SAUSAGE = 'sausage.svg'
    SCALE_OFF = 'scale-off.svg'
    SCALE_OUTLINE_OFF = 'scale-outline-off.svg'
    SCALE_OUTLINE = 'scale-outline.svg'
    SCALE = 'scale.svg'
    SCAN_EYE = 'scan-eye.svg'
    SCAN_POSITION = 'scan-position.svg'
    SCAN = 'scan.svg'
    SCHEMA_OFF = 'schema-off.svg'
    SCHEMA = 'schema.svg'
    SCHOOL_BELL = 'school-bell.svg'
    SCHOOL_OFF = 'school-off.svg'
    SCHOOL = 'school.svg'
    SCISSORS_OFF = 'scissors-off.svg'
    SCISSORS = 'scissors.svg'
    SCOOTER_ELECTRIC = 'scooter-electric.svg'
    SCOOTER = 'scooter.svg'
    SCOREBOARD = 'scoreboard.svg'
    SCREEN_SHARE_OFF = 'screen-share-off.svg'
    SCREEN_SHARE = 'screen-share.svg'
    SCREENSHOT = 'screenshot.svg'
    SCRIBBLE_OFF = 'scribble-off.svg'
    SCRIBBLE = 'scribble.svg'
    SCRIPT_MINUS = 'script-minus.svg'
    SCRIPT_PLUS = 'script-plus.svg'
    SCRIPT_X = 'script-x.svg'
    SCRIPT = 'script.svg'
    SCUBA_DIVING = 'scuba-diving.svg'
    SCUBA_MASK_OFF = 'scuba-mask-off.svg'
    SCUBA_MASK = 'scuba-mask.svg'
    SDK = 'sdk.svg'
    SEARCH_OFF = 'search-off.svg'
    SEARCH = 'search.svg'
    SECTION_SIGN = 'section-sign.svg'
    SECTION = 'section.svg'
    SEEDING_OFF = 'seeding-off.svg'
    SEEDING = 'seeding.svg'
    SELECT_ALL = 'select-all.svg'
    SELECT = 'select.svg'
    SELECTOR = 'selector.svg'
    SEND_2 = 'send-2.svg'
    SEND_OFF = 'send-off.svg'
    SEND = 'send.svg'
    SEO = 'seo.svg'
    SEPARATOR_HORIZONTAL = 'separator-horizontal.svg'
    SEPARATOR_VERTICAL = 'separator-vertical.svg'
    SEPARATOR = 'separator.svg'
    SERVER_2 = 'server-2.svg'
    SERVER_BOLT = 'server-bolt.svg'
    SERVER_COG = 'server-cog.svg'
    SERVER_OFF = 'server-off.svg'
    SERVER = 'server.svg'
    SERVICEMARK = 'servicemark.svg'
    SETTINGS_2 = 'settings-2.svg'
    SETTINGS_AUTOMATION = 'settings-automation.svg'
    SETTINGS_BOLT = 'settings-bolt.svg'
    SETTINGS_CANCEL = 'settings-cancel.svg'
    SETTINGS_CHECK = 'settings-check.svg'
    SETTINGS_CODE = 'settings-code.svg'
    SETTINGS_COG = 'settings-cog.svg'
    SETTINGS_DOLLAR = 'settings-dollar.svg'
    SETTINGS_DOWN = 'settings-down.svg'
    SETTINGS_EXCLAMATION = 'settings-exclamation.svg'
    SETTINGS_HEART = 'settings-heart.svg'
    SETTINGS_MINUS = 'settings-minus.svg'
    SETTINGS_OFF = 'settings-off.svg'
    SETTINGS_PAUSE = 'settings-pause.svg'
    SETTINGS_PIN = 'settings-pin.svg'
    SETTINGS_PLUS = 'settings-plus.svg'
    SETTINGS_QUESTION = 'settings-question.svg'
    SETTINGS_SEARCH = 'settings-search.svg'
    SETTINGS_SHARE = 'settings-share.svg'
    SETTINGS_STAR = 'settings-star.svg'
    SETTINGS_UP = 'settings-up.svg'
    SETTINGS_X = 'settings-x.svg'
    SETTINGS = 'settings.svg'
    SHADOW_OFF = 'shadow-off.svg'
    SHADOW = 'shadow.svg'
    SHAPE_2 = 'shape-2.svg'
    SHAPE_3 = 'shape-3.svg'
    SHAPE_OFF = 'shape-off.svg'
    SHAPE = 'shape.svg'
    SHARE_2 = 'share-2.svg'
    SHARE_3 = 'share-3.svg'
    SHARE_OFF = 'share-off.svg'
    SHARE = 'share.svg'
    SHAREPLAY = 'shareplay.svg'
    SHIELD_BOLT = 'shield-bolt.svg'
    SHIELD_CANCEL = 'shield-cancel.svg'
    SHIELD_CHECK = 'shield-check.svg'
    SHIELD_CHECKERED = 'shield-checkered.svg'
    SHIELD_CHEVRON = 'shield-chevron.svg'
    SHIELD_CODE = 'shield-code.svg'
    SHIELD_COG = 'shield-cog.svg'
    SHIELD_DOLLAR = 'shield-dollar.svg'
    SHIELD_DOWN = 'shield-down.svg'
    SHIELD_EXCLAMATION = 'shield-exclamation.svg'
    SHIELD_HALF = 'shield-half.svg'
    SHIELD_HEART = 'shield-heart.svg'
    SHIELD_LOCK = 'shield-lock.svg'
    SHIELD_MINUS = 'shield-minus.svg'
    SHIELD_OFF = 'shield-off.svg'
    SHIELD_PAUSE = 'shield-pause.svg'
    SHIELD_PIN = 'shield-pin.svg'
    SHIELD_PLUS = 'shield-plus.svg'
    SHIELD_QUESTION = 'shield-question.svg'
    SHIELD_SEARCH = 'shield-search.svg'
    SHIELD_SHARE = 'shield-share.svg'
    SHIELD_STAR = 'shield-star.svg'
    SHIELD_UP = 'shield-up.svg'
    SHIELD_X = 'shield-x.svg'
    SHIELD = 'shield.svg'
    SHIP_OFF = 'ship-off.svg'
    SHIP = 'ship.svg'
    SHIRT_OFF = 'shirt-off.svg'
    SHIRT_SPORT = 'shirt-sport.svg'
    SHIRT = 'shirt.svg'
    SHOE_OFF = 'shoe-off.svg'
    SHOE = 'shoe.svg'
    SHOPPING_BAG_CHECK = 'shopping-bag-check.svg'
    SHOPPING_BAG_DISCOUNT = 'shopping-bag-discount.svg'
    SHOPPING_BAG_EDIT = 'shopping-bag-edit.svg'
    SHOPPING_BAG_EXCLAMATION = 'shopping-bag-exclamation.svg'
    SHOPPING_BAG_HEART = 'shopping-bag-heart.svg'
    SHOPPING_BAG_MINUS = 'shopping-bag-minus.svg'
    SHOPPING_BAG_PLUS = 'shopping-bag-plus.svg'
    SHOPPING_BAG_SEARCH = 'shopping-bag-search.svg'
    SHOPPING_BAG_X = 'shopping-bag-x.svg'
    SHOPPING_BAG = 'shopping-bag.svg'
    SHOPPING_CART_BOLT = 'shopping-cart-bolt.svg'
    SHOPPING_CART_CANCEL = 'shopping-cart-cancel.svg'
    SHOPPING_CART_CHECK = 'shopping-cart-check.svg'
    SHOPPING_CART_CODE = 'shopping-cart-code.svg'
    SHOPPING_CART_COG = 'shopping-cart-cog.svg'
    SHOPPING_CART_COPY = 'shopping-cart-copy.svg'
    SHOPPING_CART_DISCOUNT = 'shopping-cart-discount.svg'
    SHOPPING_CART_DOLLAR = 'shopping-cart-dollar.svg'
    SHOPPING_CART_DOWN = 'shopping-cart-down.svg'
    SHOPPING_CART_EXCLAMATION = 'shopping-cart-exclamation.svg'
    SHOPPING_CART_HEART = 'shopping-cart-heart.svg'
    SHOPPING_CART_MINUS = 'shopping-cart-minus.svg'
    SHOPPING_CART_OFF = 'shopping-cart-off.svg'
    SHOPPING_CART_PAUSE = 'shopping-cart-pause.svg'
    SHOPPING_CART_PIN = 'shopping-cart-pin.svg'
    SHOPPING_CART_PLUS = 'shopping-cart-plus.svg'
    SHOPPING_CART_QUESTION = 'shopping-cart-question.svg'
    SHOPPING_CART_SEARCH = 'shopping-cart-search.svg'
    SHOPPING_CART_SHARE = 'shopping-cart-share.svg'
    SHOPPING_CART_STAR = 'shopping-cart-star.svg'
    SHOPPING_CART_UP = 'shopping-cart-up.svg'
    SHOPPING_CART_X = 'shopping-cart-x.svg'
    SHOPPING_CART = 'shopping-cart.svg'
    SHOVEL_PITCHFORKS = 'shovel-pitchforks.svg'
    SHOVEL = 'shovel.svg'
    SHREDDER = 'shredder.svg'
    SIGN_LEFT = 'sign-left.svg'
    SIGN_RIGHT = 'sign-right.svg'
    SIGNAL_2G = 'signal-2g.svg'
    SIGNAL_3G = 'signal-3g.svg'
    SIGNAL_4G_PLUS = 'signal-4g-plus.svg'
    SIGNAL_4G = 'signal-4g.svg'
    SIGNAL_5G = 'signal-5g.svg'
    SIGNAL_6G = 'signal-6g.svg'
    SIGNAL_E = 'signal-e.svg'
    SIGNAL_G = 'signal-g.svg'
    SIGNAL_H_PLUS = 'signal-h-plus.svg'
    SIGNAL_H = 'signal-h.svg'
    SIGNAL_LTE = 'signal-lte.svg'
    SIGNATURE_OFF = 'signature-off.svg'
    SIGNATURE = 'signature.svg'
    SITEMAP_OFF = 'sitemap-off.svg'
    SITEMAP = 'sitemap.svg'
    SKATEBOARD_OFF = 'skateboard-off.svg'
    SKATEBOARD = 'skateboard.svg'
    SKATEBOARDING = 'skateboarding.svg'
    SKEW_X = 'skew-x.svg'
    SKEW_Y = 'skew-y.svg'
    SKI_JUMPING = 'ski-jumping.svg'
    SKULL = 'skull.svg'
    SLASH = 'slash.svg'
    SLASHES = 'slashes.svg'
    SLEIGH = 'sleigh.svg'
    SLICE = 'slice.svg'
    SLIDESHOW = 'slideshow.svg'
    SMART_HOME_OFF = 'smart-home-off.svg'
    SMART_HOME = 'smart-home.svg'
    SMOKING_NO = 'smoking-no.svg'
    SMOKING = 'smoking.svg'
    SNOWBOARDING = 'snowboarding.svg'
    SNOWFLAKE_OFF = 'snowflake-off.svg'
    SNOWFLAKE = 'snowflake.svg'
    SNOWMAN = 'snowman.svg'
    SOCCER_FIELD = 'soccer-field.svg'
    SOCIAL_OFF = 'social-off.svg'
    SOCIAL = 'social.svg'
    SOCK = 'sock.svg'
    SOFA_OFF = 'sofa-off.svg'
    SOFA = 'sofa.svg'
    SOLAR_ELECTRICITY = 'solar-electricity.svg'
    SOLAR_PANEL_2 = 'solar-panel-2.svg'
    SOLAR_PANEL = 'solar-panel.svg'
    SORT_0_9 = 'sort-0-9.svg'
    SORT_9_0 = 'sort-9-0.svg'
    SORT_A_Z = 'sort-a-z.svg'
    SORT_ASCENDING_2 = 'sort-ascending-2.svg'
    SORT_ASCENDING_LETTERS = 'sort-ascending-letters.svg'
    SORT_ASCENDING_NUMBERS = 'sort-ascending-numbers.svg'
    SORT_ASCENDING_SHAPES = 'sort-ascending-shapes.svg'
    SORT_ASCENDING_SMALL_BIG = 'sort-ascending-small-big.svg'
    SORT_ASCENDING = 'sort-ascending.svg'
    SORT_DESCENDING_2 = 'sort-descending-2.svg'
    SORT_DESCENDING_LETTERS = 'sort-descending-letters.svg'
    SORT_DESCENDING_NUMBERS = 'sort-descending-numbers.svg'
    SORT_DESCENDING_SHAPES = 'sort-descending-shapes.svg'
    SORT_DESCENDING_SMALL_BIG = 'sort-descending-small-big.svg'
    SORT_DESCENDING = 'sort-descending.svg'
    SORT_Z_A = 'sort-z-a.svg'
    SOS = 'sos.svg'
    SOUP_OFF = 'soup-off.svg'
    SOUP = 'soup.svg'
    SOURCE_CODE = 'source-code.svg'
    SPACE_OFF = 'space-off.svg'
    SPACE = 'space.svg'
    SPACES = 'spaces.svg'
    SPACING_HORIZONTAL = 'spacing-horizontal.svg'
    SPACING_VERTICAL = 'spacing-vertical.svg'
    SPADE = 'spade.svg'
    SPARKLES = 'sparkles.svg'
    SPEAKERPHONE = 'speakerphone.svg'
    SPEEDBOAT = 'speedboat.svg'
    SPHERE_OFF = 'sphere-off.svg'
    SPHERE_PLUS = 'sphere-plus.svg'
    SPHERE = 'sphere.svg'
    SPIDER = 'spider.svg'
    SPIRAL_OFF = 'spiral-off.svg'
    SPIRAL = 'spiral.svg'
    SPORT_BILLARD = 'sport-billard.svg'
    SPRAY = 'spray.svg'
    SPY_OFF = 'spy-off.svg'
    SPY = 'spy.svg'
    SQL = 'sql.svg'
    SQUARE_ARROW_DOWN = 'square-arrow-down.svg'
    SQUARE_ARROW_LEFT = 'square-arrow-left.svg'
    SQUARE_ARROW_RIGHT = 'square-arrow-right.svg'
    SQUARE_ARROW_UP = 'square-arrow-up.svg'
    SQUARE_ASTERISK = 'square-asterisk.svg'
    SQUARE_CHECK = 'square-check.svg'
    SQUARE_CHEVRON_DOWN = 'square-chevron-down.svg'
    SQUARE_CHEVRON_LEFT = 'square-chevron-left.svg'
    SQUARE_CHEVRON_RIGHT = 'square-chevron-right.svg'
    SQUARE_CHEVRON_UP = 'square-chevron-up.svg'
    SQUARE_CHEVRONS_DOWN = 'square-chevrons-down.svg'
    SQUARE_CHEVRONS_LEFT = 'square-chevrons-left.svg'
    SQUARE_CHEVRONS_RIGHT = 'square-chevrons-right.svg'
    SQUARE_CHEVRONS_UP = 'square-chevrons-up.svg'
    SQUARE_DOT = 'square-dot.svg'
    SQUARE_F0 = 'square-f0.svg'
    SQUARE_F1 = 'square-f1.svg'
    SQUARE_F2 = 'square-f2.svg'
    SQUARE_F3 = 'square-f3.svg'
    SQUARE_F4 = 'square-f4.svg'
    SQUARE_F5 = 'square-f5.svg'
    SQUARE_F6 = 'square-f6.svg'
    SQUARE_F7 = 'square-f7.svg'
    SQUARE_F8 = 'square-f8.svg'
    SQUARE_F9 = 'square-f9.svg'
    SQUARE_FORBID_2 = 'square-forbid-2.svg'
    SQUARE_FORBID = 'square-forbid.svg'
    SQUARE_HALF = 'square-half.svg'
    SQUARE_KEY = 'square-key.svg'
    SQUARE_LETTER_A = 'square-letter-a.svg'
    SQUARE_LETTER_B = 'square-letter-b.svg'
    SQUARE_LETTER_C = 'square-letter-c.svg'
    SQUARE_LETTER_D = 'square-letter-d.svg'
    SQUARE_LETTER_E = 'square-letter-e.svg'
    SQUARE_LETTER_F = 'square-letter-f.svg'
    SQUARE_LETTER_G = 'square-letter-g.svg'
    SQUARE_LETTER_H = 'square-letter-h.svg'
    SQUARE_LETTER_I = 'square-letter-i.svg'
    SQUARE_LETTER_J = 'square-letter-j.svg'
    SQUARE_LETTER_K = 'square-letter-k.svg'
    SQUARE_LETTER_L = 'square-letter-l.svg'
    SQUARE_LETTER_M = 'square-letter-m.svg'
    SQUARE_LETTER_N = 'square-letter-n.svg'
    SQUARE_LETTER_O = 'square-letter-o.svg'
    SQUARE_LETTER_P = 'square-letter-p.svg'
    SQUARE_LETTER_Q = 'square-letter-q.svg'
    SQUARE_LETTER_R = 'square-letter-r.svg'
    SQUARE_LETTER_S = 'square-letter-s.svg'
    SQUARE_LETTER_T = 'square-letter-t.svg'
    SQUARE_LETTER_U = 'square-letter-u.svg'
    SQUARE_LETTER_V = 'square-letter-v.svg'
    SQUARE_LETTER_W = 'square-letter-w.svg'
    SQUARE_LETTER_X = 'square-letter-x.svg'
    SQUARE_LETTER_Y = 'square-letter-y.svg'
    SQUARE_LETTER_Z = 'square-letter-z.svg'
    SQUARE_MINUS = 'square-minus.svg'
    SQUARE_NUMBER_0 = 'square-number-0.svg'
    SQUARE_NUMBER_1 = 'square-number-1.svg'
    SQUARE_NUMBER_2 = 'square-number-2.svg'
    SQUARE_NUMBER_3 = 'square-number-3.svg'
    SQUARE_NUMBER_4 = 'square-number-4.svg'
    SQUARE_NUMBER_5 = 'square-number-5.svg'
    SQUARE_NUMBER_6 = 'square-number-6.svg'
    SQUARE_NUMBER_7 = 'square-number-7.svg'
    SQUARE_NUMBER_8 = 'square-number-8.svg'
    SQUARE_NUMBER_9 = 'square-number-9.svg'
    SQUARE_OFF = 'square-off.svg'
    SQUARE_PERCENTAGE = 'square-percentage.svg'
    SQUARE_PLUS_2 = 'square-plus-2.svg'
    SQUARE_PLUS = 'square-plus.svg'
    SQUARE_ROOT_2 = 'square-root-2.svg'
    SQUARE_ROOT = 'square-root.svg'
    SQUARE_ROTATED_FORBID_2 = 'square-rotated-forbid-2.svg'
    SQUARE_ROTATED_FORBID = 'square-rotated-forbid.svg'
    SQUARE_ROTATED_OFF = 'square-rotated-off.svg'
    SQUARE_ROTATED = 'square-rotated.svg'
    SQUARE_ROUNDED_ARROW_DOWN = 'square-rounded-arrow-down.svg'
    SQUARE_ROUNDED_ARROW_LEFT = 'square-rounded-arrow-left.svg'
    SQUARE_ROUNDED_ARROW_RIGHT = 'square-rounded-arrow-right.svg'
    SQUARE_ROUNDED_ARROW_UP = 'square-rounded-arrow-up.svg'
    SQUARE_ROUNDED_CHECK = 'square-rounded-check.svg'
    SQUARE_ROUNDED_CHEVRON_DOWN = 'square-rounded-chevron-down.svg'
    SQUARE_ROUNDED_CHEVRON_LEFT = 'square-rounded-chevron-left.svg'
    SQUARE_ROUNDED_CHEVRON_RIGHT = 'square-rounded-chevron-right.svg'
    SQUARE_ROUNDED_CHEVRON_UP = 'square-rounded-chevron-up.svg'
    SQUARE_ROUNDED_CHEVRONS_DOWN = 'square-rounded-chevrons-down.svg'
    SQUARE_ROUNDED_CHEVRONS_LEFT = 'square-rounded-chevrons-left.svg'
    SQUARE_ROUNDED_CHEVRONS_RIGHT = 'square-rounded-chevrons-right.svg'
    SQUARE_ROUNDED_CHEVRONS_UP = 'square-rounded-chevrons-up.svg'
    SQUARE_ROUNDED_LETTER_A = 'square-rounded-letter-a.svg'
    SQUARE_ROUNDED_LETTER_B = 'square-rounded-letter-b.svg'
    SQUARE_ROUNDED_LETTER_C = 'square-rounded-letter-c.svg'
    SQUARE_ROUNDED_LETTER_D = 'square-rounded-letter-d.svg'
    SQUARE_ROUNDED_LETTER_E = 'square-rounded-letter-e.svg'
    SQUARE_ROUNDED_LETTER_F = 'square-rounded-letter-f.svg'
    SQUARE_ROUNDED_LETTER_G = 'square-rounded-letter-g.svg'
    SQUARE_ROUNDED_LETTER_H = 'square-rounded-letter-h.svg'
    SQUARE_ROUNDED_LETTER_I = 'square-rounded-letter-i.svg'
    SQUARE_ROUNDED_LETTER_J = 'square-rounded-letter-j.svg'
    SQUARE_ROUNDED_LETTER_K = 'square-rounded-letter-k.svg'
    SQUARE_ROUNDED_LETTER_L = 'square-rounded-letter-l.svg'
    SQUARE_ROUNDED_LETTER_M = 'square-rounded-letter-m.svg'
    SQUARE_ROUNDED_LETTER_N = 'square-rounded-letter-n.svg'
    SQUARE_ROUNDED_LETTER_O = 'square-rounded-letter-o.svg'
    SQUARE_ROUNDED_LETTER_P = 'square-rounded-letter-p.svg'
    SQUARE_ROUNDED_LETTER_Q = 'square-rounded-letter-q.svg'
    SQUARE_ROUNDED_LETTER_R = 'square-rounded-letter-r.svg'
    SQUARE_ROUNDED_LETTER_S = 'square-rounded-letter-s.svg'
    SQUARE_ROUNDED_LETTER_T = 'square-rounded-letter-t.svg'
    SQUARE_ROUNDED_LETTER_U = 'square-rounded-letter-u.svg'
    SQUARE_ROUNDED_LETTER_V = 'square-rounded-letter-v.svg'
    SQUARE_ROUNDED_LETTER_W = 'square-rounded-letter-w.svg'
    SQUARE_ROUNDED_LETTER_X = 'square-rounded-letter-x.svg'
    SQUARE_ROUNDED_LETTER_Y = 'square-rounded-letter-y.svg'
    SQUARE_ROUNDED_LETTER_Z = 'square-rounded-letter-z.svg'
    SQUARE_ROUNDED_MINUS_2 = 'square-rounded-minus-2.svg'
    SQUARE_ROUNDED_MINUS = 'square-rounded-minus.svg'
    SQUARE_ROUNDED_NUMBER_0 = 'square-rounded-number-0.svg'
    SQUARE_ROUNDED_NUMBER_1 = 'square-rounded-number-1.svg'
    SQUARE_ROUNDED_NUMBER_2 = 'square-rounded-number-2.svg'
    SQUARE_ROUNDED_NUMBER_3 = 'square-rounded-number-3.svg'
    SQUARE_ROUNDED_NUMBER_4 = 'square-rounded-number-4.svg'
    SQUARE_ROUNDED_NUMBER_5 = 'square-rounded-number-5.svg'
    SQUARE_ROUNDED_NUMBER_6 = 'square-rounded-number-6.svg'
    SQUARE_ROUNDED_NUMBER_7 = 'square-rounded-number-7.svg'
    SQUARE_ROUNDED_NUMBER_8 = 'square-rounded-number-8.svg'
    SQUARE_ROUNDED_NUMBER_9 = 'square-rounded-number-9.svg'
    SQUARE_ROUNDED_PERCENTAGE = 'square-rounded-percentage.svg'
    SQUARE_ROUNDED_PLUS_2 = 'square-rounded-plus-2.svg'
    SQUARE_ROUNDED_PLUS = 'square-rounded-plus.svg'
    SQUARE_ROUNDED_X = 'square-rounded-x.svg'
    SQUARE_ROUNDED = 'square-rounded.svg'
    SQUARE_TOGGLE_HORIZONTAL = 'square-toggle-horizontal.svg'
    SQUARE_TOGGLE = 'square-toggle.svg'
    SQUARE_X = 'square-x.svg'
    SQUARE = 'square.svg'
    SQUARES_DIAGONAL = 'squares-diagonal.svg'
    SQUARES_SELECTED = 'squares-selected.svg'
    SQUARES = 'squares.svg'
    STACK_2 = 'stack-2.svg'
    STACK_3 = 'stack-3.svg'
    STACK_BACK = 'stack-back.svg'
    STACK_BACKWARD = 'stack-backward.svg'
    STACK_FORWARD = 'stack-forward.svg'
    STACK_FRONT = 'stack-front.svg'
    STACK_MIDDLE = 'stack-middle.svg'
    STACK_POP = 'stack-pop.svg'
    STACK_PUSH = 'stack-push.svg'
    STACK = 'stack.svg'
    STAIRS_DOWN = 'stairs-down.svg'
    STAIRS_UP = 'stairs-up.svg'
    STAIRS = 'stairs.svg'
    STAR_HALF = 'star-half.svg'
    STAR_OFF = 'star-off.svg'
    STAR = 'star.svg'
    STARS_OFF = 'stars-off.svg'
    STARS = 'stars.svg'
    STATUS_CHANGE = 'status-change.svg'
    STEAM = 'steam.svg'
    STEERING_WHEEL_OFF = 'steering-wheel-off.svg'
    STEERING_WHEEL = 'steering-wheel.svg'
    STEP_INTO = 'step-into.svg'
    STEP_OUT = 'step-out.svg'
    STEREO_GLASSES = 'stereo-glasses.svg'
    STETHOSCOPE_OFF = 'stethoscope-off.svg'
    STETHOSCOPE = 'stethoscope.svg'
    STICKER_2 = 'sticker-2.svg'
    STICKER = 'sticker.svg'
    STORM_OFF = 'storm-off.svg'
    STORM = 'storm.svg'
    STRETCHING_2 = 'stretching-2.svg'
    STRETCHING = 'stretching.svg'
    STRIKETHROUGH = 'strikethrough.svg'
    SUBMARINE = 'submarine.svg'
    SUBSCRIPT = 'subscript.svg'
    SUBTASK = 'subtask.svg'
    SUM_OFF = 'sum-off.svg'
    SUM = 'sum.svg'
    SUN_ELECTRICITY = 'sun-electricity.svg'
    SUN_HIGH = 'sun-high.svg'
    SUN_LOW = 'sun-low.svg'
    SUN_MOON = 'sun-moon.svg'
    SUN_OFF = 'sun-off.svg'
    SUN_WIND = 'sun-wind.svg'
    SUN = 'sun.svg'
    SUNGLASSES = 'sunglasses.svg'
    SUNRISE = 'sunrise.svg'
    SUNSET_2 = 'sunset-2.svg'
    SUNSET = 'sunset.svg'
    SUPERSCRIPT = 'superscript.svg'
    SVG = 'svg.svg'
    SWIMMING = 'swimming.svg'
    SWIPE_DOWN = 'swipe-down.svg'
    SWIPE_LEFT = 'swipe-left.svg'
    SWIPE_RIGHT = 'swipe-right.svg'
    SWIPE_UP = 'swipe-up.svg'
    SWIPE = 'swipe.svg'
    SWITCH_2 = 'switch-2.svg'
    SWITCH_3 = 'switch-3.svg'
    SWITCH_HORIZONTAL = 'switch-horizontal.svg'
    SWITCH_VERTICAL = 'switch-vertical.svg'
    SWITCH = 'switch.svg'
    SWORD_OFF = 'sword-off.svg'
    SWORD = 'sword.svg'
    SWORDS = 'swords.svg'
    TABLE_ALIAS = 'table-alias.svg'
    TABLE_COLUMN = 'table-column.svg'
    TABLE_DOWN = 'table-down.svg'
    TABLE_EXPORT = 'table-export.svg'
    TABLE_HEART = 'table-heart.svg'
    TABLE_IMPORT = 'table-import.svg'
    TABLE_MINUS = 'table-minus.svg'
    TABLE_OFF = 'table-off.svg'
    TABLE_OPTIONS = 'table-options.svg'
    TABLE_PLUS = 'table-plus.svg'
    TABLE_ROW = 'table-row.svg'
    TABLE_SHARE = 'table-share.svg'
    TABLE_SHORTCUT = 'table-shortcut.svg'
    TABLE = 'table.svg'
    TAG_OFF = 'tag-off.svg'
    TAG_STARRED = 'tag-starred.svg'
    TAG = 'tag.svg'
    TAGS_OFF = 'tags-off.svg'
    TAGS = 'tags.svg'
    TALLYMARK_1 = 'tallymark-1.svg'
    TALLYMARK_2 = 'tallymark-2.svg'
    TALLYMARK_3 = 'tallymark-3.svg'
    TALLYMARK_4 = 'tallymark-4.svg'
    TALLYMARKS = 'tallymarks.svg'
    TANK = 'tank.svg'
    TARGET_ARROW = 'target-arrow.svg'
    TARGET_OFF = 'target-off.svg'
    TARGET = 'target.svg'
    TEAPOT = 'teapot.svg'
    TELESCOPE_OFF = 'telescope-off.svg'
    TELESCOPE = 'telescope.svg'
    TEMPERATURE_CELSIUS = 'temperature-celsius.svg'
    TEMPERATURE_FAHRENHEIT = 'temperature-fahrenheit.svg'
    TEMPERATURE_MINUS = 'temperature-minus.svg'
    TEMPERATURE_OFF = 'temperature-off.svg'
    TEMPERATURE_PLUS = 'temperature-plus.svg'
    TEMPERATURE_SNOW = 'temperature-snow.svg'
    TEMPERATURE_SUN = 'temperature-sun.svg'
    TEMPERATURE = 'temperature.svg'
    TEMPLATE_OFF = 'template-off.svg'
    TEMPLATE = 'template.svg'
    TENT_OFF = 'tent-off.svg'
    TENT = 'tent.svg'
    TERMINAL_2 = 'terminal-2.svg'
    TERMINAL = 'terminal.svg'
    TEST_PIPE_2 = 'test-pipe-2.svg'
    TEST_PIPE_OFF = 'test-pipe-off.svg'
    TEST_PIPE = 'test-pipe.svg'
    TEX = 'tex.svg'
    TEXT_CAPTION = 'text-caption.svg'
    TEXT_COLOR = 'text-color.svg'
    TEXT_DECREASE = 'text-decrease.svg'
    TEXT_DIRECTION_LTR = 'text-direction-ltr.svg'
    TEXT_DIRECTION_RTL = 'text-direction-rtl.svg'
    TEXT_GRAMMAR = 'text-grammar.svg'
    TEXT_INCREASE = 'text-increase.svg'
    TEXT_ORIENTATION = 'text-orientation.svg'
    TEXT_PLUS = 'text-plus.svg'
    TEXT_RECOGNITION = 'text-recognition.svg'
    TEXT_RESIZE = 'text-resize.svg'
    TEXT_SCAN_2 = 'text-scan-2.svg'
    TEXT_SIZE = 'text-size.svg'
    TEXT_SPELLCHECK = 'text-spellcheck.svg'
    TEXT_WRAP_COLUMN = 'text-wrap-column.svg'
    TEXT_WRAP_DISABLED = 'text-wrap-disabled.svg'
    TEXT_WRAP = 'text-wrap.svg'
    TEXTURE = 'texture.svg'
    THEATER = 'theater.svg'
    THERMOMETER = 'thermometer.svg'
    THUMB_DOWN_OFF = 'thumb-down-off.svg'
    THUMB_DOWN = 'thumb-down.svg'
    THUMB_UP_OFF = 'thumb-up-off.svg'
    THUMB_UP = 'thumb-up.svg'
    TIC_TAC = 'tic-tac.svg'
    TICKET_OFF = 'ticket-off.svg'
    TICKET = 'ticket.svg'
    TIE = 'tie.svg'
    TILDE = 'tilde.svg'
    TILT_SHIFT_OFF = 'tilt-shift-off.svg'
    TILT_SHIFT = 'tilt-shift.svg'
    TIME_DURATION_0 = 'time-duration-0.svg'
    TIME_DURATION_10 = 'time-duration-10.svg'
    TIME_DURATION_15 = 'time-duration-15.svg'
    TIME_DURATION_30 = 'time-duration-30.svg'
    TIME_DURATION_45 = 'time-duration-45.svg'
    TIME_DURATION_5 = 'time-duration-5.svg'
    TIME_DURATION_60 = 'time-duration-60.svg'
    TIME_DURATION_90 = 'time-duration-90.svg'
    TIME_DURATION_OFF = 'time-duration-off.svg'
    TIMELINE_EVENT_EXCLAMATION = 'timeline-event-exclamation.svg'
    TIMELINE_EVENT_MINUS = 'timeline-event-minus.svg'
    TIMELINE_EVENT_PLUS = 'timeline-event-plus.svg'
    TIMELINE_EVENT_TEXT = 'timeline-event-text.svg'
    TIMELINE_EVENT_X = 'timeline-event-x.svg'
    TIMELINE_EVENT = 'timeline-event.svg'
    TIMELINE = 'timeline.svg'
    TIR = 'tir.svg'
    TOGGLE_LEFT = 'toggle-left.svg'
    TOGGLE_RIGHT = 'toggle-right.svg'
    TOILET_PAPER_OFF = 'toilet-paper-off.svg'
    TOILET_PAPER = 'toilet-paper.svg'
    TOML = 'toml.svg'
    TOOL = 'tool.svg'
    TOOLS_KITCHEN_2_OFF = 'tools-kitchen-2-off.svg'
    TOOLS_KITCHEN_2 = 'tools-kitchen-2.svg'
    TOOLS_KITCHEN_3 = 'tools-kitchen-3.svg'
    TOOLS_KITCHEN_OFF = 'tools-kitchen-off.svg'
    TOOLS_KITCHEN = 'tools-kitchen.svg'
    TOOLS_OFF = 'tools-off.svg'
    TOOLS = 'tools.svg'
    TOOLTIP = 'tooltip.svg'
    TOPOLOGY_BUS = 'topology-bus.svg'
    TOPOLOGY_COMPLEX = 'topology-complex.svg'
    TOPOLOGY_FULL_HIERARCHY = 'topology-full-hierarchy.svg'
    TOPOLOGY_FULL = 'topology-full.svg'
    TOPOLOGY_RING_2 = 'topology-ring-2.svg'
    TOPOLOGY_RING_3 = 'topology-ring-3.svg'
    TOPOLOGY_RING = 'topology-ring.svg'
    TOPOLOGY_STAR_2 = 'topology-star-2.svg'
    TOPOLOGY_STAR_3 = 'topology-star-3.svg'
    TOPOLOGY_STAR_RING_2 = 'topology-star-ring-2.svg'
    TOPOLOGY_STAR_RING_3 = 'topology-star-ring-3.svg'
    TOPOLOGY_STAR_RING = 'topology-star-ring.svg'
    TOPOLOGY_STAR = 'topology-star.svg'
    TORII = 'torii.svg'
    TORNADO = 'tornado.svg'
    TOURNAMENT = 'tournament.svg'
    TOWER_OFF = 'tower-off.svg'
    TOWER = 'tower.svg'
    TRACK = 'track.svg'
    TRACTOR = 'tractor.svg'
    TRADEMARK = 'trademark.svg'
    TRAFFIC_CONE_OFF = 'traffic-cone-off.svg'
    TRAFFIC_CONE = 'traffic-cone.svg'
    TRAFFIC_LIGHTS_OFF = 'traffic-lights-off.svg'
    TRAFFIC_LIGHTS = 'traffic-lights.svg'
    TRAIN = 'train.svg'
    TRANSACTION_BITCOIN = 'transaction-bitcoin.svg'
    TRANSACTION_DOLLAR = 'transaction-dollar.svg'
    TRANSACTION_EURO = 'transaction-euro.svg'
    TRANSACTION_POUND = 'transaction-pound.svg'
    TRANSACTION_RUPEE = 'transaction-rupee.svg'
    TRANSACTION_YEN = 'transaction-yen.svg'
    TRANSACTION_YUAN = 'transaction-yuan.svg'
    TRANSFER_IN = 'transfer-in.svg'
    TRANSFER_OUT = 'transfer-out.svg'
    TRANSFER_VERTICAL = 'transfer-vertical.svg'
    TRANSFER = 'transfer.svg'
    TRANSFORM_POINT_BOTTOM_LEFT = 'transform-point-bottom-left.svg'
    TRANSFORM_POINT_BOTTOM_RIGHT = 'transform-point-bottom-right.svg'
    TRANSFORM_POINT_TOP_LEFT = 'transform-point-top-left.svg'
    TRANSFORM_POINT_TOP_RIGHT = 'transform-point-top-right.svg'
    TRANSFORM_POINT = 'transform-point.svg'
    TRANSFORM = 'transform.svg'
    TRANSITION_BOTTOM = 'transition-bottom.svg'
    TRANSITION_LEFT = 'transition-left.svg'
    TRANSITION_RIGHT = 'transition-right.svg'
    TRANSITION_TOP = 'transition-top.svg'
    TRASH_OFF = 'trash-off.svg'
    TRASH_X = 'trash-x.svg'
    TRASH = 'trash.svg'
    TREADMILL = 'treadmill.svg'
    TREE = 'tree.svg'
    TREES = 'trees.svg'
    TREKKING = 'trekking.svg'
    TRENDING_DOWN_2 = 'trending-down-2.svg'
    TRENDING_DOWN_3 = 'trending-down-3.svg'
    TRENDING_DOWN = 'trending-down.svg'
    TRENDING_UP_2 = 'trending-up-2.svg'
    TRENDING_UP_3 = 'trending-up-3.svg'
    TRENDING_UP = 'trending-up.svg'
    TRIANGLE_INVERTED = 'triangle-inverted.svg'
    TRIANGLE_MINUS_2 = 'triangle-minus-2.svg'
    TRIANGLE_MINUS = 'triangle-minus.svg'
    TRIANGLE_OFF = 'triangle-off.svg'
    TRIANGLE_PLUS_2 = 'triangle-plus-2.svg'
    TRIANGLE_PLUS = 'triangle-plus.svg'
    TRIANGLE_SQUARE_CIRCLE = 'triangle-square-circle.svg'
    TRIANGLE = 'triangle.svg'
    TRIANGLES = 'triangles.svg'
    TRIDENT = 'trident.svg'
    TROLLEY = 'trolley.svg'
    TROPHY_OFF = 'trophy-off.svg'
    TROPHY = 'trophy.svg'
    TROWEL = 'trowel.svg'
    TRUCK_DELIVERY = 'truck-delivery.svg'
    TRUCK_LOADING = 'truck-loading.svg'
    TRUCK_OFF = 'truck-off.svg'
    TRUCK_RETURN = 'truck-return.svg'
    TRUCK = 'truck.svg'
    TXT = 'txt.svg'
    TYPEFACE = 'typeface.svg'
    TYPOGRAPHY_OFF = 'typography-off.svg'
    TYPOGRAPHY = 'typography.svg'
    U_TURN_LEFT = 'u-turn-left.svg'
    U_TURN_RIGHT = 'u-turn-right.svg'
    UFO_OFF = 'ufo-off.svg'
    UFO = 'ufo.svg'
    UMBRELLA_OFF = 'umbrella-off.svg'
    UMBRELLA = 'umbrella.svg'
    UNDERLINE = 'underline.svg'
    UNIVERSE = 'universe.svg'
    UNLINK = 'unlink.svg'
    UPLOAD = 'upload.svg'
    URGENT = 'urgent.svg'
    USB = 'usb.svg'
    USER_BOLT = 'user-bolt.svg'
    USER_CANCEL = 'user-cancel.svg'
    USER_CHECK = 'user-check.svg'
    USER_CIRCLE = 'user-circle.svg'
    USER_CODE = 'user-code.svg'
    USER_COG = 'user-cog.svg'
    USER_DOLLAR = 'user-dollar.svg'
    USER_DOWN = 'user-down.svg'
    USER_EDIT = 'user-edit.svg'
    USER_EXCLAMATION = 'user-exclamation.svg'
    USER_HEART = 'user-heart.svg'
    USER_HEXAGON = 'user-hexagon.svg'
    USER_MINUS = 'user-minus.svg'
    USER_OFF = 'user-off.svg'
    USER_PAUSE = 'user-pause.svg'
    USER_PENTAGON = 'user-pentagon.svg'
    USER_PIN = 'user-pin.svg'
    USER_PLUS = 'user-plus.svg'
    USER_QUESTION = 'user-question.svg'
    USER_SCAN = 'user-scan.svg'
    USER_SCREEN = 'user-screen.svg'
    USER_SEARCH = 'user-search.svg'
    USER_SHARE = 'user-share.svg'
    USER_SHIELD = 'user-shield.svg'
    USER_SQUARE_ROUNDED = 'user-square-rounded.svg'
    USER_SQUARE = 'user-square.svg'
    USER_STAR = 'user-star.svg'
    USER_UP = 'user-up.svg'
    USER_X = 'user-x.svg'
    USER = 'user.svg'
    USERS_GROUP = 'users-group.svg'
    USERS_MINUS = 'users-minus.svg'
    USERS_PLUS = 'users-plus.svg'
    USERS = 'users.svg'
    UV_INDEX = 'uv-index.svg'
    UX_CIRCLE = 'ux-circle.svg'
    VACCINE_BOTTLE_OFF = 'vaccine-bottle-off.svg'
    VACCINE_BOTTLE = 'vaccine-bottle.svg'
    VACCINE_OFF = 'vaccine-off.svg'
    VACCINE = 'vaccine.svg'
    VACUUM_CLEANER = 'vacuum-cleaner.svg'
    VARIABLE_MINUS = 'variable-minus.svg'
    VARIABLE_OFF = 'variable-off.svg'
    VARIABLE_PLUS = 'variable-plus.svg'
    VARIABLE = 'variable.svg'
    VECTOR_BEZIER_2 = 'vector-bezier-2.svg'
    VECTOR_BEZIER_ARC = 'vector-bezier-arc.svg'
    VECTOR_BEZIER_CIRCLE = 'vector-bezier-circle.svg'
    VECTOR_BEZIER = 'vector-bezier.svg'
    VECTOR_OFF = 'vector-off.svg'
    VECTOR_SPLINE = 'vector-spline.svg'
    VECTOR_TRIANGLE_OFF = 'vector-triangle-off.svg'
    VECTOR_TRIANGLE = 'vector-triangle.svg'
    VECTOR = 'vector.svg'
    VENUS = 'venus.svg'
    VERSIONS_OFF = 'versions-off.svg'
    VERSIONS = 'versions.svg'
    VIDEO_MINUS = 'video-minus.svg'
    VIDEO_OFF = 'video-off.svg'
    VIDEO_PLUS = 'video-plus.svg'
    VIDEO = 'video.svg'
    VIEW_360_ARROW = 'view-360-arrow.svg'
    VIEW_360_NUMBER = 'view-360-number.svg'
    VIEW_360_OFF = 'view-360-off.svg'
    VIEW_360 = 'view-360.svg'
    VIEWFINDER_OFF = 'viewfinder-off.svg'
    VIEWFINDER = 'viewfinder.svg'
    VIEWPORT_NARROW = 'viewport-narrow.svg'
    VIEWPORT_WIDE = 'viewport-wide.svg'
    VINYL = 'vinyl.svg'
    VIP_OFF = 'vip-off.svg'
    VIP = 'vip.svg'
    VIRUS_OFF = 'virus-off.svg'
    VIRUS_SEARCH = 'virus-search.svg'
    VIRUS = 'virus.svg'
    VOCABULARY_OFF = 'vocabulary-off.svg'
    VOCABULARY = 'vocabulary.svg'
    VOLCANO = 'volcano.svg'
    VOLUME_2 = 'volume-2.svg'
    VOLUME_3 = 'volume-3.svg'
    VOLUME_OFF = 'volume-off.svg'
    VOLUME = 'volume.svg'
    VS = 'vs.svg'
    WALK = 'walk.svg'
    WALL_OFF = 'wall-off.svg'
    WALL = 'wall.svg'
    WALLET_OFF = 'wallet-off.svg'
    WALLET = 'wallet.svg'
    WALLPAPER_OFF = 'wallpaper-off.svg'
    WALLPAPER = 'wallpaper.svg'
    WAND_OFF = 'wand-off.svg'
    WAND = 'wand.svg'
    WASH_DRY_1 = 'wash-dry-1.svg'
    WASH_DRY_2 = 'wash-dry-2.svg'
    WASH_DRY_3 = 'wash-dry-3.svg'
    WASH_DRY_A = 'wash-dry-a.svg'
    WASH_DRY_DIP = 'wash-dry-dip.svg'
    WASH_DRY_F = 'wash-dry-f.svg'
    WASH_DRY_FLAT = 'wash-dry-flat.svg'
    WASH_DRY_HANG = 'wash-dry-hang.svg'
    WASH_DRY_OFF = 'wash-dry-off.svg'
    WASH_DRY_P = 'wash-dry-p.svg'
    WASH_DRY_SHADE = 'wash-dry-shade.svg'
    WASH_DRY_W = 'wash-dry-w.svg'
    WASH_DRY = 'wash-dry.svg'
    WASH_DRYCLEAN_OFF = 'wash-dryclean-off.svg'
    WASH_DRYCLEAN = 'wash-dryclean.svg'
    WASH_ECO = 'wash-eco.svg'
    WASH_GENTLE = 'wash-gentle.svg'
    WASH_HAND = 'wash-hand.svg'
    WASH_MACHINE = 'wash-machine.svg'
    WASH_OFF = 'wash-off.svg'
    WASH_PRESS = 'wash-press.svg'
    WASH_TEMPERATURE_1 = 'wash-temperature-1.svg'
    WASH_TEMPERATURE_2 = 'wash-temperature-2.svg'
    WASH_TEMPERATURE_3 = 'wash-temperature-3.svg'
    WASH_TEMPERATURE_4 = 'wash-temperature-4.svg'
    WASH_TEMPERATURE_5 = 'wash-temperature-5.svg'
    WASH_TEMPERATURE_6 = 'wash-temperature-6.svg'
    WASH_TUMBLE_DRY = 'wash-tumble-dry.svg'
    WASH_TUMBLE_OFF = 'wash-tumble-off.svg'
    WASH = 'wash.svg'
    WATERPOLO = 'waterpolo.svg'
    WAVE_SAW_TOOL = 'wave-saw-tool.svg'
    WAVE_SINE = 'wave-sine.svg'
    WAVE_SQUARE = 'wave-square.svg'
    WAVES_ELECTRICITY = 'waves-electricity.svg'
    WEBHOOK_OFF = 'webhook-off.svg'
    WEBHOOK = 'webhook.svg'
    WEIGHT = 'weight.svg'
    WHEEL = 'wheel.svg'
    WHEELCHAIR_OFF = 'wheelchair-off.svg'
    WHEELCHAIR = 'wheelchair.svg'
    WHIRL = 'whirl.svg'
    WIFI_0 = 'wifi-0.svg'
    WIFI_1 = 'wifi-1.svg'
    WIFI_2 = 'wifi-2.svg'
    WIFI_OFF = 'wifi-off.svg'
    WIFI = 'wifi.svg'
    WIND_ELECTRICITY = 'wind-electricity.svg'
    WIND_OFF = 'wind-off.svg'
    WIND = 'wind.svg'
    WINDMILL_OFF = 'windmill-off.svg'
    WINDMILL = 'windmill.svg'
    WINDOW_MAXIMIZE = 'window-maximize.svg'
    WINDOW_MINIMIZE = 'window-minimize.svg'
    WINDOW_OFF = 'window-off.svg'
    WINDOW = 'window.svg'
    WINDSOCK = 'windsock.svg'
    WIPER_WASH = 'wiper-wash.svg'
    WIPER = 'wiper.svg'
    WOMAN = 'woman.svg'
    WOOD = 'wood.svg'
    WORLD_BOLT = 'world-bolt.svg'
    WORLD_CANCEL = 'world-cancel.svg'
    WORLD_CHECK = 'world-check.svg'
    WORLD_CODE = 'world-code.svg'
    WORLD_COG = 'world-cog.svg'
    WORLD_DOLLAR = 'world-dollar.svg'
    WORLD_DOWN = 'world-down.svg'
    WORLD_DOWNLOAD = 'world-download.svg'
    WORLD_EXCLAMATION = 'world-exclamation.svg'
    WORLD_HEART = 'world-heart.svg'
    WORLD_LATITUDE = 'world-latitude.svg'
    WORLD_LONGITUDE = 'world-longitude.svg'
    WORLD_MINUS = 'world-minus.svg'
    WORLD_OFF = 'world-off.svg'
    WORLD_PAUSE = 'world-pause.svg'
    WORLD_PIN = 'world-pin.svg'
    WORLD_PLUS = 'world-plus.svg'
    WORLD_QUESTION = 'world-question.svg'
    WORLD_SEARCH = 'world-search.svg'
    WORLD_SHARE = 'world-share.svg'
    WORLD_STAR = 'world-star.svg'
    WORLD_UP = 'world-up.svg'
    WORLD_UPLOAD = 'world-upload.svg'
    WORLD_WWW = 'world-www.svg'
    WORLD_X = 'world-x.svg'
    WORLD = 'world.svg'
    WRECKING_BALL = 'wrecking-ball.svg'
    WRITING_OFF = 'writing-off.svg'
    WRITING_SIGN_OFF = 'writing-sign-off.svg'
    WRITING_SIGN = 'writing-sign.svg'
    WRITING = 'writing.svg'
    X = 'x.svg'
    XBOX_A = 'xbox-a.svg'
    XBOX_B = 'xbox-b.svg'
    XBOX_X = 'xbox-x.svg'
    XBOX_Y = 'xbox-y.svg'
    XD = 'xd.svg'
    XXX = 'xxx.svg'
    YIN_YANG = 'yin-yang.svg'
    YOGA = 'yoga.svg'
    ZEPPELIN_OFF = 'zeppelin-off.svg'
    ZEPPELIN = 'zeppelin.svg'
    ZIP = 'zip.svg'
    ZODIAC_AQUARIUS = 'zodiac-aquarius.svg'
    ZODIAC_ARIES = 'zodiac-aries.svg'
    ZODIAC_CANCER = 'zodiac-cancer.svg'
    ZODIAC_CAPRICORN = 'zodiac-capricorn.svg'
    ZODIAC_GEMINI = 'zodiac-gemini.svg'
    ZODIAC_LEO = 'zodiac-leo.svg'
    ZODIAC_LIBRA = 'zodiac-libra.svg'
    ZODIAC_PISCES = 'zodiac-pisces.svg'
    ZODIAC_SAGITTARIUS = 'zodiac-sagittarius.svg'
    ZODIAC_SCORPIO = 'zodiac-scorpio.svg'
    ZODIAC_TAURUS = 'zodiac-taurus.svg'
    ZODIAC_VIRGO = 'zodiac-virgo.svg'
    ZOOM_CANCEL = 'zoom-cancel.svg'
    ZOOM_CHECK = 'zoom-check.svg'
    ZOOM_CODE = 'zoom-code.svg'
    ZOOM_EXCLAMATION = 'zoom-exclamation.svg'
    ZOOM_IN_AREA = 'zoom-in-area.svg'
    ZOOM_IN = 'zoom-in.svg'
    ZOOM_MONEY = 'zoom-money.svg'
    ZOOM_OUT_AREA = 'zoom-out-area.svg'
    ZOOM_OUT = 'zoom-out.svg'
    ZOOM_PAN = 'zoom-pan.svg'
    ZOOM_QUESTION = 'zoom-question.svg'
    ZOOM_REPLACE = 'zoom-replace.svg'
    ZOOM_RESET = 'zoom-reset.svg'
    ZOOM_SCAN = 'zoom-scan.svg'
    ZOOM = 'zoom.svg'
    ZZZ_OFF = 'zzz-off.svg'
    ZZZ = 'zzz.svg'
